#
# spec file for package gnome-shell
#
# Copyright (c) 2024 SUSE LLC
#
# All modifications and additions to the file contributed by third parties
# remain the property of their copyright owners, unless otherwise agreed
# upon. The license for this file, and modifications and additions to the
# file, is the same license as for the pristine package itself (unless the
# license for the pristine package is not an Open Source License, in which
# case the license is the MIT License). An "Open Source License" is a
# license that conforms to the Open Source Definition (Version 1.9)
# published by the Open Source Initiative.

# Please submit bugfixes or comments via https://bugs.opensuse.org/
#


%global __requires_exclude typelib\\(Meta|MetaTest|Soup|St|Cogl|Clutter|TelepathyGlib\\)
%define mutter_api 14
%define mutter_req 46.0

Name:           gnome-shell
Version:        46.3.1
Release:        1.1
Summary:        GNOME Shell
# shew extension is LGPL 2.1; gnome-shell-extension-tool is GPL-3.0-or-later
License:        GPL-2.0-or-later AND LGPL-2.1-or-later AND GPL-3.0-or-later
Group:          System/GUI/GNOME
URL:            https://wiki.gnome.org/Projects/GnomeShell
# Source url disabled as we are using a git checkout via source service
Source0:        %{name}-%{version}.tar.zst
Source1:        libgnome-volume-control-0.gitmodule.tar.zst

# SOURCE-FEATURE-OPENSUSE noise-texture boo#1176418 qkzhu@suse.com -- Add noise-texture as the default greeter background, used by patch4.
Source100:      noise-texture.png

# PATCH-FIX-UPSTREAM gnome-shell-private-connection.patch bnc#751211 bgo#646187 dimstar@opensuse.org -- create private connections if the user is not authorized
Patch1:         gnome-shell-private-connection.patch
# PATCH-FIX-OPENSUSE gnome-shell-executable-path-not-absolute.patch bsc#1176051 xwang@suse.com --  Fix ExecStart is not absolute path
Patch7:         gnome-shell-executable-path-not-absolute.patch
# PATCH-FIX-UPSTREAM gnome-shell-exit-crash-workaround.patch bsc#1190878 glgo#GNOME/gnome-shell#4344 qkzhu@suse.com -- Workaround logout crashing
Patch8:         gnome-shell-exit-crash-workaround.patch
# PATCH-FIX-UPSTREAM gnome-shell-fix-cursor-on-hide-preedit.patch glgo#GNOME/gnome-shell!3318 alynx.zhou@suse.com -- Correctly reset cursor when hide preedit
Patch9:         gnome-shell-fix-cursor-on-hide-preedit.patch

## NOTE: Keep SLE-only patches at bottom (starting on 1000).
# PATCH-FEATURE-SLE gnome-shell-gdm-login-applet.patch fate#314545 dliang@suse.com -- Add an applet on login UI to display suse icon, product name, hostname.
Patch1001:      gnome-shell-gdm-login-applet.patch
# PATCH-FEATURE-SLE gnome-shell-domain.patch fate#307773 dliang@suse.com -- Active Directory Integration
Patch1002:      gnome-shell-domain.patch
# PATCH-FIX-SLE gnome-shell-screen-disappear.patch bnc#870217 dliang@suse.com -- screen disapper.
Patch1003:      gnome-shell-screen-disappear.patch
# PATCH-FIX-SLE endSession-dialog-update-time-label-every-sec.patch bnc#886132 cxiong@suse.com -- update time label every second in end session dialog
Patch1004:      endSession-dialog-update-time-label-every-sec.patch
# PATCH-FIX-SLE gs-fate318433-prevent-same-account-multi-logins.patch fate#318433 cxiong@suse.com -- prevent multiple simultaneous login.
Patch1007:      gs-fate318433-prevent-same-account-multi-logins.patch
# PATCH-FIX-SLE gnome-shell-disable-ibus-when-not-installed.patch bsc#987360 qzhao@suse.com -- disable ibus start when outof Chinese, Japanese, Korean area
Patch1008:      gnome-shell-disable-ibus-when-not-installed.patch
# PATCH-FEATURE-SLE gnome-shell-fate324570-Make-GDM-background-image-configurable.patch fate#324570, glgo#GNOME/gnome-shell#680, boo#1172826 qkzhu@suse.com -- make GDM background image configurable
Patch1009:      gnome-shell-fate324570-Make-GDM-background-image-configurable.patch
# PATCH-FIX-UPSTREAM gnome-shell-jsc#SLE-16051-Input-method-recommendation.patch jsc#SLE-16051 glgo#GNOME/gnome-shell!1563 qzhao@suse.com -- launch recommended input engines when Gnome-shell init in CJK regions.
Patch1010:      gnome-shell-jsc#SLE-16051-Input-method-recommendation.patch
# PATCH-FIX-SLE gnome-shell-disable-offline-update-dialog.patch bsc#944832 milachew@mail.lv -- Disable offline update suggestion before shutdown/reboot in SLE and openSUSE Leap.
Patch1011:      gnome-shell-disable-offline-update-dialog.patch
# PATCH-FEATURE-SLE gnome-shell-jscSLE9267-Remove-sessionList-of-endSessionDialog.patch jsc#SLE-9267 qkzhu@suse.com -- Remove sessionList of endSessionDialog
Patch1012:      gnome-shell-jscSLE9267-Remove-sessionList-of-endSessionDialog.patch
# PATCH-FIX-SLE gnome-shell-add-linkoption-dl.patch -- Need explicit -ldl build option with older gcc on SLE 15
Patch1013:      gnome-shell-add-linkoption-dl.patch

# needed for directory ownership
BuildRequires:  asciidoc
BuildRequires:  dbus-1
BuildRequires:  docbook-xsl-stylesheets
BuildRequires:  fdupes
BuildRequires:  gcc-c++
BuildRequires:  meson >= 0.58.0
BuildRequires:  pkgconfig
BuildRequires:  sassc
BuildRequires:  xsltproc
BuildRequires:  pkgconfig(atk-bridge-2.0)
BuildRequires:  pkgconfig(bash-completion)
BuildRequires:  pkgconfig(gcr-4) >= 3.90.0
BuildRequires:  pkgconfig(gdk-pixbuf-2.0)
BuildRequires:  pkgconfig(gdk-x11-3.0)
BuildRequires:  pkgconfig(gi-docgen)
BuildRequires:  pkgconfig(gio-2.0) >= 2.56.0
BuildRequires:  pkgconfig(gio-unix-2.0) >= 2.56.0
BuildRequires:  pkgconfig(gjs-1.0) >= 1.71.1
BuildRequires:  pkgconfig(gnome-autoar-0)
BuildRequires:  pkgconfig(gnome-bluetooth-3.0)
BuildRequires:  pkgconfig(gnome-desktop-4)
BuildRequires:  pkgconfig(gnome-keybindings)
BuildRequires:  pkgconfig(gobject-2.0)
BuildRequires:  pkgconfig(gobject-introspection-1.0) >= 1.49.1
BuildRequires:  pkgconfig(gsettings-desktop-schemas) >= 46.beta
BuildRequires:  pkgconfig(gstreamer-1.0) >= 0.11.92
BuildRequires:  pkgconfig(gstreamer-base-1.0)
BuildRequires:  pkgconfig(gtk+-3.0) >= 3.15.0
BuildRequires:  pkgconfig(gtk4)
BuildRequires:  pkgconfig(ibus-1.0) >= 1.5.19
BuildRequires:  pkgconfig(json-glib-1.0) >= 0.13.2
BuildRequires:  pkgconfig(libcanberra)
BuildRequires:  pkgconfig(libcanberra-gtk3)
BuildRequires:  pkgconfig(libecal-2.0) >= 3.33.1
BuildRequires:  pkgconfig(libedataserver-1.2) >= 3.33.1
BuildRequires:  pkgconfig(libgnome-menu-3.0) >= 3.5.3
BuildRequires:  pkgconfig(libmutter-%{mutter_api}) >= %{mutter_req}
BuildRequires:  pkgconfig(libnm) >= 1.10.4
BuildRequires:  pkgconfig(libpipewire-0.3)
BuildRequires:  pkgconfig(libpulse) >= 2.0
BuildRequires:  pkgconfig(libpulse-mainloop-glib)
BuildRequires:  pkgconfig(libsecret-1) >= 0.18
BuildRequires:  pkgconfig(libsoup-3.0)
BuildRequires:  pkgconfig(libstartup-notification-1.0) >= 0.11
BuildRequires:  pkgconfig(libsystemd)
BuildRequires:  pkgconfig(libxml-2.0)
BuildRequires:  pkgconfig(mutter-clutter-%{mutter_api}) >= %{mutter_req}
BuildRequires:  pkgconfig(mutter-cogl-%{mutter_api}) >= %{mutter_req}
BuildRequires:  pkgconfig(mutter-cogl-pango-%{mutter_api}) >= %{mutter_req}
BuildRequires:  pkgconfig(polkit-agent-1) >= 0.100
BuildRequires:  pkgconfig(x11)
BuildRequires:  python(abi) >= 3
Requires:       gdk-pixbuf-loader-rsvg
Requires:       gstreamer-plugin-pipewire
# "System settings" menu item
Requires:       gnome-control-center
Requires:       gnome-session
# For a GSettings schema and power system icon
Requires:       gnome-settings-daemon
# "High Contrast" in accessibility status icon
Requires:       gnome-themes-accessibility
Requires:       gsettings-desktop-schemas
# ScreenSaver needs this.
Requires:       gjs >= 1.71.1
Requires:       mutter >= %{mutter_req}
Requires:       typelib(Soup) = 3.0
Recommends:     %{name}-calendar
## Finally, dependencies for session services that are needed for system icons and the user menu
# bluetooth system icon
# (lowered to recommends due to bsc#1067603, some setups without bluetooth might want to avoid this dependency)
Recommends:     gnome-bluetooth
# The dateTime applet in the panel launches gnome-clocks upon user request
Recommends:     gnome-clocks
# gnome-shell implements the dbus interface org.freedesktop.Notifications directly
Provides:       dbus(org.freedesktop.Notifications)
# gnome-shell-browser-plugin dropped in 3.31.4
Obsoletes:      gnome-shell-browser-plugin <= %{version}

%description
The GNOME Shell redefines user interactions with the GNOME desktop. In
particular, it offers new paradigms for launching applications, accessing
documents, and organizing open windows in GNOME.

%package devel
Summary:        Development files for GNOME Shell
Group:          Development/Libraries/GNOME
Requires:       %{name} = %{version}

%description devel
The GNOME Shell redefines user interactions with the GNOME desktop. In
particular, it offers new paradigms for launching applications, accessing
documents, and organizing open windows in GNOME.

%package calendar
Summary:        Evolution Calendar support for GNOME Shell
Group:          System/GUI/GNOME
Requires:       %{name} = %{version}
# The clock / calendar applet in the panel requires e-d-s (bnc#795793).
Requires:       evolution-data-server
Supplements:    (%{name} and evolution-data-server)

%description calendar
This package adds support for Evolution Calendar, such as appointments
into GNOME Shell calendar.

%package -n gnome-extensions
Summary:        Extensions app for GNOME Shell
Group:          System/GUI/GNOME
Requires:       %{name} = %{version}

%description -n gnome-extensions
This package contains an optional extensions app for managing GNOME Shell extensions.

%lang_package

%prep
%autosetup -N
pushd subprojects
tar xf %{SOURCE1}
mv libgnome-volume-control-0.gitmodule gvc
popd
%patch -P 1 -p1
%patch -P 7 -p1
%patch -P 8 -p1
%patch -P 9 -p1

%if 0%{?sle_version}
%patch -P 1001 -p1
%patch -P 1002 -p1
%patch -P 1003 -p1
%patch -P 1004 -p1
%patch -P 1007 -p1
%patch -P 1008 -p1
%patch -P 1009 -p1
%if 0%{?suse_version} > 1500 || 0%{?sle_version} >= 150300
%patch -P 1010 -p1
%patch -P 1011 -p1
%endif
%patch -P 1012 -p1
%patch -P 1013 -p1
%endif

cp %{SOURCE100} data/theme/

%build
%meson \
	--libexecdir=%{_libexecdir}/%{name} \
	-D gtk_doc=true \
	-D man=true \
	-D networkmanager=true \
	-D systemd=true \
	-D tests=false \
	%{nil}
%meson_build

%install
%meson_install
# This is the directory where extensions get installed
install -d %{buildroot}%{_datadir}/gnome-shell/extensions
# This is the directory where search providers get installed
install -d %{buildroot}%{_datadir}/gnome-shell/search-providers
%find_lang %{name} %{?no_lang_C}
# Work around race, as reported in bnc#844891 & bgo#709313.
install -d %{buildroot}%{_datadir}/gnome-shell/modes
%fdupes %{buildroot}%{_prefix}
# Not needed, only used for nightly git snapshots
rm -f %{buildroot}%{_datadir}/icons/hicolor/scalable/apps/org.gnome.Extensions.Devel.svg
%python3_fix_shebang

%files
%license COPYING
%doc README.md NEWS
%{_bindir}/gnome-shell
%{_bindir}/gnome-extensions
%{_bindir}/gnome-shell-extension-prefs
%{_bindir}/gnome-shell-extension-tool
%{_bindir}/gnome-shell-test-tool
%dir %{_libdir}/gnome-shell
%dir %{_libexecdir}/gnome-shell
%exclude %{_libexecdir}/gnome-shell/gnome-shell-calendar-server
%{_libexecdir}/gnome-shell/gnome-shell-hotplug-sniffer
%{_libexecdir}/gnome-shell/gnome-shell-perf-helper
%{_libexecdir}/gnome-shell/gnome-shell-portal-helper
%{_libdir}/gnome-shell/Gvc-1.0.typelib
%{_libdir}/gnome-shell/Shell-%{mutter_api}.typelib
%{_libdir}/gnome-shell/St-%{mutter_api}.typelib
%{_libdir}/gnome-shell/libgnome-shell-menu.so
%{_libdir}/gnome-shell/libshell-%{mutter_api}.so
%{_libdir}/gnome-shell/libgvc.so
%{_libdir}/gnome-shell/libst-%{mutter_api}.so
%{_datadir}/applications/org.gnome.Shell.desktop
%{_datadir}/applications/org.gnome.Shell.PortalHelper.desktop
%{_datadir}/dbus-1/interfaces/org.gnome.Shell.Introspect.xml
%{_datadir}/dbus-1/interfaces/org.gnome.Shell.PadOsd.xml
%{_datadir}/dbus-1/interfaces/org.gnome.Shell.Screencast.xml
%{_datadir}/dbus-1/interfaces/org.gnome.Shell.Screenshot.xml
%{_datadir}/dbus-1/interfaces/org.gnome.ShellSearchProvider.xml
%{_datadir}/dbus-1/interfaces/org.gnome.ShellSearchProvider2.xml
%{_datadir}/dbus-1/services/org.gnome.Shell.HotplugSniffer.service
%{_datadir}/dbus-1/services/org.gnome.Shell.PortalHelper.service
%{_datadir}/glib-2.0/schemas/org.gnome.Extensions.gschema.xml
%{_datadir}/glib-2.0/schemas/org.gnome.shell.gschema.xml
%{_datadir}/gnome-control-center/keybindings/50-gnome-shell-launchers.xml
%{_datadir}/gnome-control-center/keybindings/50-gnome-shell-system.xml
%{_datadir}/gnome-control-center/keybindings/50-gnome-shell-screenshots.xml
# Own these dirs for extensions, search-providers and work around a race condition
%dir %{_datadir}/gnome-shell/extensions
%dir %{_datadir}/gnome-shell/search-providers
%dir %{_datadir}/gnome-shell/modes
%{_datadir}/gnome-shell/gnome-shell-dbus-interfaces.gresource
%{_datadir}/gnome-shell/gnome-shell-theme.gresource
%{_datadir}/gnome-shell/gnome-shell-osk-layouts.gresource
%{_datadir}/gnome-shell/perf-background.xml
%{_datadir}/gnome-shell/gnome-shell-icons.gresource
%{_mandir}/man?/gnome-shell.?%{ext_man}
%{_userunitdir}/org.gnome.Shell.target
%{_userunitdir}/org.gnome.Shell@wayland.service
%{_userunitdir}/org.gnome.Shell@x11.service
%{_datadir}/glib-2.0/schemas/00_org.gnome.shell.gschema.override

%dir %{_libdir}/gnome-shell/girepository-1.0
%{_libdir}/gnome-shell/girepository-1.0/Shew-0.typelib

%{_libdir}/gnome-shell/libshew-0.so

%{_datadir}/dbus-1/services/org.gnome.Shell.Notifications.service
%{_datadir}/gnome-shell/org.gnome.Shell.Notifications
%{_datadir}/gnome-shell/org.gnome.Shell.Notifications.src.gresource

%{_datadir}/dbus-1/services/org.gnome.Shell.Screencast.service
%{_datadir}/gnome-shell/org.gnome.Shell.Screencast
%{_datadir}/gnome-shell/org.gnome.Shell.Screencast.src.gresource

%{_datadir}/dbus-1/services/org.gnome.ScreenSaver.service
%{_datadir}/gnome-shell/org.gnome.ScreenSaver
%{_datadir}/gnome-shell/org.gnome.ScreenSaver.src.gresource

%{_mandir}/man?/gnome-extensions.?%{ext_man}
%{_datadir}/bash-completion/completions/gnome-extensions
%{_datadir}/icons/hicolor/scalable/apps/org.gnome.Shell.Extensions.svg
%{_datadir}/icons/hicolor/symbolic/apps/org.gnome.Shell.Extensions-symbolic.svg
%{_userunitdir}/org.gnome.Shell-disable-extensions.service
%{_datadir}/applications/org.gnome.Shell.Extensions.desktop
%{_datadir}/dbus-1/interfaces/org.gnome.Shell.Extensions.xml
%{_datadir}/dbus-1/services/org.gnome.Shell.Extensions.service
%{_datadir}/gnome-shell/org.gnome.Shell.Extensions
%{_datadir}/gnome-shell/org.gnome.Shell.Extensions.src.gresource

%files devel
%doc %{_datadir}/doc/shell/
%doc %{_datadir}/doc/st/
%{_datadir}/gnome-shell/*.gir
%dir %{_datadir}/gnome-shell/gir-1.0
%{_datadir}/gnome-shell/gir-1.0/Shew-0.gir

%files calendar
%{_libexecdir}/gnome-shell/gnome-shell-calendar-server
%{_datadir}/dbus-1/services/org.gnome.Shell.CalendarServer.service

%files -n gnome-extensions
%{_bindir}/gnome-extensions-app
%{_datadir}/applications/org.gnome.Extensions.desktop
%{_datadir}/icons/hicolor/scalable/apps/org.gnome.Extensions.svg
%{_datadir}/icons/hicolor/symbolic/apps/org.gnome.Extensions-symbolic.svg
%{_datadir}/dbus-1/services/org.gnome.Extensions.service
%{_datadir}/gnome-shell/org.gnome.Extensions
%{_datadir}/gnome-shell/org.gnome.Extensions.data.gresource
%{_datadir}/gnome-shell/org.gnome.Extensions.src.gresource
%{_datadir}/metainfo/org.gnome.Extensions.metainfo.xml

%files lang -f %{name}.lang

%changelog
* Sun Jun 30 2024 Bjørn Lie <bjorn.lie@gmail.com>
- Update to version 46.3.1:
  + Fix including gvc source in tarball
- Changes from version 46.3:
  + Fix rendering artifacts of some rounded borders
  + Fix overview animation glitch when windows overlap workspaces
  + Misc. bug fixes and cleanups
  + Updated translations.
- Add gvc (libgnome-volume-control) submodule to _service file and
  inject subproject into the source directory. This is not tracked
  as git submodules, so the regular 'git submodule' service
  parameter is ineffective here.
* Mon May 27 2024 Dominique Leuenberger <dimstar@opensuse.org>
- Update to version 46.2:
  + Fix size of workspace switcher OSD.
  + Fix handling of invalid TLS certs in portal handler.
  + Exclude override-redirect windows from workspace animation.
  + Also center time on lock screen when using 12h format.
  + Use absolute tray icon position in root event coordinates.
  + Fix displaying info messages on login screen.
  + Correct expected bus name for streams.
  + Fix notifications on lock screen.
  + notifications: Only apply special styling to symbolic icons.
  + Fix number of search results with Large Text option.
  + Fix showing keyboard layouts with variants.
  + Tweak font sizes in calendar.
  + automountManager: Fix re-asking password for TCRYPT devices.
  + Fix stuck unlock prompt when animations are disabled.
  + Fix possible hang on startup during ibus-daemon launch.
  + Misc. bug fixes and cleanups.
  + Updated translations.
* Fri May 17 2024 Alynx Zhou <alynx.zhou@suse.com>
- Add gnome-shell-fix-cursor-on-hide-preedit.patch: Correctly reset
  preedit cursor location when hide preedit text to prevent
  potential problems (glgo#GNOME/gnome-shell!3318).
* Thu May  2 2024 Dominique Leuenberger <dimstar@opensuse.org>
- Update to version 46.1:
  + Improve notification of conflicting session.
  + Add shift level to Korean OSK layout.
  + Fix markup support in notifications.
  + extensions-app: Fix empty rows with '&' in extension name.
  + extensions-app: Improve HIG compliance.
  + Omit expand buttons in notification banners.
  + Misc. bug fixes and cleanups.
  + Updated translations.
* Mon Apr 29 2024 pgajdos@suse.com
- remove dependency on /usr/bin/python3 using
  %%python3_fix_shebang macro, [bsc#1212476]
* Sun Mar 17 2024 Dominique Leuenberger <dimstar@opensuse.org>
- Update to version 46.0:
  + Fix model selection in on-screen keyboard.
  + Fix key getting stuck when raising screen shield.
  + Fix notifications sometimes being empty.
  + Fix cursor visibilty when magnified.
  + Fixed crashes.
  + Misc. bug fixes and cleanups.
  + Updated translations.
* Fri Mar  8 2024 Dominique Leuenberger <dimstar@opensuse.org>
- Update to version 46.rc:
  + Fix repainting drawing area.
  + Support locking down extension installation.
  + Fix auto-closing FDO notifications.
  + Ensure remote actions are activated with correct platform data.
  + FDO notifications: Support ActivationToken signal.
  + Delete selected text on backspace from on-screen keyboard.
  + Various on-screen keyboard improvements.
  + Inform users of conflicting local/remote sessions on login.
  + screencasts: Use h264 encoding if available.
  + Work around issue in NetworkManager's wireguard support.
  + Allow expanding notifications in message list.
  + Fixed crash.
  + Misc. bug fixes and cleanups.
  + Updated translations.
* Fri Mar  8 2024 Dominique Leuenberger <dimstar@opensuse.org>
- Update to version 46.beta:
  + Improve High Contrast styling.
  + Improve default styling.
  + Close mount notification when drive gets disconnected.
  + extensions-app: Remember window state.
  + Fix feedback look in keyboard backlight slider.
  + Follow "switch-shapes" accessibility setting.
  + Fix effects of transient wayland windows.
  + Add keyboard model configuration support.
  + Add Text Editor to the dash by default.
  + Fix icon size regression in dash.
  + Improve project and development documentation.
  + overview: Keep dimming effect for modal dialogs.
  + Do not use markup in button labels.
  + Fix menu alignment in RTL locales.
  + Overhaul assets in monitor layout switcher.
  + Fix overview transition from search results to session.
  + Add header to notifications.
  + extensions-app: Use adaptive dialogs.
  + Register custom D-Bus errors.
  + Improve appearance of symbolic icons in notifications.
  + Improve minimize animation.
  + Use a single source for all system notifications.
  + Add missing shift level to Georgian OSK layout.
  + Tweak switch appearance.
  + Improve handling of screencast failures.
  + Fixed crash.
  + Misc. bug fixes and cleanups.
* Fri Mar  8 2024 Dominique Leuenberger <dimstar@opensuse.org>
- Update to version 46.alpha:
  + Fix scroll handling on sliders.
  + overview: Handle unredirection as part of the state transition.
  + Handle DESKTOP windows during workspace animations.
  + Improve wording in welcome dialog.
  + Improve recording indicator in light style.
  + Fix calendar popup shrinking on date changes.
  + app: Make all windows on target workspace recent when
    activated.
  + Fix performance degradation due to repeated signal leak.
  + Optimize application search.
  + Fix on-screen keyboard backspace getting stuck.
  + Adapt to ClutterContainer removal.
  + Fix arrow navigation in search results.
  + Improve monitor OSD labels.
  + Use dedicated assets in ctrl-alt-tab popup.
  + Updated translations.
- Replace gtk-doc BuildRequires with pkgconfig(gi-docgen): follow
  upstreams port to gi-docgen.
* Thu Mar  7 2024 Xiaoguang Wang <xiaoguang.wang@suse.com>
- Update gnome-shell-gdm-login-applet.patch: Clean up JS errors
  (bsc#1221100).
* Tue Feb 20 2024 Alynx Zhou <alynx.zhou@suse.com>
- Add gjs Requires, because ScreenSaver DBus daemon is a gjs
  script. (bsc#1219359)
* Mon Jan 22 2024 Xiaoguang Wang <xiaoguang.wang@suse.com>
- Adapt to version 45.3 (bsc#1216072):
  + Rebase gnome-shell-domain.patch
  + Rebase gnome-shell-fate324570-Make-GDM-background-image-configurable.patch
* Wed Jan 10 2024 Dominique Leuenberger <dimstar@opensuse.org>
- Update to version 45.3:
  + Allow any enter key to be used to screenshot.
  + Fix spinner in light style variant.
  + Improve formatting of extension errors.
  + Fixed crash.
  + Misc. bug fixes and cleanups.
  + Updated translations.
- Drop gnome-shell_nb_fix_trans.patch: fixed upstream.
* Sat Dec  2 2023 Bjørn Lie <bjorn.lie@gmail.com>
- Update to version 45.2:
  + Fix performance degradation due to repeated signal leak
  + Optimize application search
  + Fix on-screen keyboard backspace getting stuck
  + Fix arrow navigation in search results
  + Support async code in Eval() D-Bus method
  + Fix sliders not requesting any size
  + Only show prefs dialog after the extension has been loaded
  + Improve high-contrast styling
  + Fix mapping of tablet rings/strips
  + Add support for "version-name" field in extension metainfo
  + Fixed crashes
  + Misc. bug fixes and cleanups
  + Updated translations.
* Tue Nov 28 2023 Dominique Leuenberger <dimstar@opensuse.org>
- Use %%patch -p N instead of deprecated %%patchN.
* Wed Nov  1 2023 Bjørn Lie <bjorn.lie@gmail.com>
- Update to version 45.1:
  + Fix scroll handling on sliders
  + overview: Handle unredirection as part of the state transition
  + Handle DESKTOP windows during workspace animations
  + Fix unexpected focus changes with multi-window apps
  + Improve recording indicator in light style
  + Fix calendar popup shrinking on date changes
  + Fixed crashes
  + Misc. bug fixes and cleanups
  + Updated translations.
* Thu Oct 26 2023 bjorn.lie@gmail.com
- Update to version 45.0+20:
  + workspaceAnimation: Handle DESKTOP windows
  + st/scroll-view: Use clutter_actor_get_effect() to get fade effect
  + overview: Handle unredirection in OverviewShown state machine
  + status/system: Use Intl to format battery percentage
  + slider:
  - Ignore left/right scroll directions
  - Fix check for emulated scroll events
  + Updated translations.
- Add gnome-shell_nb_fix_trans.patch: Fix typo in translation
  breaking gnome-shell calendar overview.
* Fri Oct 20 2023 Xiaoguang Wang <xiaoguang.wang@suse.com>
- Rebase patches for SLE-15-SP6 (bsc#1216072):
  + Rebase endSession-dialog-update-time-label-every-sec.patch
  + Rebase gnome-shell-disable-ibus-when-not-installed.patch
  + Rebase gnome-shell-domain.patch
  + Rebase gnome-shell-exit-crash-workaround.patch
  + Rebase gnome-shell-fate324570-Make-GDM-background-image-configurable.patch
  + Rebase gnome-shell-gdm-login-applet.patch
  + Rebase gnome-shell-jsc#SLE-16051-Input-method-recommendation.patch
  + Rebase gnome-shell-jscSLE9267-Remove-sessionList-of-endSessionDialog.patch
  + Rebase gnome-shell-screen-disappear.patch
  + Remove aboutMenu.js
* Thu Oct 12 2023 Yifan Jiang <yfjiang@suse.com>
- Add gnome-shell-add-linkoption-dl.patch on SLE and Leap: the -ldl
  option to build gnome-shell main programme is needed because an
  upstream fix. This option needs explicitly given on current SLE
  build environment. See:
  https://gitlab.gnome.org/GNOME/gnome-shell/-/commit/65cde18786e2bea8ffe33317b86182207e419240
* Sat Sep 16 2023 Bjørn Lie <bjorn.lie@gmail.com>
- Update to version 45.0:
  + Fix exposing window previews on lock screen via keyboard
    shortcuts
  + Improve handling of latched vs. locked modes in OSK
  + Fix regression in workspace state tracking
  + Update extensions immediately on startup after major upgrades
  + Reverse slider direction in RTL locales
  + Misc. bug fixes and cleanups (bsc#1215485 CVE-2023-43090).
  + Updated translations.
- Change compression of tarball in service and spec to zst from xz.
* Wed Sep  6 2023 Bjørn Lie <bjorn.lie@gmail.com>
- Update to version 45.rc:
  + Allow notification dismissal with backspace
  + Add workspace indicators in activities button
  + Add extension hook to add quick settings items
  + Fix legibility issue in calendar
  + Fix three-finger swipes on touchscreens
  + Add more options to `gnome-extensions create`
  + Fix scrolling regression in ScrollView
  + Fix broken workspace animation with swipe gesture
  + Restore focus indication in system entries
  + Use UUID as fallback extension gettext domain
  + Reflect core app change in default "Utilities" folder
  + Support OWE networks in status menu
  + Show immediate feedback when toggling bluetooth
  + Switch workspaces when scrolling over activities button
  + Wrap around when navigating menus with arrow keys
  + Fix background apps menu showing up empty
  + Misc. bug fixes and cleanups
  + Updated translations.
* Mon Sep  4 2023 Bjørn Lie <bjorn.lie@gmail.com>
- Update to version 45.beta.1:
  + Fix input handling in alt-tab and several other components
  + Fix screenshot tool
  + Export notification source classes for extensions
  + Finishing ESM porting touches
  + Misc. bug fixes and cleanups
  + Updated translations.
* Mon Sep  4 2023 Bjørn Lie <bjorn.lie@gmail.com>
- Update to version 45.beta:
  + Load extensions as modules
  + Run "perf" tests as external scripts
  + Remove toLocaleFormat() from date
  + Use Tecla for keyboard layout previews
  + Fix accessibility of quick settings sliders
  + Port to EcmaScript modules
  + Overhaul ExtensionUtils API for modules
  + Add a camera indicator
  + Add keyboard backlight quick toggle
  + Hide popup menu ornaments by default
  + Improve light style variant
  + Add InjectionManager convenience API for extensions
  + Use per-direction labels on ring/strip tablet actions
  + Misc. bug fixes and cleanups
  + Updated translations.
- Add TelepathyGlib to global typelibs exclude.
* Mon Sep  4 2023 Bjørn Lie <bjorn.lie@gmail.com>
- Update to version 45.alpha:
  + Improve background apps menu
  + Complete GTK4 port
  + Use user-defined names in bluetooth menu
  + Improve the built-in screen recorder
  + Remove the app menu
  + Fix stuck authentication dialog in remote sessions
  + Provide generated toolbox images for development
  + Fix glitches in calendar when using large-text option
  + Use icons for ornaments in popup menus
  + Improve calendar styling
  + Fix IM popup getting stuck on engine changes
  + Support color-scheme setting for default stylesheet
  + Remove Soup2 support
  + Expose public functions for search provider registration
  + Updated translations.
- Bump mutter_api 13 and mutter_req 45.alpha following upstream
  changes.
* Mon Sep  4 2023 Bjørn Lie <bjorn.lie@gmail.com>
- Update to version 44.4:
  + Fix accessibility of quick settings sliders.
  + Allow notification dismissal with backspace.
  + Misc. bug fixes and cleanups.
  + Updated translations.
* Thu Jul  6 2023 Bjørn Lie <bjorn.lie@gmail.com>
- Update to version 44.3:
  + Fix cursor offset when using magnifier.
  + Fix missing workspace borders after wallpaper changes.
  + Revert screencast optimization that results in bogus windows.
  + Misc. bug fixes and cleanups.
  + Updated translations.
* Mon Jun  5 2023 Bjørn Lie <bjorn.lie@gmail.com>
- Update to version 44.2:
  + Improve built-in screen recorder
  + Use user-defined names in bluetooth menu
  + Fix stuck authentication dialog in remote sessions
  + Fix glitches in calendar when using large-text option
  + Fix IM popup getting stuck on engine changes
  + Fixed crash
  + Misc. bug fixes and cleanups
  + Updated translations.
* Tue Apr 25 2023 Bjørn Lie <bjorn.lie@gmail.com>
- Update to version 44.1:
  + Add section title in background apps menu.
  + Fix visibility of xembed icons.
  + Fix placeholder alignment in bluetooth menu.
  + Fix recording screenshots in recent items.
  + Fix reloading extensions on version-validation changes.
  + Fix force-enabling animations at runtime.
  + Fix stuck session after logout dialog timeout.
  + Fix window screenshots with pointer.
  + Only show network subtitles if they don't match the title.
  + Fix constructing QuickMenuToggles with icon-name.
  + Fix accessible names in VPN menu.
  + Don't fail extracting extensions without schemas.
  + Fixes and improvements to the light theme variant.
  + Improve accessible name of wireless menu items.
  + Use consistent naming for "Power Mode" toggle.
  + Fix support for transparent colors in symbolic SVGs.
  + Fix notifications getting stuck indefinitely.
  + Fix keynav of menu-less buttons.
  + Fix corner cases when matching apps on StartupWmClass.
  + Fix occasional misalignment of search results.
  + Fix regression in content-type sniffing on autorun.
  + Fix building API documentation.
  + Fixed crash.
  + Plugged leak
  + Misc. bug fixes and cleanups
  + Updated translations.
- Enable gtk_doc passed to meson again, build the docs.
* Thu Apr 20 2023 Bjørn Lie <bjorn.lie@gmail.com>
- Move file wrongly placed in the split out gnome-extensions
  sub-package. There is the gui app and there is the commandline
  binary. These two are destinct from one another.
- Mark patch that needs rebase correctly.
* Thu Apr  6 2023 Xiaoguang Wang <xiaoguang.wang@suse.com>
- Update gnome-shell-private-connection.patch: (bsc#1209373)
* Thu Mar 30 2023 bjorn.lie@gmail.com
- Update to version 44.0+42:
  + appFavorite:
  - Add missing .desktop extension for simplescan
  - Rename simple-scan.desktop
  + style: Light variant fixes and accommodations
  + extensionDownloader: Check schemadir existence and type
  + status/network: Fix a11y names for VPN connection menu items
  + quickSettings: Fix icon-name construct property in menu toggles
  + screenshot: Fix broken GLib.Error.matches call
  + Updated translations.
* Wed Mar 22 2023 bjorn.lie@gmail.com
- Update to version 44.0+28:
  + status/network: Generalize code to hide subtitle
  + screenshot: Get cursor texture from window
  + st/icon-theme: Disconnect from settings signals on disposal
  + workspacesView: Update visibility after updating workspaces
  + screenshot: Use meta_window_has_pointer () for pointer check
  + main:
  - Add missing newlines
  - Fix syncing animations-enabled
  + style: Reduce padding between quick menu toggle text and
    separator
  + modalDialog: Fix fading out dialog
  + endSessionDialog: Catch async errors
  + tests:
  - Set GNOME_SHELL_SESSION_MODE to user
  - Add default test setup with common env settings
  + extension-tool: Set reminder for removing old compat code
  + Updated translations.
- Move patch to SLE only patches:
  + gnome-shell-jscSLE9267-Remove-sessionList-of-endSessionDialog.patch
* Sun Mar 19 2023 Bjørn Lie <bjorn.lie@gmail.com>
- Update to version 44.0:
  + Updated translations.
* Wed Mar  8 2023 Bjørn Lie <bjorn.lie@gmail.com>
- Add Soup to global Requires exclude, and add a manual
  typelib(Soup) = 3.0 Requires. Only require 3.0, before we got a
  dependency on Soup 2.4 as well.
- Add St, Cogl and Clutter typelibs to global Requires exclude
  aswell. These typelibs are provided by multiple packages, but
  currently gnome-shell gets these provided by itself or mutter.
  We already have an explicit mutter requires in place so no more
  changes are needed for now from our end.
- Drop explicit typelib(Rsvg) Requires, no longer needed.
* Mon Mar  6 2023 Bjørn Lie <bjorn.lie@gmail.com>
- Update to version 44.rc:
  + Unmute to default volume when slider was at 0
  + Fix missing battery percentage in the top bar
  + Fix unexpected focus order after activating apps
  + Stop using GTK for systray support
  + Expose GtkIconTheme replacement to extensions
  + Disallow using (most of) GTK in the compositor process
  + Plugged leak
  + Misc. bug fixes and cleanups
  + Updated translations.
- Replace pkgconfig(gnome-desktop-3.0) with
  pkgconfig(gnome-desktop-4) BuildRequires following upstream
  changes.
- Temp disable gtk-doc, fails build atm.
  https://gitlab.gnome.org/GNOME/gnome-shell/-/issues/6486
* Fri Feb 24 2023 Bjørn Lie <bjorn.lie@gmail.com>
- Update to version 44.beta:
  + Fix screencast UI being erroneously disabled
  + Fix unresponsive screen area when quick settings are opened
  + Ensure completions are disabled when hiding on-screen keyboard
  + Fix missing name in wired network quick settings button
  + Properly apply saved shortcuts inhibition permissions
  + Don't let wayland popovers block overview
  + Improve high contrast styling
  + Open correct Settings panel from on-screen keyboard menu
  + Test running gnome-shell in CI
  + Do not use symbolic app icons for High Contrast
  + Prepare extension loading for ESM
  + Fix input source switching with focus on password entry
  + Ensure quick settings toggles align with the pixel grid
  + Lower OOM score of gnome-shell process
  + Polish page switching behavior during DND in app grid
  + Tweak lock- and login screen styling
  + Consistently link to Settings from menus
  + Make it easier for extensions to add a credential manager
  + Fix mount operation dialog when Disks is not available
  + Refine quick settings
  + Mute/unmute volume when clicking slider icon
  + Add device menu to Bluetooth quick settings
  + Expose list of background apps in quick settings
  + Compile extension GSettings after install
  + Fixed crash
  + Plugged memory leak
  + Misc. bug fixes and cleanups
  + Updated translations.
- Replace pkgconfig(libmutter-11), pkgconfig(mutter-clutter-11),
  pkgconfig(mutter-cogl-11) and pkgconfig(mutter-cogl-pango-11)
  with a new mutter_api define and set it to 12. Also add a new
  mutter_req define and set it to 44.beta. Make future versionbumps
  more practical.
- Rebase patches with quilt. Disable
  gnome-shell-exit-crash-workaround.patch for now, should no longer
  be needed + Not sure I trust the rebase quilt did.
- Drop gnome-shell-main-Leak-the-GJS-context-and-ShellGlobal.patch:
  Fixed upstream.
- Add a glob to typelib exclude.
* Tue Feb 14 2023 Bjørn Lie <bjorn.lie@gmail.com>
- Update to version 43.3:
  + Ensure quick settings toggles align with the pixel grid
  + Lower OOM score of gnome-shell process
  + Fix incomplete device list in volume menus
  + Fixed crash
  + Plugged leak
  + Misc. bug fixes and cleanups
  + Updated translations.
* Tue Feb  7 2023 Xiaoguang Wang <xiaoguang.wang@suse.com>
- Update gs-fate318433-prevent-same-account-multi-logins.patch:
  Fix no warning messages (bsc#1207323).
* Sat Dec 10 2022 Bjørn Lie <bjorn.lie@gmail.com>
- Update to version 43.2:
  + Fix screencast UI being erroneously disabled.
  + Properly apply saved shortcuts inhibition permissions.
  + Fix IM candidate popup getting closed when switching pages.
  + Fix unresponsive screen area when quick settings are opened.
  + Ensure completions are disabled when hiding on-screen keyboard.
  + Fix missing name in wired network quick settings button.
  + Don't let wayland popovers block overview.
  + Fix repeated entries in volume device menu.
  + Fix input source switching with focus on password entry.
  + Misc. bug fixes and cleanups.
  + Updated translations.
* Fri Dec  2 2022 Xiaoguang Wang <xiaoguang.wang@suse.com>
- Add gnome-shell-main-Leak-the-GJS-context-and-ShellGlobal.patch:
  Leak the GJS context and ShellGlobal, the patch is from
  https://src.fedoraproject.org/rpms/gnome-shell/tree/rawhide
  (bsc#1205518)
* Fri Nov  4 2022 Bjørn Lie <bjorn.lie@gmail.com>
- Update to version 43.1:
  + Fix default keyboard layout during initial setup.
  + Show Bluetooth switch in more cases.
  + Include origin in sound device switcher.
  + Fix remembering inhibit-shortcut permission for multiple apps.
  + Forward TERMINAL input purpose to ibus.
  + Fix style glitches.
  + Fix tracking of newly installed apps.
  + Fix space key getting stuck in on-screen keyboard.
  + Fix showing passwords as on-screen keyboard suggestions.
  + Fix network portal regression.
  + Fix possible freeze during initialization.
  + Misc. bug fixes and cleanups.
  + Updated translations.
* Fri Oct 28 2022 Milachew <milachew@mail.lv>
- Add gnome-shell-disable-offline-update-dialog.patch :
  Disable offline update suggestion before shutdown/reboot
  in SLE and openSUSE Leap (bsc#944832).
* Sun Sep 18 2022 Bjørn Lie <bjorn.lie@gmail.com>
- Update to version 43.0:
  + Fix rebooting into boot loader menu.
  + Improve entry legibility in GNOME Classic.
  + Fixed crash.
  + Misc. bug fixes and cleanups.
  + Updated translations.
* Mon Sep  5 2022 Dominique Leuenberger <dimstar@opensuse.org>
- Pass -Dtests=false to meson: we build mutter without installed
  tests and thus do not have the deps available for this.
* Mon Sep  5 2022 Bjørn Lie <bjorn.lie@gmail.com>
- Update to version 43.rc:
  + Tweak quick settings appearance
  + Use NM connectivity check URI for portal helper
  + Only show "Night Light" toggle when supported
  + Fix accessibility of quick settings sliders
  + Use more unambiguous icons in on-screen keyboard
  + Add screenshot item to quick settings
  + Fix entering extended characters from on-screen keyboard
  + Prevent SignalTracker from leaking objects
  + Fix turning off VPN in quick settings
  + Fix initial selection in switch-monitor popup on desktop
  + Improve handling of recurring events
  + Indicate transitional states in bluetooth quick toggle
  + Work around pipewire regression for screencasts
  + Plugged memory leak
  + Misc. bug fixes and cleanups
  + Updated translations.
* Mon Aug 29 2022 Bjørn Lie <bjorn.lie@gmail.com>
- Replace pkgconfig(libsoup-2.4) with pkgconfig(libsoup-3.0)
  BuildRequires: gnome-shell already supports soup3.
* Fri Aug 12 2022 Bjørn Lie <bjorn.lie@gmail.com>
- Update to version 43.beta:
  + Allow extension updates with only Extension Manager installed
  + Use new About window in Extensions app
  + Stop auto-dismissing notifications on focus changes
  + Tweak access portal dialog
  + Add device switcher to volume sliders
  + Replace combined system menu with quick settings
  + Use the same format in screencast and screenshot file names
  + Only load extensions that support the current session mode
  + Improve overview animation performance
  + Port to gcr4
  + Fix logging in with realmd
  + Optimize workspace background shadow
  + Improve app grid navigation
  + Improve on-screen keyboard
  - Delete multiple characters and words when holding backspace
  - Provide word suggestions when using plan keyboard layouts
  - Use extended layout when TERMINAL hint is set
  + Fix remembering set up bluetooth devices
  + Misc. bug fixes and cleanups.
  + Updated translations.
- Replace pkgconfig(gcr-base-3) with pkgconfig(gcr-4) BuildRequires
  following upstreams port.
* Fri Aug 12 2022 Dominique Leuenberger <dimstar@opensuse.org>
- Update to version 43.alpha:
  + Add convenience property for icon-only buttons.
  + Align space-padded times in world clock.
  + Fix top bar menus on lock screen.
  + Show wireguard connects in VPN list.
  + Fix on-screen keyboard gestures.
  + Fix focus tracking in magnifier on wayland.
  + Fix OSD colors with light stylesheet.
  + Only close messages via delete key if they can be closed.
  + Fix screenshots when XDG directories are disabled.
  + Do not create systemd scope for D-Bus activated apps.
  + Improve high-contrast stylesheet.
  + Hide overview after 'Show Details' from app context menu.
  + Fix feedback when turning on a11y features by keyboard.
  + Fix stylesheet papercuts.
  + Use libsoup 3.0 by default.
  + Indicate selected language in on-screen keyboard menu.
  + Respect IM hint for candidates list in on-screen keyboard.
  + Fix edge case where windows stay dimmed after a modal is
    closed.
  + Improve Belgian on-screen keyboard layout.
  + Fix fallback ibus-daemon launching.
  + Make sure screenshot UI opens above dialogs.
  + Use EventEmitter class instead of injecting Signal methods.
  + Plugged leak.
  + Misc. bug fixes and cleanups.
* Thu Aug 11 2022 Bjørn Lie <bjorn.lie@gmail.com>
- Update to version 42.4:
  + Fix adding suggestions from on-screen keyboard
  + Allow extension updates with only Extension Manager installed
  + Only load extensions that support the current session mode
  + Fix logging in with realmd
  + Tweak access portal dialog
  + Improve overview animation performance
  + Fix remembering set up bluetooth devices
  + Plugged leak
  + Misc. bug fixes and cleanups
  + Updated translations.
* Wed Jul  6 2022 Dominique Leuenberger <dimstar@opensuse.org>
- Update to version 42.3.1:
  + Fix regression in ibus support.
  + Make sure screenshot UI opens above dialogs.
  + Misc. bug fixes and cleanups.
- Changes from version 42.3:
  + Fix feedback when turning on a11y features by keyboard.
  + Fix OSD colors with light stylesheet.
  + Only close messages via delete key if they can be closed.
  + Fix screenshots when XDG directories are disabled.
  + Do not create systemd scope for D-Bus activated apps.
  + Improve high-contrast stylesheet.
  + Hide overview after 'Show Details' from app context menu.
  + Fix stylesheet papercuts.
  + Respect IM hint for candidates list in on-screen keyboard.
  + Fix edge case where windows stay dimmed after a modal is
    closed.
  + Improve Belgian on-screen keyboard layout.
  + Fix fallback ibus-daemon launching.
  + Misc. bug fixes.
  + Updated translations.
* Mon May 30 2022 Dominique Leuenberger <dimstar@opensuse.org>
- Update to version 42.2:
  + Align space-padded times in world clocks.
  + Fix top bar menus on lock screen.
  + Fix on-screen keyboard gestures.
  + Fix focus tracking in magnifier on wayland.
  + Misc. bug fixes.
* Fri May  6 2022 Frederic Crozat <fcrozat@suse.com>
- Update to version 42.1:
  + Limit unfullscreen gesture to not interfere with overview.
  + Properly hide the second (real) cursor when magnified.
  + Fix various style glitches.
  + Fix creating default application folders.
  + Fix switching monitor configuration.
  + Add Home/End keynav in app grid.
  + Handle monitor changes during startup animation.
  + Fix fractional timezone offsets in world clock.
  + Default to right text-align in RTL locales.
  + calendar: Fix alignment of world clocks header in RTL.
  + Rely on symbolic icons instead of 'HighContrast' icon theme.
  + Fix moving windows from secondary monitor to non-active workspace.
  + Make sure startup animation completes.
  + Fix Swiss on-screen keyboard layouts.
  + Add Austrian-German on-screen keyboard layout.
  + Fix on-screen keyboard in modal dialogs and lock screen.
  + Fix menus in pad OSD.
  + Sync default colors with libadwaita.
  + Fix grab regressions when entering overview.
  + Scale calendar with text size.
  + Allow more intermediate icon sizes in app grid.
  + Fixed crash.
  + Plugged memory leak.
- Remove merged upstream:
  + gnome-shell-42.0-fix-switching-configuration.patch
  + gnome-shell-Pass-cancellable-when-querying-file-info.patch
* Sat Apr 30 2022 Antoine Belvire <antoine.belvire@opensuse.org>
- Add gnome-shell-42.0-fix-switching-configuration.patch: Fix
  monitor switching configuration (glgo#GNOME/gnome-shell#5217).
* Sun Mar 13 2022 Bjørn Lie <bjorn.lie@gmail.com>
- Update to version 42.0:
  + introspect: Add WindowsChanged signal.
  + Fix on-screen keyboard during grabs.
  + Fixed crash.
  + Updated translations.
* Mon Mar  7 2022 Bjørn Lie <bjorn.lie@gmail.com>
- Update to version 42.rc:
  + Fix programatically set scrollview fade.
  + Fix overview DND during screencasts.
  + Fix taking screenshots with shift+PrntScrn.
  + Disable workspace switching while in search.
  + Fix opening device settings for enterprise WPA networks.
  + Switch workspaces with Home and End keys in overview.
  + Fix regressions from style refresh.
  + Show disabled icons in system menu when devices are disabled.
  + Fix inserting items from object inspector in looking glass.
  + Fix drag placeholder position in dash in RTL locales.
  + Simplify signal handling with (dis)connectObject() convenience
    methods.
  + Ensure remote access indicator is shown for a minimum time.
  + Improve CSS shadow appearance.
  + Ignore work area in overview layout.
  + Fix glitches in overview transition.
  + Fixed crash.
  + Misc. bug fixes and cleanups.
  + Updated translations.
- Update patches with quilt.
* Thu Feb 24 2022 bjorn.lie@gmail.com
- Update to version 42.beta+40:
  * overview: Don't expect time argument from drag-end signal
  * workspaceAnimation: Fix warning on restacking
  * cleanup:
  - Use new indentation style for object literals
  - Use new indentation style for arrays
  - Stop using string concatenation
  * status/network:
  - Show disabled icon when bluetooth cellular is disabled
  - Show vpn-disabled icon when vpn is disabled
  - Show cellular-disabled icon when cellular is disabled
  * status/bluetooth: Show bluetooth-disabled icon when disabled
  * Updated translations.
- Drop gnome-shell-fix-NMDevice-get-path.patch: Fixed upstream.
- Rebase patches with quilt.
* Thu Feb 17 2022 Bjørn Lie <bjorn.lie@gmail.com>
- Rebase patches with quilt.
* Thu Feb 17 2022 Xiaoguang Wang <xiaoguang.wang@suse.com>
- Add gnome-shell-fix-NMDevice-get-path.patch: Fix the NMDevice
  get_path is null(bsc#1176553 glgo#GNOME/gnome-shell#4565).
* Tue Feb 15 2022 Bjørn Lie <bjorn.lie@gmail.com>
- Update to version 42.beta:
  + Add Swiss French and Swiss German OSK layouts
  + Add switches for debug flags to looking glass
  + Support auth lists on the login screen
  + Overhaul shell stylesheet
  + Fix timing issue on login screen
  + Fix activating apps with tracked OR windows
  + Fix banding issues with the vignette lightbox shader
  + Implement in-shell screenshot and screencast UI
  + Fix keyboard navigation to windows/apps in overview
  + Adjust to Clutter grab API changes
  + Fix stuck transition when using super-scroll gesture
  + Support the new 'high-contrast' setting
  + Remove rounded top bar corners
  + Fix calendar events with custom timezone
  + Support dark wallpapers
  + Improve terminology for pinning icons to dash
  + Use libadwaita for extension preferences
  + Fix out-of-sync location indicator
  + Fade screen when switching between dark/light mode
  + Improve presentation of multi-day events in calendar
  + Implement Extensions redesign
  + Implement OSD redesign
  + Misc. bug fixes and cleanups
  + Updated translations.
- Replace pkgconfig(gnome-bluetooth-1.0) with
  pkgconfig(gnome-bluetooth-3.0) BuildRequires following upstreams
  port.
- Move patches from openSUSE to SLE/Leap only status:
  + gnome-shell-disable-ibus-when-not-installed.patch
  + gnome-shell-fate324570-Make-GDM-background-image-configurable.patch
  + gnome-shell-jsc#SLE-16051-Input-method-recommendation.patch
* Tue Feb 15 2022 Bjørn Lie <bjorn.lie@gmail.com>
- Drop 2078.patch: Not needed for 42.alpha.
* Tue Feb 15 2022 Bjørn Lie <bjorn.lie@gmail.com>
- Update to version 41.4:
  + Start tracking windows when expected by extensions.
  + Fix timing issue on login screen.
  + Fix lightbox shader compatibility with older drivers.
  + Fix activating apps with tracked OR windows.
  + Fix banding issues with the vignette lightbox shader.
  + Fix keyboard navigation to windows/apps in overview.
  + Fix stuck transition when using super-scroll gesture.
  + Fix calendar events with custom timezone.
  + Fix out-of-sync location indicator.
  + Misc. bug fixes and cleanups.
  + Updated translations.
* Wed Feb  9 2022 Xiaoguang Wang <xiaoguang.wang@suse.com>
- Update gs-fate318433-prevent-same-account-multi-logins.patch:
  Fix the JS ERR: Error: Wrong type number; string expected
  (bsc#1195179 bsc#1195141).
* Tue Feb  8 2022 Bjørn Lie <bjorn.lie@gmail.com>
- Add 2078.patch: Fix build with meson 0.61 and newer.
* Mon Feb  7 2022 Xiaoguang Wang <xiaoguang.wang@suse.com>
- Add gnome-shell-Pass-cancellable-when-querying-file-info.patch:
  Pass cancellable when querying file info
  (bsc#1205518 glgo#GNOME/gnome-shell!2268)
* Thu Jan 27 2022 Yifan Jiang <yfjiang@suse.com>
- Disable gs-fate318433-prevent-same-account-multi-logins.patch:
  temporarily disable it to workaround a regression of remote
  connection (bsc#1195141).
* Wed Jan 12 2022 Dominique Leuenberger <dimstar@opensuse.org>
- Update to version 42.alpha:
  + Fix icon updates while hidden.
  + Fix erratic scrolling in GTK apps.
  + Fix GTK color picker support.
  + Fix sound-file support in notifications.
  + Fix high-contrast switches.
  + Allow extensions to opt-in to running on lock/login screen.
  + magnifier: Avoid offscreen rendering if possible.
  + Warn when unsafe-mode is toggled.
  + Improve handling of all-day/zero-length events in calendar.
  + Keep keyboard focus in notification list after deleting
    message.
  + switchMonitor: Don't include builtin/external modes on
    desktops.
  + Fix wrongly rejected D-Bus calls after gnome-shell restarts.
  + Improve window tracking.
  + Simplify scroll fade shader to work with old hardware.
  + Tweak (un)minimize animations.
  + Properly handle markup when highlighting search terms.
  + Don't wake up screen in DND mode.
  + Port to GWeather 4.0.
  + extensions-app: Use libadwaita.
  + Fix immediately withdrawn notifications getting stuck.
  + Honor XDG SingleMainWindow key in .desktop files.
  + Opt-in to unique GType names in extension prefs.
  + Don't terminate remote sessions in headless mode.
  + Fixed crashes.
  + Misc. bug fixes and cleanups.
  + Updated translations.
* Tue Jan 11 2022 Bjørn Lie <bjorn.lie@gmail.com>
- Update to version 41.3:
  + Improve window tracking
  + Simplify scroll fade shader to work with old hardware
  + Tweak (un)minimize animations
  + Don't wake up screen in DND mode
  + Fix immediately withdrawn notifications getting stuck
  + Honor XDG SingleMainWindow key in .desktop files
  + Fixed crashes
  + Misc. bug fixes and cleanups
  + Updated translations.
- Modernize our Supplements in gnome-shell-calendar sub-package.
* Fri Dec 17 2021 QK ZHU <qkzhu@suse.com>
- Add gnome-shell-exit-crash-workaround.patch:
  + Backport from Ubuntu, This is a workaround to maintain a clean
    environment for gnome-shell and particularly JavaScript/GJS to
    shutdown without crashing.
  + Proper fixes are still pending
    https://gitlab.gnome.org/GNOME/gnome-shell/-/merge_requests/1759
    https://gitlab.gnome.org/GNOME/gnome-shell/-/merge_requests/648
    (bsc#1190878 glgo#GNOME/gnome-shell#4344).
* Wed Dec 15 2021 Xiaoguang Wang <xiaoguang.wang@suse.com>
- Update gs-fate318433-prevent-same-account-multi-logins.patch:
  Show message "Multiple logins are not supported" when mixed
  locally/remotely login(bsc#1190745).
* Mon Dec 13 2021 Bjørn Lie <bjorn.lie@gmail.com>
- Update to version 41.2:
  + Fix wrongly rejected D-Bus calls after gnome-shell restarts.
  + magnifier: Avoid offscreen rendering if possible.
  + Improve handling of all-day/zero-length events in calendar.
  + Keep keyboard focus in notification list after deleting
    message.
  + Misc. bug fixes and cleanups.
  + Updated translations.
- Switch to git checkout of released tag via source service.
* Fri Nov 26 2021 Callum Farmer <gmbr3@opensuse.org>
- Revert last change, turns out this is what breaks locking
  in Budgie desktop
* Fri Nov  5 2021 Callum Farmer <gmbr3@opensuse.org>
- Change to using a boolean dependency Requires for gnome-session
  to allow Budgie-only installation
* Fri Nov  5 2021 Bjørn Lie <bjorn.lie@gmail.com>
- Update to version 41.1:
  + Fix icon updates while hidden
  + Fix erratic scrolling in GTK apps
  + Fix GTK color picker support
  + Fix sound-file support in notifications
  + Fix high-contrast switches
  + Only allow one extension prefs dialog at a time
  + Fixed crashes
  + Misc. bug fixes and cleanups
  + Updated translations.
- Drop 380d2db1d9047ecffcef7d78f00184963b403efc.patch: Fixed
  upstream
* Wed Oct  6 2021 Bjørn Lie <bjorn.lie@gmail.com>
- Add 380d2db1d9047ecffcef7d78f00184963b403efc.patch: inputMethod:
  Clear preeditStr before reset. Previously, these were performed
  in a different order before GNOME 41. During some other changes
  they were swapped.
  However, this causes both GTK 3 and GTK 4 applications to scroll
  to incorrect positions from the preedit change.
* Wed Sep 22 2021 Michael Gorse <mgorse@suse.com>
- Update to version 41.0:
  + Updated translations.
- Up mutter dependency.
* Wed Sep 22 2021 Dominique Leuenberger <dimstar@opensuse.org>
- Update to version 41.rc.1:
  + Make tests optional.
  + Misc. bug fixes.
  + Updated translations.
* Wed Sep 22 2021 Dominique Leuenberger <dimstar@opensuse.org>
- Update to version 41.rc:
  + Optimize rendering of fullscreen zoom.
  + Fix glitchy launch animations when leaving overview.
  + Show low priority notifications only in message list.
  + Support Soup 3 instead of 2.4.
  + Set log domain for extensions that use console.log().
  + Fix wrong separator position in dash.
  + Fix OSK not registering button presses on X11.
  + Fix work area getting messed up by hidden panels.
  + Fix IM candidate popover position.
  + Restrict callers of private D-Bus APIs.
  + Support committing preedit string on focus loss.
  + Misc. bug fixes and cleanups.
  + Updated translations.
* Wed Sep 22 2021 Dominique Leuenberger <dimstar@opensuse.org>
- Update to version 41.beta:
  + Unbreak Xwayland apps when not using systemd in user session.
  + extension-tool: Always print location on successful creation.
  + Fix distributed man pages.
  + Immediately start app grid drags for non-touch devices.
  + Avoid unnecessary icon shadow changes.
  + Handle screencast failures more gracefully.
  + Use symbolic icons in looking glass toolbar.
  + Allow overriding super+number shortcuts in Settings.
  + Don't include hidden search results in keynav.
  + Use anaccelerated deltas in swipe tracker.
  + status/network: Do not disable on login screen.
  + Always take workarea into account when allocating workspaces.
  + location: Split out geoclue agent from indicator.
  + Add focus indication for switches.
  + Honor switch-user lockdown settings in unlock screen.
  + Fix glitch when dragging window preview in overview.
  + Lock down "Show Text" in password entries.
  + Add power mode selection to status menu.
  + workspace: Handle skip-taskbar changes.
  + status/network: Use WWan settings panel for GSM/LTE modems.
  + extensionUtils: Add gettext convenience helpers.
  + screenShield: Fix suspend inhibitor accounting.
  + Unify app context menus.
  + Use consistent terminology in window menu.
  + Fixed crashes.
  + Misc. bug fixes and cleanups.
  + Updated translations.
- Rebase gnome-shell-private-connection.patch.
* Tue Sep 21 2021 Bjørn Lie <bjorn.lie@gmail.com>
- Update to version 40.5:
  + Optimize rendering of fullscreen zoom.
  + Fix glitchy launch animations when leaving overview.
  + Fix wrong separator position in dash.
  + Fix OSK not registering button presses on X11.
  + Fix work area getting messed up by hidden panels.
  + Fix IM candidate popover position.
  + Misc. bug fixes and cleanups.
  + Updated translations.
* Thu Sep 16 2021 Stanislav Brabec <sbrabec@suse.com>
- Remove obsolete translation-update-upstream support
  (jsc#SLE-21105).
* Wed Aug 18 2021 Bjørn Lie <bjorn.lie@gmail.com>
- Update to version 40.4:
  + Don't include hidden search results in keynav.
  + Always take workarea into account when allocating workspaces.
  + Add focus indication for switches.
  + Fix glitch when dragging window preview in overview.
  + workspace: Handle skip-taskbar changes.
  + screenShield: Fix suspend inhibitor accounting.
  + Fixed crash.
  + Misc. bug fixes and cleanups.
  + Updated translations.
* Mon Aug 16 2021 Michael Gorse <mgorse@suse.com>
- Remove libcroco from BuildRequires: the relevant sources are now
  included directly in the gnome-shell tarball.
* Tue Aug 10 2021 Xiaoguang Wang <xiaoguang.wang@suse.com>
- Add gnome-shell-executable-path-not-absolute.patch: Fix ExecStart
  is not absolute path. ExecStart can use related path in high
  systemd version. The current systemd version in SLE-15-SP2
  should use absolute path (bsc#1176051 bsc#1188960).
* Mon Aug  2 2021 Yifan Jiang <yfjiang@suse.com>
- Drop patches fixed upstream:
  + gnome-shell-network-agent-not-pop-up.patch
  + gnome-shell-jscSLE16518-update-subprojects-libgvc.patch
  + gnome-shell-CVE-2020-17489.patch
* Wed Jul 21 2021 Xiaoguang Wang <xiaoguang.wang@suse.com>
- Drop gnome-shell-lock-bg-on-primary.patch: the
  gnome-shell-1007468-lock-screen-SUSE-logo-missing.patch has been
  removed, we don't need this patch now(bsc#1188533).
* Tue Jul 13 2021 Bjørn Lie <bjorn.lie@gmail.com>
- Update to version 40.3:
  + Fix glitch in app grid → session transition.
  + Fix IM popup visibility when in fullscreen.
  + magnifier: Fix view jumps when using caret tracking.
  + Fix shadow rendering glitches.
  + Fix vertical scrollbars in RTL locales.
  + Fixed crash.
  + Misc. bug fixes and cleanups.
  + Updated translations.
- Drop gnome-shell-session-launch-timeout.patch: Fixed upstream.
* Tue Jun 15 2021 Dominique Leuenberger <dimstar@opensuse.org>
- Update gnome-shell-session-launch-timeout.patch: Use the version
  proposed by upstream elminating the timeout alltogether.
* Mon Jun 14 2021 Dominique Leuenberger <dimstar@opensuse.org>
- Add gnome-shell-session-launch-timeout.patch: give the X11
  session components more time to launch.
* Fri Jun 11 2021 Bjørn Lie <bjorn.lie@gmail.com>
- Update to version 40.2:
  + Unbreak Xwayland apps when not using systemd in user session.
  + Fix distributed man pages.
  + Avoid unnecessary icon shadow changes.
  + Immediately start app grid drags for non-touch devices.
  + Handle screencast failures more gracefully.
  + Fixed crashes.
  + Misc. bug fixes.
  + Updated translations.
- Changes from version 40.1:
  + Fix keyboard preview for IM that use 'default' layout.
  + extensions: Fix copying technical details on prefs crash.
  + Make window previews as large as possible.
  + Fix PgUp/PgDown handling in overview.
  + Fix scroll view following keyboard focus.
  + Fix word suggestions in on-screen keyboard.
  + Support animated backgrounds set via the wallpaper portal.
  + Fix freeze after cancelling (some) system-modal dialogs.
  + Support double-super when animations are disabled.
  + gdm: Allow timed login with disabled user list.
  + status: Report real battery percentage when full.
  + Allow tap-drag-release to select variants in OSK.
  + Fix password authentication after fingerprint failure.
  + Fix screen blanking on idle.
  + Fix oversized system action icons in search.
  + Only show 'Open Windows' in app menus if there are multiple.
  + Fix duplicated workspaces in minimap.
  + Fix repeated letters in type-to-find overview search.
  + Improve workspace placeholder in overview minimap.
  + screencasts: Improve default gstreamer pipeline.
  + Leave overview when activating app via shortcut.
  + Fix invisible scroll bars in faded views.
  + Correct arrow navigation in alt-tab switcher in RTL locales.
  + Improve touch interaction of app grid actions.
  + Fixed crashes.
  + Misc. bug fixes and cleanups.
  + Updated translations.
* Tue Apr  6 2021 QK ZHU <qkzhu@suse.com>
- Rebase patches, the following patches are rebased to version
  40.0:
  + gnome-shell-domain.patch
  + gnome-shell-gdm-login-applet.patch
  + gnome-shell-jscSLE9267-Remove-sessionList-of-endSessionDialog.patch
  + gnome-shell-lock-bg-on-primary.patch
  + gnome-shell-screen-disappear.patch
  + gs-fate318433-prevent-same-account-multi-logins.patch
- Drop 2 patches, lock screen redesigned in version 3.36 or later:
  + gnome-shell-864872-unlock-by-mouse-motion.patch
  + gnome-shell-1007468-lock-screen-SUSE-logo-missing.patch
    (bsc#1184102).
* Sun Mar 21 2021 Cliff Zhao <qzhao@suse.com>
- Update gnome-shell-jsc#SLE-16051-Input-method-recommendation.patch:
  fix (boo#1183823).
* Sat Mar 20 2021 Dominique Leuenberger <dimstar@opensuse.org>
- Update to version 40.0:
  + Updated translations.
* Fri Mar 19 2021 Dominique Leuenberger <dimstar@opensuse.org>
- Disable
  gnome-shell-jsc#SLE-16051-Input-method-recommendation.patch:
  Clears existing keyboard on gnome-shell restart (boo#1183823).
* Wed Mar 17 2021 Dominique Leuenberger <dimstar@opensuse.org>
- Update to version 40.rc:
  + Define default app grid arrangement.
  + Fix shading behind system modal dialogs.
  + Only show logout-inhibiting apps in end-session dialog.
  + Fix minimap previews on multi-monitor systems.
  + Drop strict extension version match for unstable releases.
  + Fix missing app menu after overview gesture.
  + Improve app folder appearance.
  + Fix window previews becoming undraggable after workspace
    switch.
  + Fix dragging icons to a different page in RTL locales.
  + Support double super for opening app grid.
  + Improve workspace handling on secondary monitors.
  + Improve interaction when dragging between app grid pages.
  + Fix launching on requested workspace on wayland.
  + Make wifi strength indicator consistent with icons in Settings.
  + Start session in overview.
  + Tweak window preview layout in overview.
  + Improve overview performance.
  + Fix new workspaces being invisible in minimap.
  + Fix glitch after dragging window preview from second monitor.
  + Do not switch workspaces when scrolling during super-tab.
  + Make OSK shifting up windows more reliable.
  + Fix swipe gesture glitches.
  + Fix mis-scaled preview icons in window picker.
  + Fix unintended app grid changes during icon DND in dash.
  + Fix missing X11 fallback icons.
  + Fixed crashes.
  + Misc. bug fixes and cleanups.
  + Updated translations.
- Rebase
  gnome-shell-fate324570-Make-GDM-background-image-configurable.patch.
* Wed Mar 17 2021 Cliff Zhao <qzhao@suse.com>
- Update gnome-shell-jsc#SLE-16051-Input-method-recommendation.patch:
  Modify the Japanese input engine load order which will more fit
  for our community(bnc#1183475);
* Tue Feb 23 2021 Dominique Leuenberger <dimstar@opensuse.org>
- Update to version 40.beta:
  + Overview redesign:
  - Move dash to the bottom.
  - Do not duplicate dash icons in app grid.
  - Separate favorites from running apps in dash.
  - Change to a horizontal workspace layout.
  - Move background to workspaces.
  - Overhaul window preview style.
  - Rework workspace switching animation.
  - Show workspace side-by-side.
  - Allow switching workspaces with super+scroll on wayland.
  - Allow swiping through more than one workspace at a time.
  - Extend active dash area to the screen edge.
  - Change overall overview layout.
  - Refine workspace activation in overview.
  - Add vertical swipe gesture to shift through overview>
  - Add shortcuts for shifting through overview.
  - Round background corners in overview.
  - Hide workspace minimap when using less than two workspaces.
  - Scale down backgrounds in window picker.
  - Minor improvements and bug fixes.
  + Fix glitch in app folder icons on smaller displays.
  * Remove arrows from top bar menus.
  * Fix stuck grab after failed area screenshots.
  * Prefer image-data hint over app-icon in notifications>
  * Fix drag actor position when animations are turned off.
  * Improve spacing in MPRIS notifications with small text.
  * Add Welcome dialog after major updates.
  * Do not save empty commands in run dialog history.
  * Consider device type for fingerprint hint on login screen.
  * Add tooltip to Extensions app to view unellipsized description.
  * Fix stuck polkit dialog when using non-password auth.
  * Provide screenshot feedback (flash, shutter) before writing
    file to disk.
  * Improve Thai layout in on-screen keyboard.
  * Improve error handling for fingerprint auth.
  * Handle a large number of window previews more gracefully.
  * Follow swipe gesture when bringing up on-screen keyboard.
  * Disable out-of-date extensions by default (again).
  * Fixed crashes.
  * Misc. bug fixes and cleanups.
  + Updated translations.
* Sat Jan 23 2021 Dominique Leuenberger <dimstar@opensuse.org>
- Update to version 40.alpha.1.1:
  + Adapt to settings moving to gsettings-desktop-schemas.
  + Misc. bug fixes.
  + Updated translations.
* Fri Jan 15 2021 Dominique Leuenberger <dimstar@opensuse.org>
- Update to version 40.alpha.1:
  + Restore app picker fade during swipes.
  + Sort extensions in Looking Glass alphabetically.
  + Fix screenshots of unredirected fullscreen windows on X11.
  + Use GPU to render (most) shadows.
  + Refine avatar styling.
  + Fix storing VPN secrets.
  + Don't depend on asciidoc and sassc when building from tarball.
  + Use horizontal pages in app picker.
  + Avoid costly icon theme lookups unless when needed.
  + Properly expose locked state to logind.
  + Use 3 fingers for system swipe gestures.
  + Fix glitches in overview transitions.
  + Improve login screen accessibility.
  + Overhaul top bar styling.
  + Allow changing input volume by scrolling over microphone icon.
  + Port Extensions app and portal to GTK4.
  + Fixed crashes.
  + Misc. bug fixes and cleanups.
- Add pkgconfig(gtk4) BuildRequires: new dependency. NOTE:
  currently, there are indeed GTK3 AND GTK4 required.
* Fri Jan 15 2021 Dominique Leuenberger <dimstar@opensuse.org>
- Update to version 40.alpha:
  + Handle @content properties in ease() functions.
  + Fix screencast indicator on Xorg.
  + Expand ellipsized app picker labels on hover.
  + Fix inline-replies in chat notifications.
  + Refine MPRIS notification layout.
  + Improve do-not-disturb support.
  + Fix mobile broadband support.
  + Add extension filtering in Extensions app.
  + Improve app picker spacing on larger resolutions.
  + Plugged leaks.
  + Fixed crashes.
  + Updated translations.
* Thu Jan 14 2021 Dominique Leuenberger <dimstar@opensuse.org>
- Update to version 3.38.3:
  + Fix disappearing app grid.
  + Fix screenshots of unredirected fullscreen windows on X11.
  + Fix storing VPN secrets.
  + Fix glitches in overview transitions.
  + Improve login screen accessibility.
  + Fixed crashes.
  + Misc. bug fixes and cleanups.
  + Updated translations.
* Mon Jan 11 2021 Cliff Zhao <qzhao@suse.com>
- Add gnome-shell-jsc#SLE-16051-Input-method-recommendation.patch:
  launch recommended input engines when Gnome-shell init in CJK
  regions (jsc#SLE-16051, glgo#GNOME/gnome-shell!1563).
* Tue Dec 29 2020 Dominique Leuenberger <dimstar@opensuse.org>
- Re-enable gnome-shell-private-connection.patch: it was rebased
  back in October, but not enabled (boo#1180230).
* Tue Dec 29 2020 Bjørn Lie <bjorn.lie@gmail.com>
- Add missing pkgconfig(libpipewire-0.3) BuildRequires and
  gstreamer-plugin-pipewire Requires, needed now to build the
  screen-cast support.
* Thu Dec  3 2020 Bjørn Lie <bjorn.lie@gmail.com>
- Update to version 3.38.2:
  + Handle @content properties in ease() functions.
  + Fix screencast indicator on Xorg.
  + Fix inline-replies in chat notifications.
  + Improve do-not-disturb support.
  + Fix mobile broadband support.
  + Improve app picker spacing on larger resolutions.
  + Plugged leaks.
  + Fixed crashes.
  + Misc. bug fixes and cleanups.
  + Updated translations.
- Drop 98234acd5b48a58c2d112b5edb3dddb85e04a643.patch: Fixed
  upstream.
* Fri Oct 23 2020 Marcus Rueckert <mrueckert@suse.de>
- Fix crash which can be triggerd with steam or claws mail:
  https://gitlab.gnome.org/GNOME/gnome-shell/-/commit/98234acd5b48a58c2d112b5edb3dddb85e04a643.patch
* Fri Oct 23 2020 Xiaoguang Wang <xiaoguang.wang@suse.com>
- Add gnome-shell-CVE-2020-17489.patch: reset auth prompt on vt
  switch before fade in in loginDialog
  (bsc#1175155 glgo#GNOME/gnome-shell!1377 CVE-2020-17489).
* Mon Oct 12 2020 QK ZHU <qkzhu@suse.com>
- Add gnome-shell-jscSLE16518-update-subprojects-libgvc.patch:
  Update libgvc to revision 7a621180. This update is necessary to
  add support for recent UCM related changes in ALSA and PulseAudio
  (jsc#SLE-16518, glgo#GNOME/gnome-shell!1444).
* Thu Oct  8 2020 dimstar@opensuse.org
- Update to version 3.38.1:
  + Add screen recordings to recent items.
  + Tweak peek-password feature.
  + Fix workspace glitches in overview.
  + Improve DND behavior in app picker.
  + Misc. bug fixes and cleanups.
  + Updated translations.
- Enable gtk-doc building again.
* Thu Oct  8 2020 dimstar@opensuse.org
- Update to version 3.38.0:
  + Misc. bug fixes and cleanups.
  + Updated translations.
* Thu Oct  8 2020 dimstar@opensuse.org
- Update to version 3.37.92:
  + Fix screen recorder shortcut.
  + Support cycle-group cycling only over windows in the workspac3.
  + Misc bugfixes and cleanups.
  + Updated translations.
* Thu Oct  8 2020 Michael Gorse <mgorse@suse.com>
- Rebase gnome-shell-private-connection.patch.
* Thu Oct  8 2020 dimstar@opensuse.org
- Update to version 3.37.91:
  + Fix potential stack overflow in libcroco.
  + Fix page removal in app picker.
  + Fix "old style" VPN authentication.
  + Fix X11 session login.
  + Fix week number alignment when using font-scaling.
  + Fix lock screen on systems without GLSL shader support.
- Changes from version 3.37.90:
  + Fix extension updates when many extensions are installed.
  + Fix missing icons in on-screen keyboard.
  + Fix delay when showing calendar events.
  + Allow rearranging items in app picker.
  + Fix top bar navigation when NumLock is active.
  + Delay login animation until wallpaper has loaded.
  + Reset auth prompt on login screen on VT switch before fade in.
  + Move screencasting into a separate service.
  + Replace loaded terms with more descriptive one.
  + Add "Boot Options" support to restart dialog.
  + Move "Restart" into a separate menu item/dialog.
  + Default to not installing updates on low battery.
- Changes from version 3.37.3:
  + Refactor and clean up window picker.
  + Move calendar events out of notifications list.
  + Refine app folder dialogs.
  + Hide switch-user button on lock screen if unsupported.
  + Refactor and clean up app picker pagination.
  + Add API to retrieve specified mimetypes from clipboards.
  + Support prepending workspace with horizontal layouts.
  + Update microphone icon on input volume changes.
  + Cache labels on GPU.
  + Fix regressions in redesigned modal dialogs.
  + Use GIcon for all application icons.
  + Support pre-authenticated logins in vmware environments.
  + Better support sandboxed apps with multiple .desktop files.
  + Fix on-screen keyboard size in portrait orientation.
- Changes from version 3.37.2:
  + Add support for "PrefersNonDefaultGPU" desktop key.
  + Only start systemd units when running under systemd.
  + Fix "ghost" media controls.
  + Fix zombie sockets from extensions downloader.
  + Update world clocks offsets when timezone changes.
  + Support scrolling anywhere in slider menu items.
  + Fix "Do Not Disturb" setting getting reset on startup.
  + Only allow updates for extensions that aren't cached.
  + Fix matching notifications by PID.
  + Indicate extension errors in Extensions app.
  + Add clipboard API for querying supported mimetypes.
  + Add preview to color picker.
  + Improve world clocks styling.
  + Remove Frequent view from app picker.
  + Fix pad OSD glitches.
  + Expose actor tree in looking glass.
- Changes from version 3.37.1:
  + Improve bluetooth submenu title.
  + Add openPrefs() convenience method for extensions.
  + Bring back support for empty StIcons.
  + Wake up screen when unlocking programmatically.
  + Improve extensions tool error reporting.
  + Improve handling of scale-factor changes.
  + Tone down weekend days with events in calendar.
  + Fix showing bluetooth submenu when devices were set up.
  + Add support for parental controls filtering.
  + Provide alternative extension templates.
  + Improve weather section's empty state.
  + Fix translations of folder names>
  + Fix delay on lock screen after entering wrong password.
  + Inhibit remote access when disabled by session mode.
  + Improve calendar-server performance.
  + Add gnome-shell-extension-prefs wrapper for compatibility.
  + Fix stuck lock screen after unlock.
  + Updated translations.
- Drop gnome-shell-Get-resource-scale-by-get_resource_scale.patch:
  fixed upstream.
- Do not apply gnome-shell-private-connection.patch: needs rebase.
- Disable gtk-doc building: failure to build in this beta.
* Wed Oct  7 2020 Bjørn Lie <bjorn.lie@gmail.com>
- Update to version 3.36.7:
  + Fix potential stack overflow in libcroco (CVE-2020-12825).
  + Fix system action search regressions.
  + Fix week number alignment when using font-scaling.
  + Misc. bug fixes and cleanups.
  + Updated translations.
* Sun Sep 13 2020 QK ZHU <qkzhu@suse.com>
- Update gnome-shell-fate324570-Make-GDM-background-image-configurable.patch:
  Bring noise-texture.png back which will be used as the default
  value of org.gnome.desktop.background.lockdialog picture-uri
  (boo#1176418).
* Thu Sep 10 2020 Xiaoguang Wang <xiaoguang.wang@suse.com>
- Move branding image file to branding-SLE package
  (jsc#SLE-11720 bsc#1176304).
  + Update gnome-shell-1007468-lock-screen-SUSE-logo-missing.patch
  + Remove sle-background.png
* Tue Sep  8 2020 Bjørn Lie <bjorn.lie@gmail.com>
- Update to version 3.36.6:
  + Fix lock screen on systems without GLSL shader support.
  + Fix app icon scaling regression on HiDPI displays.
  + Updated translations.
* Wed Aug 12 2020 Bjørn Lie <bjorn.lie@gmail.com>
- Update to version 3.36.5:
  + Fix extension updates when many extensions are installed.
  + Fix missing icons in on-screen keyboard.
  + Fix delay when showing calendar events.
  + Fix app picker regressions on small displays.
  + Fix top bar navigation when NumLock is active.
  + Delay login animation until wallpaper has loaded.
  + Revert changes that caused mispositioning in overview in
    multi-monitor setups.
  + Reset auth prompt on login screen on VT switch before fade in.
  + Fix stuck grab when destroying open popup menu.
  + Misc. bug fixes and cleanups.
  + Updated translations.
* Fri Aug  7 2020 QK ZHU <qkzhu@suse.com>
- Update gnome-shell-fate324570-Make-GDM-background-image-configurable.patch:
  to be compatible with 3.36 (boo#1172826).
* Thu Jul 16 2020 Bjørn Lie <bjorn.lie@gmail.com>
-  Update to version 3.36.4+3:
  + Fix check for updates with several extensions.
  + Tighten sandbox ID prefix check.
  + Updated translations.
* Mon Jul 13 2020 Xiaoguang Wang <xiaoguang.wang@suse.com>
- Update gnome-shell.spec: Replace is_opensuse with sle_version
  (jsc#SLE-11720).
* Thu Jul  9 2020 Xiaoguang Wang <xiaoguang.wang@suse.com>
- Add gnome-shell-network-agent-not-pop-up.patch: Fix network agent
  doesn't pop up (bsc#1171822).
* Wed Jul  8 2020 Bjørn Lie <bjorn.lie@gmail.com>
- Update to version 3.36.4:
  + Hide switch-user button on lock screen if unsupported.
  + Improve world clocks styling.
  + Improve calendar-server performance.
  + Fix regressions in redesigned modal dialogs.
  + Better support sandboxed apps with multiple .desktop files.
  + Fix on-screen keyboard size in portrait orientation.
  + Support scrolling anywhere in slider menu items.
  + Fixed crash.
  + Plugged leaks.
  + Misc. bug fixes and cleanups.
  + Updated translations.
- Drop patch fixed upstream:
  + gnome-shell-disable-screensaver-user-switch-when-remote.patch
* Thu Jun 11 2020 QK ZHU <qkzhu@suse.com>
- Add gnome-shell-disable-screensaver-user-switch-when-remote.patch:
  This patch will set the button invisible when the user's can_switch
  is false (e.g. when the session is remote) or user-switch-enabled is
  disabled (bsc#1167276 glgo#GNOME/gnome-shell!1215).
* Thu Jun  4 2020 Bjørn Lie <bjorn.lie@gmail.com>
- Update to version 3.36.3:
  + Add gnome-shell-extension-prefs wrapper for compatibility.
  + Fix distorted fallback icons in top bar.
  + Lower timeout for scrolling in overview.
  + Only start systemd units when running under systemd.
  + Fix "ghost" media controls.
  + Fix zombie sockets from extensions downloader.
  + Update world clocks offsets when timezone changes.
  + Fix "Do Not Disturb" setting getting reset on startup.
  + Fix pad OSD glitches.
  + Fix matching notifications by PID.
  + Only allow updates for extensions that aren't cached.
  + Fixed various crashes.
  + Misc. bug fixes and cleanups.
  + Updated translations.
- Drop gnome-shell-panel-center-app-icon.patch: Fixed upstream.
* Wed Jun  3 2020 Xiaoguang Wang <xiaoguang.wang@suse.com>
- Update gnome-shell-private-connection.patch: Remove JS error in
  messages log when NetworkManager is not installed (bsc#1172424).
* Thu May  7 2020 Bjørn Lie <bjorn.lie@gmail.com>
- Add gnome-shell-panel-center-app-icon.patch: panel: Center app
  icon. Giving the icon extra space may distort it, so center it
  vertically.
* Thu May  7 2020 Stasiek Michalski <stasiek@michalski.cc>
- Move gnome-extensions to seperate package since gnome-software
  allows to uninstall the package causing gnome-shell to be
  uninstalled with it
* Thu Apr 30 2020 Bjørn Lie <bjorn.lie@gmail.com>
- Update to version 3.36.2:
  + Add openPrefs() convenience method for extensions.
  + Bring back support for empty StIcons.
  + Wake up screen when unlocking programmatically.
  + Improve handling of scale-factor changes.
  + Fix translations of folder names.
  + Fix delay on lock screen after entering wrong password.
  + Match ASCII alternatives of system actions.
  + Tone down weekend days with events in calendar.
  + Fix area screenshots on multi-monitor systems.
  + Fix stuck lock screen after unlock.
  + Fixed crashes.
  + Misc. bug fixes and cleanups.
  + Updated translations.
* Sun Apr 26 2020 Xiaoguang Wang <xiaoguang.wang@suse.com>
- Add gnome-shell-Get-resource-scale-by-get_resource_scale.patch:
  To remove 'Getting invalid resource scale property' warnings in
  the log(bsc#1169845 glgo#GNOME/gnome-shell!1206).
* Wed Apr 22 2020 Dominique Leuenberger <dimstar@opensuse.org>
- License: GPL-2.0-or-later AND LGPL-2.1-or-later AND
  GPL-3.0-or-later.
* Thu Apr  9 2020 Xiaoguang Wang <xiaoguang.wang@suse.com>
- Update gnome-shell-disable-ibus-when-not-installed.patch: Remove
  error in journal log(bsc#1169029).
* Wed Apr  1 2020 bjorn.lie@gmail.com
- Update to version 3.36.1:
  + Improve app folders.
  + Fix launching ibus daemon.
  + Do not shutdown ibus/xsettings on X11 compositor restart.
  + Hide hint text in entries when preedit is used.
  + Do not load app infos on main thread.
  + Don't expose FDO Notifications interface on main bus name.
  + Fix icon of mobile broadband connections.
  + Fix high-contrast/symbolic icon mix-up.
  + Don't ellipsize times in world clock.
  + Only check for extension updates if there are any extensions.
  + Fix crash when trying to update removed extensions.
  + Make Extensions app available as flatpak.
  + Display fractional timezones as hours:minutes.
  + Fix assigning pad keybindings.
  + Handle embedded newlines in lock screen notifications.
  + Fix OSK layout fallback for unsupported variants.
  + Do not apply text color to color glyphs (emojis).
  + Check "Install pending software updates" by default.
  + Do not warn about missing GDM on each login.
  + Fix telepathy chat notifications.
  + Fix offline updates support in end session dialog.
  + Fix activating notifications by keyboard.
  + Remove handling of 'blacklisted' extensions.
  + Only update extensions if Extensions app is installed.
  + Improve Norwegian on-screen-keyboard layout.
  + Fix IM support for deleting surrounding text.
  + Fix blur effect with fractional scaling.
  + Use better location name in weather section.
  + Fix glitch in sound feedback on volume changes.
  + Fix on-screen keyboard regressions.
  + Improve screen-reader support.
  + Fix password entry resize on login/lock screen.
  + Fix crash when opening app picker.
  + Misc. bug fixes and cleanups.
  + Updated translations.
- Drop gnome-shell-fix-nb-osk-layout.patch: Fixed upstream.
- Add pkgconfig(bash-completion) BuildRequires: New dependency.
* Wed Apr  1 2020 Bjørn Lie <bjorn.lie@gmail.com>
- Disable patches needing rebase:
  + gnome-shell-fate324570-Make-GDM-background-image-configurable.patch
  + gnome-shell-jscSLE9267-Remove-sessionList-of-endSessionDialog.patch
* Wed Apr  1 2020 bjorn.lie@gmail.com
- Update to version 3.36.0:
  + Fix off-by-1900 error in date conversions.
  + Fix crash on startup with topIcons* extension enabled.
  + Don't require gsd-xsettings for X11 support on wayland.
  + Fix ibus support in Xorg session.
  + Improve Extensions D-Bus API.
  + Allow session modes to specify alternative resource name.
  + Fix link to location settings in aggregate menu.
  + Fix illegible app folder titles with light theme.
  + Really fix visual glitch in sliders.
  + Updated translations.
* Wed Apr  1 2020 Bjørn Lie <bjorn.lie@gmail.com>
- Add gnome-shell-fix-nb-osk-layout.patch: Fix Norwegian Bokmål osk
  layout (glgo#GNOME/gnome-shell!1073).
* Wed Apr  1 2020 Dominique Leuenberger <dimstar@opensuse.org>
- Update to version 3.35.92:
  + Plug a memory leak.
  + Fix missing "back" button on login screen.
  + Fix width of window preview titles in overview.
  + Fix looking glass text with light style variant.
  + Center unlock entry.
  + Hide overlay scrollbars in notification popup.
  + Work around add_actor() slowness in icon spring animation.
  + Add disable-animations heuristics.
  + Fix visual glitches in on-screen keyboard.
  + Fix clearing changed textures from cache.
  + Fix visual glitch in sliders.
  + Stop using dedicated lock screen background.
  + Fix entries disappearing after authentication errors.
  + Fix crash when animations are disabled.
  + Fix passing pointer events to clients when magnified.
  + Fix keynav on new lock screen.
  + Avoid short-lived allocations on actor removal.
  + Fix super-sized default avatars in user list.
  + Leave overview when locking the screen.
  + Hide message list on login screen.
  + Avoid IO on the main thread.
  + Fix window animations getting stuck when client doesn't respond.
  + Only subscribe to touchpad events for touchpad gestures.
  + Start X11 session services before Xwayland clients.
  + Only show switch-user button with unlock prompt.
  + Misc. bug fixes and cleanups.
  + Updated translations.
* Wed Apr  1 2020 Dominique Leuenberger <dimstar@opensuse.org>
- Rebase and re-enable
  gnome-shell-jscSLE9267-Remove-sessionList-of-endSessionDialog.patch.
* Wed Apr  1 2020 dimstar@opensuse.org
- Update to version 3.35.91:
  + Improve magnifier.
  + Only enable OSK automatically if touch-mode is enabled.
  + Merge screen shield and unlock dialog to new lock screen.
  + Improve ShellBlur effect.
  + Adapt user avatar for new lock screen.
  + Animate prompt transition on lock screen.
  + Reduce font-size in dialog titles if text doesn't fit.
  + Various lock screen improvements and bug fixes.
  + Misc. bug fixes and cleanups.
* Wed Apr  1 2020 dimstar@opensuse.org
- Update to version 3.35.90:
  + Update default favorite apps.
  + Add Shell.Blur effect.
  + Overhaul scroll/swipe gestures.
  + Fix VPN connections when delaying request.
  + Overhaul theme.
  + Improve visual appearance of Weather integration.
  + Implement new system dialog designs.
  + Animate position changes of app icons.
  + Add St.Viewport.
  + Make app folders behave as dialogs.
  + Add do-not-disturb functionality to calendar popup.
  + Show hint actor in focused entries.
  + Switch screen-recorder back to VP8.
  + Allow to run perf-tool as wayland compositor.
  + Handle extension updates.
  + Animate showing and hiding caps-lock warning.
  + Support "auto" lengths in CSS.
  + Turn extension-prefs into the offical Extensions app.
  + Sandbox the portal helper.
  + Misc. bug fixes and cleanups.
- Changes from version 3.35.3:
  + Add discrete GPU support for NVidia drivers.
  + Fix DND of window previews with tablet devices.
  + Update pad OSD actions dynamically on mode changes.
  + st: Add dedicated PasswordEntry widget.
  + Allow stand-alone builds of gnome-extensions tool.
  + extension-tool: Don't treat missing .js handler as error.
  + Disallow top bar menus without top bar.
  + Misc. bug fixes and cleanups.
- Changes from version 3.35.2:
  * Fix unredirection after cancelled animations.
  * Include shadow in window screenshots.
  * Show indicator when microphone is active.
  * Wiggle login/unlock password entries on failure.
  * Use correct timezones for events.
  * Use font from interface settings.
  * Add back sound feedback when scrolling volume indicator.
  * Enable clean session shutdown after gnome-shell failure.
  * Fixed crashes.
  * Misc. bug fixes and cleanups.
- Rebase
  gnome-shell-fate324570-Make-GDM-background-image-configurable.patch.
- Disable
  gnome-shell-jscSLE9267-Remove-sessionList-of-endSessionDialog.patch:
  needs rebase.
- Update BuildRequires to mutter libraries to new api version 6,
  and explicitly require libmutter-6-0.
- Disable
  gnome-shell-fate324570-Make-GDM-background-image-configurable.patch:
  needs rebase.
* Wed Apr  1 2020 bjorn.lie@gmail.com
- Update to version 3.34.5:
  + Leave overview when locking the screen.
  + Avoid IO on the main thread.
  + Fix OSK layout fallback for unsupported variants.
  + Fix high-contrast/symbolic icon mix-up.
  + Misc. bug fixes and cleanups.
  + Updated translations.
- Switch to using explicit released tag in _service.
* Mon Mar  9 2020 QK ZHU <qkzhu@suse.com>
- Drop gnome-shell-Avoid-loginDialog-grab-focus-when-locked.patch:
  This patch will steal the mouse focus of the gdm greeter, drop
  it to be aligned with upstream, let the first/only user entry of
  gdm to be selected by default, and the bug the patch fixed can not
  be reproduced in GNOME3.34 (bsc#1164856).
- Rebase gs-fate318433-prevent-same-account-multi-logins.patch and
  gnome-shell-domain.patch.
* Thu Feb 27 2020 dimstar@opensuse.org
- Update to version 3.34.4+4:
  * shell: fix typo in comment
  * global: force fsync() to worker thread when saving state
  * overview: Hide the overview on session mode hasOverview changes
  * closeDialog: Make dialog inactive while fading out
* Sun Feb 16 2020 Bjørn Lie <bjorn.lie@gmail.com>
- Update to version 3.34.4:
  + Switch screen-recorder back to VP8.
  + Updated translations.
* Sun Jan  5 2020 bjorn.lie@gmail.com
- Update to version 3.34.3+0:
  * Bump verion to 3.34.3
* Mon Dec 30 2019 Frederic Crozat <fcrozat@suse.com>
- Update BuildRequires for latest release of gnome-desktop-3
  to get systemd scope support for launched applications.
- Update BuildRequires to mutter libraries >= 3.34.0 and
  gsettings-desktop-schemas >= 3.33.1.
* Fri Dec 27 2019 dimstar@opensuse.org
- Update to version 3.34.2+2:
  * polkitAgent: Only set key focus to password entry after opening dialog
* Tue Dec 24 2019 dimstar@opensuse.org
- Update to version 3.34.2+1:
  * keyboard: Stop accessing deprecated actor property
* Fri Dec 13 2019 dead_mozay@opensuse.org
- Update to version 3.34.2+0:
  * popupMenu: Close when a system modal pops up
  * switcherPopup: Dismiss when a system modal dialog opens
  * weather: Only require auto-location authorization if sandboxed
  * util: Place spawned processes into a systemd scope
  * shell-global: Place launched applications into a systemd scope
  * Update Malay translation
  * closeDialog: Fix scale of dialog for x11 clients in Wayland sessions
  * switcherPopup: Fix scrollable check
  * calendar-server: Use correct timezone for all-day events
  * theme: Add light styling to message buttons
  * Update Chinese (Taiwan) translation
  * appIcon: Draw running dot above the overview icon
  * texture-cache: Remove also scaled keys from the cache
  * data: Enable clean session shutdown after gnome-shell failure
  * extensionSystem: Create a file to flag that extensions are being loaded
  * extensions-tool: Fix removing from settings list
  * introspect: Fix whitelist check
  * theme: Add :active styling to message-close and media control buttons
  * theme: Add message close button styling
  * theme: Darken hovered message-media-control button
  * magnifier: Use new cursor tracker API to keep wayland focus while hidden
  * magnifier: Use own showSystemCursor() instead of set_pointer_visible()
  * Update Brazilian Portuguese translation
  * polkitAgent: Use dialog as confirmation when the user has no password
  * polkitAgent: Update user name on user changes
  * polkitAgent: Fix a typo of a signal name
  * appDisplay: Add a timeout when switching pages during DnD
  * appDisplay: Add threshold after overshoot page switches
  * appDisplay: Simplify event blocking while folder is opened
  * appDisplay: Ensure we don't recreate existing AppIcons for folders
  * appDisplay: Add missing .actor
  * keyboard: Try harder to find a matching layout
  * screenShield: Replace child properties
  * switcherPopup: Fix last commit
  * switcherPopup: Improve modifier-less keybinding navigation
  * switcherPopup: Use roundtrip time when the popup is modifier-less
  * appDisplay: Don't crash if app is missing categories
  * panel: Update window section items on title changes
  * power: Handle "100%% but charging" case
  * closeDialog: Fix dialog size when using geometry scaling
  * appIcon: Remove drag monitor on destroy
  * folderView: Reset schemas before removing the folder
  * baseAppView: Destroy icon when removing
  * allView: Rename variable
  * allView, frequentView: Only create icons when necessary
  * polkitAgent: Fix spinner
  * Increase .calendar-today visibility
  * appMenu: Hide stopped spinner actor
  * animation: Add parameter for hiding stopped Spinner actor
  * animation: Turn Spinner animate parameter into Params option
* Thu Nov 21 2019 Frederic Crozat <fcrozat@suse.com>
- Update gnome-shell-domain.patch to fix syntax errors.
* Tue Nov 19 2019 dimstar@opensuse.org
- Update to version 3.34.1+14:
  * windowManager: Replace left-over calls to _removeEffect()
  * Update Russian translation
  * windowManager: Complete interrupted size change effects
  * windowManager: Use Sets to track ongoing effects
  * ci: Fix checking out mutter on stable branches
  * theme: Adjust system-menu-action buttons
  * calendar-server: Uses wrong timezone for event times
* Fri Nov  1 2019 Alynx Zhou <alynx.zhou@suse.com>
- Rebase patch gnome-shell-domain.patch and
  gnome-shell-1007468-lock-screen-SUSE-logo-missing.patch.
* Wed Oct 30 2019 dimstar@opensuse.org
- Update to version 3.34.1+7:
  * dnd: Skip drag target when its acceptDrop() throws an exception
* Wed Oct 23 2019 bjorn.lie@gmail.com
- Update to version 3.34.1+6:
  + shell-screenshots: Do not pass a clip for window screenshots.
  + workspace: Sort windows in overview grid using cached center.
  + screenShield: Compute lock timeout fade duration using
    animation settings.
  + environment: Only disable unredirection of ongoing transitions.
  + js: Replace Tweener time leftovers with ease duration.
  + animation: Finish porting to clutter transitions.
* Wed Oct  9 2019 Bjørn Lie <bjorn.lie@gmail.com>
- Update to version 3.34.1:
  + Fix "Frequent" view icons disappearing on hover
  + Allow editing app folder names.
  + Skip property transitions while hidden.
  + Make menu animations more consistent.
  + Improve performance when enabling/disabling all extensions.
  + Fix extra icons appearing in "Frequent" view animation.
  + Fix fading out desktop icons.
  + Fix box-shadow glitch with prerendered resources.
  + Fix accidentally skipped animations.
  + Fix screenshots and window animations when scaled.
  + Don't leak NOTIFY_SOCKET environment variable to applications.
  + Fix lock-up on X11 when ibus is already running on startup.
  + Fix screen dimming on idle.
  + Do not notify systemd before initialization is complete.
  + Support SAE secrets in network agent.
  + Fix various regressions with dynamic workspaces.
  + Fixed crashes.
  + Misc. bug fixes and cleanups.
  + Updated translations.
* Sat Sep 21 2019 bjorn.lie@gmail.com
- Update to version 3.34.0+148:
  + shell-util: Do not scale the clip in
    get_content_for_window_actor()
  + Update Galician translation
  + screenShield: Stop using deprecated actor property
  + unlockDialog: Use inheritance instead of composition
  + loginDialog: Stop using deprecated actor property
  + environment: Try harder to find a transition
  + layout: Don't use the actors pick workaround on update regions
  + renameFolderMenu: Use a custom menu item inheriting from
    PopupBaseMenuItem
  + renameFolderMenu: Move to non-legacy coding style
  + renameFolderMenu: Set the entry as menu focus actor
  + popupMenu: Add focusActor property to define the default focus
    actor
  + popupBaseMenuItem: Add support for Hidden Ornament
  + renameFolderMenu: Don't save the source
  + folderIcon: Remove duplicated addMenu call
  + workspace: Fix an incorrect signal check
  + appDisplay: Animate DnD app icons at the position they were
    dropped
  + appDisplay: Add API to animate launch at given position
  + workspace: Return results of forwarded acceptDrop
  + overview: Only accept AppIcon drops if the app can open a new
    window
  + shell-app: Never allow opening new windows while an app is
    starting
  + workspace: Use AppIcon.app to check action-support by the drag
    source
  + introspect: Check whitelist also for GetRunningWindows()
  + st: Fix box-shadow drawing with prerendered_texture
  + workspace: Remove unused properties of WindowClone
  + viewSelector: Only reset search entry if it has key focus
  + workspace: Reset idle hide timeout for overlays on reentry
  + workspace: Make title of overlay reactive
  + workspace: Continue overlay idle hide timeout when pointing at
    close button
  + Updated translations.
* Tue Sep 17 2019 bjorn.lie@gmail.com
- Update to version 3.34.0+117:
  + util: Handle trailing LTR/RTL markers in URLs
  + cleanup: Don't add linebreak before operators
  + cleanup: Disambiguate assignments in arrow functions
  + cleanup: Remove trailing spaces
  + cleanup: Fix up "special" comments
  + cleanup: Use consistent brace style of blocks
  + cleanup: Avoid pointless "renames" in destructuring
  + cleanup: Avoid unnecessary parentheses in arrow functions
  + cleanup: Avoid useless return statements
  + cleanup: Don't use Array/Object constructors
* Tue Sep 17 2019 Chingkai Chu <qkzhu@suse.com>
- Rebase gnome-shell-864872-unlock-by-mouse-motion.patch to 3.34.
* Fri Sep 13 2019 bjorn.lie@gmail.com
- Update to version 3.34.0+94:
  + lookingGlass: Only update window list when visible
  + ci: Disable MR handling for now
  + ci: Disallow legacy style in merge requests
  + ci: Fail on any common lint errors
  + cleanup: Don't assume hasOwnProperty() method on objects
  + cleanup: "Only" use two indentation styles for object literals
  + cleanup: Stop using Mainloop module
- Switch to checkout from master, we need the fixes for stability.
- Drop gnome-shell-remove-the-INITIALIZED-extensionState.patch:
  Fixed upstream.
* Thu Sep 12 2019 Dead Mozay <dead_mozay@opensuse.org>
- Add gnome-shell-remove-the-INITIALIZED-extensionState.patch:
  Completely remove the INITIALIZED ExtensionState
* Mon Sep  9 2019 mgorse@suse.com
- Update to version 3.34.0:
  + Handle startup/shutdown of misc X11 services.
  + Fix sound volume mute/unmute.
  + Correctly terminate pasted text.
  + Updated translations.
* Mon Sep  9 2019 Chingkai Chu <qkzhu@suse.com>
- Add gnome-shell-jscSLE9267-Remove-sessionList-of-endSessionDialog.patch:
  Remove sessionList of endSessionDialog for security reasons
  (jsc#SLE-9267).
* Sat Sep  7 2019 Bjørn Lie <bjorn.lie@gmail.com>
- Fixup _service to follow our standards.
* Thu Sep  5 2019 Michael Gorse <mgorse@suse.com>
- Rebase SLE patches and modernize syntax in a few cases:
  gnome-shell-gdm-login-applet.patch
  gnome-shell-domain.patch
  gnome-shell-864872-unlock-by-mouse-motion.patch
  gnome-shell-lock-bg-on-primary.patch
  gs-fate318433-prevent-same-account-multi-logins.patch
  gnome-shell-1007468-lock-screen-SUSE-logo-missing.patch
* Wed Sep  4 2019 Luke Jones <luke@ljones.dev>
- Update to version 3.33.92
  + Animate pointer a11y pie timer.
  + Fix restarting shell in systemd user session.
  + Misc. bug fixes and cleanups.
* Tue Sep  3 2019 Luke Jones <luke@ljones.dev>
- Update to version 3.33.91
  + Fix regression when adjusting brightness.
  + Fix pointer a11y timeout animation.
  + Add new extensions CLI tool.
  + Only track top-level windows.
  + Misc. bug fixes and cleanups.
  + Re-apply gnome-shell-private-connection.patch
- Changes from version 3.33.90
  + Implement DND app picker folder management.
  + Make Clocks/Weather integration work with sandboxed apps.
  + Support startup via systemd user instance.
  + Replace Tweener with Clutter animations.
  + Minimize travel distance in overview animation.
  + Rescan icon theme when installed apps changed.
  + Consistently animate new window actions.
  + Misc. bug fixes and cleanups.
- Changes from version 3.33.4
  + Fix unintentional interference between gestures.
  + Fix unintentional loop while polkit dialog is active.
  + Fix alt-tab icon size on HiDPI.
  + Style fixes and improvements.
  + Fix style updates for non-background CSS properties.
  + Fix cursor visibility in screen recordings.
  + Add option for disabling the hot corner.
  + Use more fine-grained levels in battery indicator.
  + Fix the calculation of the maximum number of app search
    results.
  + Handle horizontal workspace layout with gestures/animations.
  + Improve handling of session mode extensions.
  + Misc. bug fixes and cleanups.
- Changes from version 3.33.3
  + Prepare for optional X11.
  + Fix opening window menu.
  + Reload search providers when installed applications change.
  + Implement locate-pointer accessibility feature.
  + Allow to disable window menus via session mode.
  + Implement mouse accessibility.
  + Call GDM's RegisterSession() after startup.
  + Fix extended keys popups being hidden by on-screen keyboard.
  + Fix top bar being hidden by lock screen.
  + Update theme to better match GTK's Adwaita.
  + Set up GJS profiler when GJS_TRACE_FD is set.
  + Misc. bug fixes and cleanups.
- Changes from version 3.33.2
  + Fix keeping actors visible in scrollviews.
  + Move some chrome above popup windows.
  + Include 'sandboxed-app-id' in winodw introspection info.
  + Port to libecal-2.0.
  + Support TCRYPT in mount password dialog.
  + Misc. bug fixes and cleanups.
- Changes from version 3.33.1
  + Refine the app menu.
  + Refine window preview style.
  + Only emit ::style-changed on actual changes.
  + Disable emoji on-screen keyboard support on X11.
  + Fix tablet button mapping overlay.
  + Don't crash for world clock locations with no timezone.
  + Don't leak old on-screen keyboard layout groups.
  + Fix ellipsization in dialog subtitles/bodies.
  + Fix glitch of fullscreen window in workspace switch animation.
  + Fix distortion of some image contents.
  + Allow dragging unfocused tiled/maximized windows from top bar.
  + Handle network interface name changes.
  + Avoid unnecessary style changes when computing
    :first/:last-child.
  + Misc. bug fixes and cleanups.
* Wed Jul 24 2019 bjorn.lie@gmail.com
- Update to version 3.32.2+11:
  + shell-global: don't warn when unsetting non-existent state
  + keyring-prompt: relax NULL check in remove_mnemonics()
  + modemManager: improve check for CDMA system identifier
  + windowAttentionHandler: disconnect signals before destruction
  + shell-recorder: Restore cursor recording
  + altTab:
  - Remove get_preferred_width override of AppIcon
  - Fix a wrong variable name
  - Ensure style of this._list before calculating icon sizes
  + boxpointer: Unset the sourceActor on destruction
- Switch to git checkout via source service, upstream is lacking in
  stable releases. In the future we will use a stable tag when
  possible, but when upstream slacks off, we will use a checkout of
  the stable branch.
* Wed May 29 2019 Bjørn Lie <bjorn.lie@gmail.com>
- Drop gnome-shell-animations-speedup.patch: It causes problems
  with 3'rd party gnome-shell themes, and was dropped from upstream
  stable branch due to this.
* Sun May 26 2019 Bjørn Lie <bjorn.lie@gmail.com>
- Update to version 3.32.2:
  + Fix tablet button mapping overlay.
  + Fix ellipsization in dialog subtitles/bodies.
  + Don't crash for world clock locations with no timezone.
  + Handle network interface name changes.
  + Don't leak old on-screen keyboard layout groups.
  + Avoid unnecessary style changes when computing
    :first/:last-child.
  + Misc. bug fixes.
- Drop gnome-shell-do-not-chain-up-to-parent-allocate.patch: Fixed
  upstream.
* Tue May 14 2019 Yifan Jiang <yfjiang@suse.com>
- Add gnome-shell-do-not-chain-up-to-parent-allocate.patch: Don't
  chain up to parent's allocate, resolving Topicon Plus extension
  high cpu consumption (glgo#GNOME/gnome-shell#1054).
* Fri Apr 19 2019 Bjørn Lie <bjorn.lie@gmail.com>
- Add gnome-shell-animations-speedup.patch: Speed up animations
  (glgo#GNOME/gnome-shell!505).
* Thu Apr 18 2019 Dominique Leuenberger <dimstar@opensuse.org>
- Update to version 3.32.1:
  + Fix avatar scaling on login screen
    (glgo#GNOME/gnome-shell#1024).
  + Fix distortion of desktop zoom (glgo#GNOME/gnome-shell#646).
  + Fix mouse cursor visibility when using desktop zoom
    (glgo#GNOME/gnome-shell#1020).
  + Fix screen dimming after wake-up on lock screen
    (glgo#GNOME/gnome-shell#900).
  + Fix Alt+Esc switcher (glgo#GNOME/gnome-shell#1064).
  + Respect struts for popover placement
    (glgo#GNOME/gnome-shell#1102).
  + Fix app icons updates after theme changes
    (glgo#GNOME/gnome-shell#1117).
  + Fix desktop zoom after resolution changes
    (glgo#GNOME/gnome-shell#1120).
  + Implement stick-to-finger workspace switch overview gestures
    (glgo#GNOME/gnome-shell#516).
  + Make World Clocks offsets relative to local time
    (glgo#GNOME/gnome-shell#1157).
  + Fix top app icon disappearing from dash
    (glgo#GNOME/gnome-shell#1053).
  + Update switch style to match new Adwaita
    (glgo#GNOME/gnome-shell!496).
  + Ensure CSS units are pixel-aligned when scaling is used [Carlos; #91]
  + Misc. bug fixes and cleanups: glgo#GNOME/gnome-shell!444,
    glgo#GNOME/gnome-shell#1016, glgo#GNOME/gnome-shell#1018,
    glgo#GNOME/gnome-shell!449, glgo#GNOME/gnome-shell#1036,
    glgo#GNOME/gnome-shell!455, glgo#GNOME/gnome-shell#1094,
    glgo#GNOME/gnome-shell!440, glgo#GNOME/gnome-shell#1023,
    glgo#GNOME/gnome-shell#624, glgo#GNOME/gnome-shell#1017,
    glgo#GNOME/gnome-shell!476, glgo#GNOME/gnome-shell!473,
    glgo#GNOME/gnome-shell!480, glgo#GNOME/gnome-shell#1130,
    glgo#GNOME/gnome-shell!485, glgo#GNOME/gnome-shell!481,
    glgo#GNOME/gnome-shell!490, glgo#GNOME/gnome-shell!489,
    glgo#GNOME/gnome-shell#1151, glgo#GNOME/gnome-shell!435,
    glgo#GNOME/gnome-shell#1160, glgo#GNOME/gnome-shell!482,
    glgo#GNOME/gnome-shell#1150, glgo#GNOME/gnome-shell#1166,
    glgo#GNOME/gnome-shell!384.
  + Updated translations.
- Drop gnome-shell-screenShield-Handle-signal-StatusChanged.patch:
  fixed upstream.
* Fri Mar 29 2019 xwang@suse.com
- Add gnome-shell-screenShield-Handle-signal-StatusChanged.patch:
  Enable dimming screen when screen is locked (bsc#1118286,
  glgo#GNOME/gnome-shell#900).
* Mon Mar 25 2019 Chingkai <qkzhu@suse.com>
- Move
  gnome-shell-fate324570-Make-GDM-background-image-configurable.patch
  to PATCH-FEATURE-OPENSUSE since the related patch of
  gsettings-desktop-schemas was rebased.
* Wed Mar 13 2019 Bjørn Lie <bjorn.lie@gmail.com>
- Move
  gnome-shell-fate324570-Make-GDM-background-image-configurable.patch
  to be a SLE only patch.
* Wed Mar 13 2019 Chingkai <qkzhu@suse.com>
- Rebase : the following patches are rebased to version 3.32.0
  + gnome-shell-Avoid-loginDialog-grab-focus-when-locked.patch
  + gnome-shell-disable-ibus-when-not-installed.patch
  + gnome-shell-fate324570-Make-GDM-background-image-configurable.patch
  + gnome-shell-private-connection.patch
* Tue Mar 12 2019 Bjørn Lie <bjorn.lie@gmail.com>
- Update to version 3.32.0:
  + Fix sizing issues in on-screen-keyboard emoji panel.
  + Fix test linker failure on Debian/Ubuntu.
  + Avoid assertion when sizing fallback app icons from CSS.
  + Fix mis-sized menu arrows after texture cache changes.
  + Updated translations.
- Add typelib(Rsvg) Requires: Needed runtime dependency.
* Tue Mar  5 2019 Bjørn Lie <bjorn.lie@gmail.com>
- Update to version 3.31.92:
  + Fix visual glitch in submenus.
  + Support fractional scaling.
  + Only consider visible children for :first-child/:last-child.
  + Hide trailing separator in search results.
  + Remember choice in inhibit-shortcuts dialogue.
  + Don't toggle on-screen keyboard on every focus change.
  + Fix legacy tray icons not responding to events on wayland.
  + Fix generating French OSK layout.
  + Use borderless round user images.
  + Misc. bug fixes and cleanups.
  + Updated translations.
- Drop gnome-shell-meson.patch: Fixed upstream.
* Fri Feb 22 2019 bjorn.lie@gmail.com
- Update to version 3.31.91:
  + Don't close on-screen-keyboard's language menu on hover.
  + Don't let unfullscreen gesture interfere with top bar taps.
  + Always use symbolic user icon in system menu.
  + Add flags parameter in GrabAccelerators API.
  + Misc. bug fixes and cleanups.
  + Updated translations.
* Thu Feb 21 2019 bjorn.lie@gmail.com
- Update to version 3.31.90:
  + Fix input methods after ibus restarts.
  + Refresh world clocks and weather sections.
  + Port to ES6 classes (update your extensions!).
  + networkAgent: Advise users when WPS support is available.
  + Performance improvements.
  + Fix drag-and-drop with wacom pens.
  + Fix CAPS LOCK indication on wayland.
  + Show details of non-sensitive notifications on lock screen.
  + Refine extension-prefs' error UI.
  + Add switch-to-application-n keybindings.
  + Remove top bar translucency.
  + Support emojis and keypads in on-screen keyboard.
  + Don't allow popups to re-enable keyboard shortcuts on lock
    screen (bsc#1124493, glgo#GNOME/gnome-shell#851, CVE-2019-3820).
  + Replace app menu.
  + Include commonly copied+pasted extension helpers.
  + Misc. bug fixes and cleanups: glgo#GNOME/gnome-shell#780,
    glgo#GNOME/gnome-shell#909, glgo#GNOME/gnome-shell!316,
    glgo#GNOME/gnome-shell!308, glgo#GNOME/gnome-shell!309,
    glgo#GNOME/gnome-shell#915, glgo#GNOME/gnome-shell!350,
    glgo#GNOME/gnome-shell!362, glgo#GNOME/gnome-shell!357,
    glgo#GNOME/gnome-shell!365, glgo#GNOME/gnome-shell!366,
    glgo#GNOME/gnome-shell!283, glgo#GNOME/gnome-shell!367,
    glgo#GNOME/gnome-shell#942, glgo#GNOME/gnome-shell!371,
    glgo#GNOME/gnome-shell!373, glgo#GNOME/gnome-shell!374,
    glgo#GNOME/gnome-shell!343, glgo#GNOME/gnome-shell!375,
    glgo#GNOME/gnome-shell!292, glgo#GNOME/gnome-shell!317,
    glgo#GNOME/gnome-shell!377, glgo#GNOME/gnome-shell!379,
    glgo#GNOME/gnome-shell!346, glgo#GNOME/gnome-shell!383,
    glgo#GNOME/gnome-shell#953, glgo#GNOME/gnome-shell!388.
  + Updated translations.
- Disable the following patches:
  + gnome-shell-private-connection.patch
  + gnome-shell-disable-ibus-when-not-installed.patch
  + gnome-shell-Avoid-loginDialog-grab-focus-when-locked.patch
  + gnome-shell-fate324570-Make-GDM-background-image-configurable.patch
- Drop
  gnome-shell-disable-POPUP-keybindings-in-unlock-screen.patch:
  Fixed upstream.
* Thu Feb 21 2019 bjorn.lie@gmail.com
- Update to version 3.31.4:
  + Improve icon grid performance.
  + Remove browser plugin.
  + Add DBus API for introspecting the application state.
  + Always allow leaving the overview via the hot-corner.
  + Misc. bug fixes: bgo#643595, bgo#673767,
    glgo#GNOME/gnome-shell!293, glgo#GNOME/gnome-shell#783,
    glgo#GNOME/gnome-shell#781, glgo#GNOME/gnome-shell!298,
    glgo#GNOME/gnome-shell!297, glgo#GNOME/gnome-shell#782,
    glgo#GNOME/gnome-shell!301, glgo#GNOME/gnome-shell!314,
    glgo#GNOME/gnome-shell!305, glgo#GNOME/gnome-shell#799,
    glgo#GNOME/gnome-shell#632, glgo#GNOME/gnome-shell!327.
  + Updated translations.
- Drop gnome-shell-browser-plugin subpackage following upstream.
  Obsolete it from the main package.
- Replace pkgconfig(libmutter-3), pkgconfig(mutter-clutter-3),
  pkgconfig(mutter-cogl-3) and pkgconfig(mutter-cogl-pango-3)
  BuildRequires with pkgconfig(libmutter-4),
  pkgconfig(mutter-clutter-4), pkgconfig(mutter-cogl-4) and
  pkgconfig(mutter-cogl-pango-4) BuildRequires.
- Drop upstream fixed patches:
  + gnome-shell-ibusManager-Dont-pass-undefined-callback.patch.
  + gnome-shell-altSwitcher-Fix-error-when-alternatives-are-disabled.patch.
  + gnome-shell-dash-Destroy-items-child-before-tooltip.patch.
  + gnome-shell-st-button-Ignore-pointer-emulated-touch-events.patch.
  + gnome-shell-Do-not-call-KeyboardManager.holdKeyboard.patch.
  + gnome-shell-panel-Dont-allow-opening-hidden-menus.patch: panel
  + gnome-shell-inputMethod-Avoid-calling-set_preedit_text.patch.
  + gnome-shell-inputMethod-Keep-track-preedit-string-visibility.patch.
* Thu Feb 21 2019 bjorn.lie@gmail.com
- Update to version 3.31.2:
  + Port away from and remove ShellGenericContainer.
  + popupMenu: Fix keyboard activation when numlock is active.
  + Do not block all shortcuts while app folders are expanded.
  + Fix regression in handling new input sources.
  + Reask password after udisk errors for no/wrong passwords.
  + Improve performance of app icon animations.
  + Avoid focus changes when updating keyboard options.
  + notifications: Support icon theme names in 'image-path' hint.
  + Respect natural-scroll setting for workspace swipe gesture.
  + Confine window preview titles to workspace area.
  + Misc. bug fixes.
  + Updated translations.
* Thu Feb 21 2019 bjorn.lie@gmail.com
- Add upstream bug fix patches from the stable branch:
  + gnome-shell-panel-Dont-allow-opening-hidden-menus.patch: panel:
    Don't allow opening hidden menus via keybindings.
  + gnome-shell-disable-POPUP-keybindings-in-unlock-screen.patch:
    shellActionModes: disable POPUP keybindings in unlock screen.
  + gnome-shell-inputMethod-Avoid-calling-set_preedit_text.patch:
    inputMethod: Avoid calling set_preedit_text() if unnecessary.
  + gnome-shell-inputMethod-Keep-track-preedit-string-visibility.patch:
    inputMethod: Keep track of preedit string visibility.
* Fri Jan 18 2019 bjorn.lie@gmail.com
- Add gnome-shell-Do-not-call-KeyboardManager.holdKeyboard.patch:
  keyboard: Do not call KeyboardManager.holdKeyboard() with
  set-content-type. Patch from upstream stable branch.
* Thu Dec 27 2018 bjorn.lie@gmail.com
- Add upstream bug fix patches from stable branch:
  + gnome-shell-ibusManager-Dont-pass-undefined-callback.patch:
    ibusManager: Don't pass undefined callback to ibus.
  + gnome-shell-altSwitcher-Fix-error-when-alternatives-are-disabled.patch:
    AltSwitcher: Fix error when all alternatives are disabled.
  + gnome-shell-dash-Destroy-items-child-before-tooltip.patch:
    dash: destroy items's child before tooltip.
  + gnome-shell-st-button-Ignore-pointer-emulated-touch-events.patch:
    st-button: Ignore pointer emulated touch events.
* Wed Nov 14 2018 bjorn.lie@gmail.com
- Update to version 3.30.2:
  + popupMenu: Fix keyboard activation when numlock is active.
  + Do not block all shortcuts while app folders are expanded.
  + Fix regression in handling new input sources.
  + Improve performance of app icon animations.
  + Respect natural-scroll setting for workspace swipe gesture.
  + notifications: Support icon theme names in 'image-path' hint.
  + Confine window preview titles to workspace area.
  + Misc. bug fixes.
  + Updated translations.
* Mon Nov 12 2018 qkzhu@suse.com
- Add gnome-shell-fate324570-Make-GDM-background-image-configurable.patch:
  + Add a background for this_lockDialogGroup to make login/lock
    background configurable
  + This patch requires a patch in gsettings-desktop-schemas
    gsettings-desktop-schemas-fate324570-Add-key-for-GDM-background-
    configuration.patch
  + You can change the background via gsettings, and the schema id is
    "org.gnome.desktop.background.lockdialog"
  + The default theme is the same as upstream's, you can configure the
    the background in a branding package just like how GNOME Shell's
    wallpaper was changed
  (fate#324570, glgo#GNOME/gnome-shell#680).
* Tue Oct  9 2018 bjorn.lie@gmail.com
- Update to version 3.30.1:
  + Cancel search on overview hiding (glgo#GNOME/gnome-shell!205).
  + Fix disappearing network icon (glgo#GNOME/gnome-shell#140).
  + Improve switch-monitor shortcut handling
    (glgo#GNOME/gnome-shell!208).
  + Fix missing key information in keyring dialog
    (glgo#GNOME/gnome-shell#574).
  + De-duplicate all entries in run command history
    (glgo#GNOME/gnome-shell#524).
  + Fix frozen disk unlock dialogs (glgo#GNOME/gnome-shell#565).
  + Fix unresponsive-app dialog blocking input in other windows
    (glgo#GNOME/gnome-shell#273).
  + Fix handling of forward-key-event input method signal
    (glgo#GNOME/gnome-shell#531).
  + Misc. bug fixes: glgo#GNOME/gnome-shell#520, bgo#791233,
    glgo#GNOME/gnome-shell!188, glgo#GNOME/gnome-shell#539,
    glgo#GNOME/gnome-shell!217, glgo#GNOME/gnome-shell#536,
    glgo#GNOME/gnome-shell#537, glgo#GNOME/gnome-shell#578,
    glgo#GNOME/gnome-shell!236, glgo#GNOME/gnome-shell#579,
    glgo#GNOME/gnome-shell!228, glgo#GNOME/gnome-shell#618,
    glgo#GNOME/gnome-shell#471, glgo#GNOME/gnome-shell!255.
  + Updated translations.
- Rebase patches with quilt and some manual touchup.
* Tue Sep 18 2018 antoine.belvire@opensuse.org
- Update spec file:
  + Update build dependency versions according to meson.build.
  + No longer recommend lang package as it already supplements main
    package (same effect, it's redundant).
* Thu Sep  6 2018 luc14n0@linuxmail.org
- Update to version 3.30.0:
  + Updated translations.
- Re-enable translation-update-upstream call: the previous issue
  has been fixed.
* Sat Sep  1 2018 luc14n0@linuxmail.org
- Update to version 3.29.92:
  + Choose some actors to cache on the GPU (bgo#792633).
  + inputMethod: Hide preedit text if requested
    (glgo#GNOME/gnome-shell#431).
  + Fix forced fallback app-menus on wayland
    (glgo#GNOME/gnome-shell#276).
  + Updated translations.
* Tue Aug 21 2018 dimstar@opensuse.org
- Update to version 3.29.91:
  + Fix handling of 0/false options in ShowOSD D-Bus API
    (bgo#791669).
  + overview: Fix handling of confirmation dialogs on wayland.
  + Avoid some full relayout/redraws.
  + Keep workspace switcher slid out when workspaces are in use.
  + Ignore auto-repeat for some keybindings
    (glgo#GNOME/gnome-shell#373).
  + Misc. bug fixes (glgo#GNOME/gnome-shell#464).
  + Updated translations.
- Drop gnome-shell-fix-build-new-meson47.patch: fixed upstream.
* Fri Aug  3 2018 bjorn.lie@gmail.com
- Update to version 3.29.90:
  + Add remote access indication on wayland.
  + Fix wrong window positions in overview on wayland.
  + Add gesture to unfullscreen a window.
  + Add PickColor method to screenshot D-Bus interface.
  + Consider "new-window" action when opening new windows.
  + Make workspace switching gestures follow motion.
  + Support audio volumes above 100%%.
  + Misc. bug fixes: glgo#GNOME/gnome-shell#424,
    glgo#GNOME/gnome-shell!132, glgo#GNOME/gnome-shell!182,
    glgo#GNOME/gnome-shell#433, glgo#GNOME/gnome-shell!179,
    bgo#786496.
  + Updated translations.
- Drop gnome-shell-fix-wrong-systemd-user-unit-location.patch:
  Fixed upstream.
- Disable t-u-u, currently broken and needs fixing.
- Add gnome-shell-fix-build-new-meson47.patch: build: Fix build
  with meson >= 47.0.
* Wed Jul 25 2018 luc14n0@linuxmail.org
- Update to version 3.29.4:
  + Fix "Clear All" for calendar events
    (glgo#GNOME/gnome-shell#325).
  + Allow cancelling direct switch operations
    (glgo#GNOME/gnome-shell#315).
  + Support being started by systemd --user.
  + Support key event forwarding required by some input methods
    (glgo#GNOME/gnome-shell#275).
  + Misc. bug fixes and cleanups: bgo#663461,
    glgo#GNOME/gnome-shell#372, glgo#GNOME/gnome-shell#414.
  + Updated translations.
- Changes from version 3.29.3:
  + Save creation time in screenshot metadata (bgo#790481).
  + Improve consistency between ctrl- and middle-click on app icons
    (glgo#GNOME/gnome-shell#316).
  + Add support for font-feature-settings CSS property
    (glgo#GNOME/gnome-shell#34).
  + Adjust to MetaScreen removal (bgo#759538).
  + Misc. bug fixes: glgo#GNOME/gnome-shell#298, bgo#788931,
    glgo#GNOME/gnome-shell#26, glgo#GNOME/gnome-shell#76,
    bgo#788882, bgo#791233.
  + Updated translations.
- Add gnome-shell-fix-wrong-systemd-user-unit-location.patch:
  provided by upstream.
- Replace pkgconfig(libmutter-2), pkgconfig(mutter-clutter-2),
  pkgconfig(mutter-cogl-2) and pkgconfig(mutter-cogl-pango-2) with
  pkgconfig(libmutter-3), pkgconfig(mutter-clutter-3),
  pkgconfig(mutter-cogl-3) and pkgconfig(mutter-cogl-pango-3)
  BuildRequires following upstreams changes.
* Tue Jul 24 2018 bjorn.lie@gmail.com
- Update to version 3.28.3+20180724.2a2f3c981 (bgo#776588):
  + workspaceThumbnail: Sync clone position changes with actor
  + workspace: Recompute bounding box on window 'position-changed'
* Mon Jul 23 2018 bjorn.lie@gmail.com
- Update to version 3.28.3+20180718.6ed21e1ce:
  + Bump version to 3.28.3.
  + events: Re-use event messages where possible.
  + workspaceThumbnail:
  - Don't keep stale clones in list.
  - Remove unused private win reference.
  + workspace: Don't keep stale clones in list.
  + keyboard: Implement standalone FocusTracker.
  + ui: Theme lookup should respect XDG_DATA_DIRS.
  + st-texture-cache:
  - Save cairo surfaces to a different map.
  - Don't add NULL textures to cache.
  + Change "const" to "var".
  + magnifier.js: Fix zoom juddering.
  + st-label: Unset clutter text instance on disposal.
  + Updated translations.
* Fri Jun 22 2018 luc14n0@linuxmail.org
- Update to version 3.29.2:
  + Guard against untimely keyboard map changes
    (glgo#GNOME/gnome-shell#240).
  + Fixes:
  - Icons in search provider results
    (glgo#GNOME/gnome-shell#249).
  - Blurriness of OSD under some resolutions (bgo#782011).
  - Lagging pointer when zoomed (bgo#682013).
  + Misc. bug fixes: glgo#GNOME/gnome-shell#244,
    glgo#GNOME/gnome-shell#136, glgo#GNOME/gnome-shell#214,
    glgo#GNOME/gnome-shell#294, bgo#787871, bgo#781471.
* Sun Jun  3 2018 luc14n0@linuxmail.org
- Update to version 3.29.1:
  + Support icons in app-menu (bgo#760985).
  + Misc. bug fixes: bgo#792687, glgo#GNOME/gnome-shell#221.
  + Updated translations.
- Drop:
  + source service and use upstream tarball once more: the
    situation has been normalized.
  + gnome-shell-network-initialize-async.patch: fixed upstream.
* Mon May 21 2018 bjorn.lie@gmail.com
- Update to version 3.28.2+20180519.a52597ac5:
  + network: Update the icon in the panel whenever NM's state
    changes.
  + Updated translations.
- Add gnome-shell-network-initialize-async.patch: network:
  initialize the agent asynchronously (bgo#789811,
  glgo#GNOME/gnome-shell#63). Patch from upstream git.
* Wed May  9 2018 bjorn.lie@gmail.com
- Update to version 3.28.2+20180509.e1ed4b25e:
  + networkAgent: Fix fallout from libnm port
  + Bump version to 3.28.2
  + build: Include Cally in St introspection
  + remoteSearch: Actually return icons
  + osdWindow: Fix blurriness at certain resolutions
  + keyboardManager: take group index into account when preserving
    keymap
  + keyboardManager: Preserve current keymap across reloads
  + polkitAgent: Guard against repeated close() calls
  + Updated translations.
* Wed Apr 18 2018 bjorn.lie@gmail.com
- Update to version 3.28.1+20180418.b476e851b:
  + workspaceThumbnail:
  - Only update _porthole if the overview is visible
  - Rebuild thumbnails if workareas size changed
  - Initialize porthole based on workArea
  + popupMenu: Fix wrong call to clutter_actor_add_child()
  + utils: Simplify URL regex to only support one layer of
    parentheses
  + polkitAgent: Hide authentication dialogs while locked
  + workspace: Don't move focus unconditionally
  + networkAgent: Use libnm for plugin loading
  + worldClock: Handle named timezones
- Switch back to using git-checkout via source-service, upstream
  seems unable to produce tarballs.
* Sat Apr 14 2018 bjorn.lie@gmail.com
- Drop unneeded NetworkManager-gnome Recommends.
* Tue Mar 20 2018 dimstar@opensuse.org
- Unconditionally enable translation-update-upstream: on
  Tumbleweed, this results in a NOP and for Leap in SLE paid
  translations being used (boo#1086036).
* Mon Mar 19 2018 dimstar@opensuse.org
- Fix patch tags for gnome-shell-private-connection.patch and
  gnome-shell-private-connection.patch: both patches have been
  rebased in time for 3.28.0.
* Thu Mar 15 2018 fcrozat@suse.com
- Switch to Recommends on gnome-bluetooth, we might avoid this
  dependency on small setups without bluetooth (bsc#1067603).
* Mon Mar 12 2018 luc14n0@linuxmail.org
- Update to version 3.28.0:
  + Updated translations.
- Add gdk-x11-3.0, gio-unix-2.0, gobject-2.0, libecal-1.2,
  libxml-2.0, mutter-cogl-2 and x11 pkgconfig modules BuildRequires
  to avoid implicit dependencies.
- Drop pkgconfig(xtst) BuildRequires as mutter takes care of
  pulling it into the dep chain.
- Replace libsecret-unstable with libsecret-1 pkgconfig modules,
  and libnm-glib, libnm-gtk and libnm-util with libnm pkgconfig
  modules to align with meson script.
* Tue Mar  6 2018 dimstar@opensuse.org
- Update to version 3.27.92:
  + Misc. bug fixes: glgo#GNOME/gnome-shell#64,
    glgo#GNOME/gnome-shell#66, glgo#GNOME/gnome-shell#72.
- Replace pkgconfig(libmutter-1), pkgconfig(mutter-clutter-1) and
  pkgconfig(mutter-cogl-pango-1) BuildRequires with
  pkgconfig(libmutter-1), pkgconfig(mutter-clutter-2) and
  pkgconfig(mutter-cogl-pango-2), following upstreams API version
  bump.
* Wed Feb 28 2018 dimstar@opensuse.org
- Modernize spec-file by calling spec-cleaner
* Mon Feb 26 2018 xwang@suse.com
- Rebase gnome-shell-disable-ibus-when-not-installed.patch and
  gnome-shell-private-connection.patch (bsc#1082505).
* Thu Feb 22 2018 dimstar@opensuse.org
- Update to version 3.27.91:
  + Fix wrong bluetooth state when disabled by HW airplane mode
    (bgo#789110).
  + Dump javascript stack on aborts, traps and segfaults
    (bgo#789237).
  + Allow Escape to "cancel" top bar focus (bgo#671121).
  + Fix leaving the overview erroneously on window hover
    (bgo#784545).
  + Add keyboard accessibility dialog (bgo#788564).
  + Port to libnm (bgo#789811).
  + Don't pop up on-screen-keyboard on touch events (bgo#788188).
  + Improve the on-screen-keyboard.
  + Add Thunderbolt support.
  + Don't lock immediately on login after a wayland session crash.
  + Respect cursor's hot x/y coordinates when recording
    (bgo#792860).
  + Allow closing windows and apps during <alt>Tab (bgo#620106).
  + Fix small app folder icons when using HiDPI (bgo#792259).
  + Make sassc a mandatory build dependency (bgo#792822).
  + Misc. bug fixes: bgo#789231, bgo#789277, bog#788542,
    bgo#789103, bgo#779974, bgo#788931, bgo#776940, bgo#786987,
    bgo#791007, bgo#791233, bgo#791148, bgo#706191, bgo#791655,
    bgo#791487, bgo#779413, bgo#787845, bgo#788627, bgo#792354,
    bgo#792616, bgo#781329, bgo#780957, bgo#740142,
    glgo#GNOME/gnome-shell#10, glgo#GNOME/gnome-shell#33.
  + Updated translations.
- Add pkgconfig(ibus-1.0) and sassc BuildRequires: new
  dependencies.
- Update meson parameters in line with upstreams changes:
  + enable-browser-plugin=true => browser-plugin=true.
  + enable-documentation=true => gtk-doc=true.
  + enable-man=true => man=true.
  + enable-networkmanager=yes => networkmanager=true.
  + enable-systemd=yes => systemd=true.
- Drop gnome-shell-osk-dont-popup-when-not-needed.patch: fixed
  upstream.
- Rebase gnome-shell-Avoid-loginDialog-grab-focus-when-locked.patch
  and gnome-shell-meson.patch.
- Disable gnome-shell-disable-ibus-when-not-installed.patch and
  gnome-shell-private-connection.patch: patches need to be rebased.
* Mon Feb  5 2018 badshah400@gmail.com
- Update to version 3.27.1:
  + Fix gdm: Remove separate greeter universal access icon
    (bgo#788943).
- Stop using git-checkout, return to upstream released tarball.
* Wed Jan 31 2018 bjorn.lie@gmail.com
- Update to version 3.26.2+20180130.0d9c74212:
  + padOsd: Ensure to pick pad devices only.
  + network: Fix visibility of VPN section.
  + dnd: Declare restore location variables.
  + appDisplay: don't try to close the popup menu that is already
    destroyed.
  + background: don't leak wall clock when background changes.
  + dateMenu:
  - Fix possible crash with unknown locations.
  - Ignore malformed world-clocks settings.
  + dash: Do not shadow ClutterActor's destroy().
  + Updated translations.
- Update _service url to new gitlab home.
- Drop gnome-shell-network-fix-visibility-VPN.patch: Fixed
  upstream.
* Wed Jan 10 2018 zaitor@opensuse.org
- Add gnome-shell-network-fix-visibility-VPN.patch: network: Fix
  visibility of VPN section (bgo#787845).
- Own directories
  {_datadir}/gnome-shell/extensions|search-providers|modes again,
  seems a lot of packages depended on this beeing true.
* Thu Jan  4 2018 zaitor@opensuse.org
- Update to version 3.26.2+20171218.15b1810a6:
  + background: don't leak wall clock when background changes.
  + dateMenu:
  - Fix possible crash with unknown locations.
  - Ignore malformed world-clocks settings.
  + dash:
  - Do not shadow ClutterActor's destroy().
  - Make sure item labels are only destroyed once.
  + status/keyboard: Reset menuItems and Label objects on change.
  + overview: Protect ::drag-end handlers.
  + Updated translations.
- Switch to git-checkout via source services.
- Pass enable-browser-plugin=true, enable-documentation=true,
  enable-man=true, enable-networkmanager=yes and
  enable-systemd=yes to meson, ensure we build the features we
  want.
- Following the above, add gtk-doc BuildRequires and build
  documentation again.
- Run spec-cleaner, modernize spec.
- Drop update-desktop-files BuildRequires and stop using the
  suse_update_desktop_file macro.
- Drop conditional libaccountsservice0, libcaribou0 and
  libgdmgreeter1 Requires needed for no longer supported versions
  of openSUSE.
- Add fdupes BuildRequires and pass fdupes macro, remove duplicate
  files.
- Drop gnome-shell-wayland Obsoletes: No currently supported
  version of openSUSE have ever had this binary, so this is no
  longer needed.
- Stop exporting BROWSER_PLUGIN_DIR=%%%%{_libdir}/browser-plugins,
  does not work as we are using meson buildsystem.
* Mon Nov  6 2017 xwang@suse.com
- Move SLE-Classic function to gnome-shell-extensions package
  (bsc#1065611).
  + Remove gs-sle-classic-ext.patch
  + Remove SLEClassicExt.js
* Sat Nov  4 2017 luc14n0@linuxmail.org
- Update to version 3.26.2:
  + Dump javascript stack on aborts, traps and segfaults
    (bgo#789237).
  + Misc. bug fixes: bgo#788607, bgo#789018, bgo#789231.
  + Updated translations.
- Update Url to https://wiki.gnome.org/Projects/GnomeShell: current
  GNOME Shell's project web page.
- Drop %%glib2_gsettings_schema_requires macro: the functionality is
  covered by file triggers now.
- Drop fixed upstream patches:
  gnome-shell-unset-primary-and-bottom-monitor-when-headless.patch
  and gnome-shell-spawn-wifi-panel-for-wep-configuration.patch.
- Rebase patches: gnome-shell-private-connection.patch and
  gnome-shell-osk-dont-popup-when-not-needed.patch.
* Sat Oct 28 2017 badshah400@gmail.com
- Add gnome-shell-spawn-wifi-panel-for-wep-configuration.patch:
  network: Spawn wifi panel for further WPA enterprise
  configuration; patch taken from upstream git (bgo#789231).
* Thu Oct 26 2017 xwang@suse.com
- Update gs-sle-classic-ext.patch: Fix the preview window is not
  fully shown in overview mode (bsc#1064378).
* Thu Oct 19 2017 mgorse@suse.com
- Add
  gnome-shell-unset-primary-and-bottom-monitor-when-headless.patch:
  fixes a crash when the monitor is turned off (bgo#788607).
* Sat Oct 14 2017 badshah400@gmail.com
- Add gnome-shell-osk-dont-popup-when-not-needed.patch: Stop the
  on-screen keyboard from showing up when touchscreen use doesn't
  activate a text field; patch taken from upstream bug report
  (bgo#788188).
* Mon Oct  9 2017 xwang@suse.com
- Update gs-sle-classic-ext.patch to version 3.26.1
* Thu Oct  5 2017 dimstar@opensuse.org
- Do not recommend gnome-shell-search-provider-documents: that
  package in turn should just supplement gnome-shell.
* Wed Oct  4 2017 zaitor@opensuse.org
- Update to version 3.26.1:
  + Don't detach launched apps to not break pkexec and friends
    (bgo#763531).
  + Allow search providers to not autostart (bgo#785380,
    bgo#787986).
  + Fix crash when tray icons are hidden/shown in quick succession
    (bgo#787361).
  + Make window group switcher more consistent (bgo#786009).
  + Improve legibility of the top bar when translucent
    (bgo#787940).
  + Don't crash when running outside a logind session (bgo#788046).
  + Allow to run headless (bgo#730551).
  + Update calendar on timezone changes (bgo#678507).
  + Improve keyboard navigation of window previews (bgo#786546).
  + Run unit tests on `meson test` (bgo#786497).
  + Misc. bug fixes: bgo#787423, bgo#766368, bgo#787580,
    bgo#787907, bgo#787901, bgo#788039, bgo#788003, bgo#786343,
    bgo#787902, bgo#788265, bgo#788339, bgo#787905, bgo#788282,
    bgo#787676.
  + Updated translations.
- Drop upstream fixed patches:
  + Drop gnome-shell-app-workaround-pkexec.patch.
  + gnome-shell-dateMenu-fixes.patch.
  + gnome-shell-fix-crash-hint-actor-NULL.patch.
  + gnome-shell-only-listen-window-created-events-once.patch.
  + gnome-shell-disable-osk-gesture-on-lock-screen.patch.
- Move all SLE only patches to patch# 1000 and above.
* Tue Oct  3 2017 jengelh@inai.de
- Update package summaries.
* Fri Sep 29 2017 badshah400@gmail.com
- Add gnome-shell-disable-osk-gesture-on-lock-screen.patch:
  Disable OSK gesture on lock screen (bgo#788339).
* Thu Sep 28 2017 xwang@suse.com
- Add gnome-shell-Avoid-loginDialog-grab-focus-when-locked.patch:
  Fix using keyboard can't unlock screen (bsc#1058521, bgo#788169).
* Tue Sep 19 2017 zaitor@opensuse.org
- Add gnome-shell-only-listen-window-created-events-once.patch:
  gtk-embed: ensure we only listen for window-created events once
  (bgo#787361).
* Mon Sep 18 2017 xwang@suse.com
- Fix JS warning, define classes with 'var' instead of 'const'
  (bgo#785084)
  + Update aboutMenu.js
  + Update gnome-shell-domain.patch
* Fri Sep 15 2017 zaitor@opensuse.org
- Add gnome-shell-app-workaround-pkexec.patch: app: Work around
  pkexec restriction when launching (bgo#763531).
- Add gnome-shell-dateMenu-fixes.patch: Fix gnome-weather and
  notification icon (bgo#787423, bgo#766368).
- Add gnome-shell-fix-crash-hint-actor-NULL.patch: StEntry: fix
  crash when hint actor is NULL (bgo#787580).
* Wed Sep 13 2017 xwang@suse.com
- Update sle-classic patches to version 3.26.0:
  + Update SLEClassicExt.js
  + Update gnome-shell-1007468-lock-screen-SUSE-logo-missing.patch
  + Update gnome-shell-disable-ibus-when-not-installed.patch
  + Update gnome-shell-domain.patch
  + Update gnome-shell-gdm-login-applet.patch
  + Update gs-fate318433-prevent-same-account-multi-logins.patch
  + Update gs-sle-classic-ext.patch
* Tue Sep 12 2017 luc14n0@linuxmail.org
- Update to version 3.26.0:
  + Misc. bug fixes bgo#786332, bgo#786783, bgo#786886, bgo#786868.
  + Updated translations.
* Wed Aug 23 2017 xwang@suse.com
- Update SLEClassicExt.js. Fix only half panel shown on bottom of
  desktop when scaling-factor equals 2(Require patched
  gnome-shell-extensions)(bsc#1046570).
* Tue Aug 22 2017 zaitor@opensuse.org
- Update to version 3.25.91:
  + Open context menu of highlighted search result on Shift+F10
    (bgo#675315).
  + Fix mid-sentence capitalization in weather forecasts
    (bgo#779873).
  + Add switcher popup to cycle through monitor configurations
    (bgo#783550).
  + Offer system actions in search (bgo#691900).
  + Misc. bug fixes: bgo#777519, bgo#786120, bgo#786145,
    bgo#786419, bgo#786526, bgo#786520, bgo#786520, bgo#786146.
  + Updated translations.
* Mon Aug 21 2017 dimstar@opensuse.org
- Update to version 3.25.90:
  + Add permission dialog for inhibiting shortucts (bgo#783342).
  + Improve window picker layout (bgo#783953).
  + Remove legacy status icon tray (bgo#785956).
  + Drop autotools support (bgo#785153).
  + Misc. bug fixes: bgo#785090, bgo#785309, bgo#767805,
    bgo#747794, bgo#785358, bgo#785556.
  + Updated translations.
- Drop gnome-shell-linking.patch, libtool BuildRequires and call to
  autogen.sh: no longer needed after the port to meson build
  system.
- Add gnome-shell-meson.patch: Fix rpath path while linking gvc
  (/usr/share/gnome-shell is not valid to carry arch dependent
  binaries).
- Add meson BuildRequires: follow upstreams port to meson.
* Wed Aug  2 2017 zaitor@opensuse.org
- Update to version 3.25.4:
  + gdm: Fix "Not listed" focus indication (bgo#7840409).
  + Fix missing icons in freedesktop notifications (bgo#784245).
  + gdm: Disable user list when empty (bgo#731320).
  + gdm: Allow empty reponse to PAM messages (bgo#784360).
  + Fix blocked clicks in shutdown dialog (bgo#781738).
  + Show OSD popup when changing volume via scroll wheel (bgo#781028).
  + Refine list search results (bgo#749957).
  + Replace mutter's unresponsive app dialog (bgo#762083).
  + Improve handling of extension errors (bgo#781728).
  + Implement tablet rings/strips configuration (bgo#782033).
  + Adjust to mozjs52 update in gjs (bgo#785084, bgo#785090).
  + Support the meson build system (bgo#783229).
  + Misc. bug fixes: bgo#780403, bgo#772589, bgo#784130,
    bgo#783975, bgo#784353, bgo#784361, bgo#772284, bgo#765011,
    bgo#765011, bgo#765011, bgo#784985, bgo#781471, bgo#785047,
    bgo#736148, bgo#736148.
  + Updated translations.
- Stop handling glib2_gsettings_schema_post(un) and
  desktop_database_post(un) in post(un), no longer needed as we
  have filetriggers to take care of this now. Also drop obsolete
  clean section.
- Rebase gnome-shell-linking.patch.
- Disable  gnome-shell-private-connection.patch, needs rebase or is
  possibly no longer needed.
- Drop upstream fixed patches:
  + gnome-shell-1036494-Consistently-handle-createExtensionObject-errors.patch
  + gnome-shell-1036494-Catch-import-errors.patch
  + gnome-shell-1036494-Consistently-handle-initExtension-errors.patch
  + gnome-shell-878951-hide-list-with-no-user.patch
- Pass autogen.sh instead of autoreconf, upstream tarball is not
  proper, need to bootstrap it.
- Following the above, add gnome-common BuildRequires.
* Wed Aug  2 2017 dimstar@opensuse.org
- Update to version 3.25.3:
  + Bypass proxies for captive portal (bgo#769692).
  + Correctly handle "text-shadow: none;" (bgo#783485).
  + Add StEntry:hint-actor property (bgo#783484).
  + Support text-shadow CSS property in StEntry (bgo#783484).
  + Misc. bug fixes: bgo#777732, bgo#783202, bgo#783210,
    bgo#783206, bgo#783286, bgo#783439, bgo#783483, bgo#783823,
    bgo#781950.
  + Updated translations.
- Rebase gnome-shell-linking.patch.
* Wed Aug  2 2017 zaitor@opensuse.org
- Update to version 3.25.2:
  + Fix StEntry::primary-icon-clicked emission (bgo#782190).
  + Add an optional icon parameter to PopupMenu.addAction()
    (bgo#782166).
  + Allow search providers to include clipboard text with results
    (bgo#775099).
  + Reduce dependency on Caribou (bgo#777342).
  + Add transparency to top bar when free floating (bgo#747163).
  + Animate maximize/unmaximize operations (bgo#766685).
  + Misc. bug fixes: bgo#782000, bgo#780215, bgo#782802,
    bgo#782637, bgo#782930, bgo#755164, bgo#780215, bgo#782982.
  + Updated translations.
- Drop gnome-shell-portalhelper-fixes.patch: Fixed upstream.
* Wed Aug  2 2017 zaitor@opensuse.org
- Update to version 3.25.1:
  + Close Wifi selection dialog on lock (bgo#780054).
  + Fix DND over window previews in overview (bgo#737166).
  + Follow GNOME Weather's location permissions (bgo#780252).
  + Fix portals that require a new window to be loaded
    (bgo#759044).
  + Fix restricting menus to screen height on HiDPI displays
    (bgo#753305).
  + Misc. bug fixes and cleanups: bgo#780063, bgo#780321,
    bgo#780381, bgo#780453, bgo#758873, bgo#780606, bgo#642652,
    bgo#777732, bgo#780157, bgo#781482, bgo#780404, bgo#781545,
    bgo#781728).
  + Updated translations.
- Drop
  gnome-shell-login-fix-session-button-can-be-clicked.patch: Fixed
  upstream.
* Wed Aug  2 2017 xwang@suse.com
- Update sle-classic patches to version 3.24.3:
  + Update aboutMenu.js
  + Update endSession-dialog-update-time-label-every-sec.patch
  + Update gnome-shell-1007468-lock-screen-SUSE-logo-missing.patch
  + Update gnome-shell-864872-unlock-by-mouse-motion.patch
  + Update gnome-shell-878951-hide-list-with-no-user.patch
  + Update gnome-shell-domain.patch
  + Update gnome-shell-gdm-login-applet.patch
  + Update gnome-shell-lock-bg-on-primary.patch
  + Update
    gnome-shell-login-fix-session-button-can-be-clicked.patch
  + Update gnome-shell-screen-disappear.patch
  + Update gs-fate318433-prevent-same-account-multi-logins.patch
  + Update gs-sle-classic-ext.patch
* Thu Jul 20 2017 zaitor@opensuse.org
- Update to version 3.24.3:
  + Bypass proxies for captive portal (bgo#769692).
  + Fix missing icons in freedesktop notifications (bgo#784245).
  + Fix blocked clicks in shutdown dialog (bgo#781738).
  + Implement tablet rings/strips configuration (bgo#782033).
  + Misc. bug fixes: bgo#780215, bgo#782802, bgo#783286,
    bgo#784130, bgo#784353, bgo#781471.
  + Updated translations.
- Drop gnome-shell-portalhelper-fixes.patch and
  gnome-shell-emulate-click-action.patch: fixed upstream.
* Wed Jul 12 2017 zaitor@opensuse.org
- Add gnome-shell-emulate-click-action.patch: Fix clicks in
  gnome-shell shutdown dialog (bgo#781738, boo#1036681).
* Tue Jul 11 2017 alarrosa@suse.com
- Add
  gnome-shell-1036494-Consistently-handle-createExtensionObject-errors.patch,
  gnome-shell-1036494-Catch-import-errors.patch and
  gnome-shell-1036494-Consistently-handle-initExtension-errors.patch
  to handle correctly extensions that fail to load (bsc#1036494,
  bgo#781728, CVE-2017-8288).
* Mon Jul 10 2017 qzheng@suse.com
- Enable gnome-shell-878951-hide-list-with-no-user.patch on
  openSUSE. Upstream commit fbc5e37 (bsc#1047262, bgo#731320).
* Mon Jun 26 2017 xwang@suse.com
- Drop gnome-shell-970480-authprompt-wrapping-message.patch:
  Fixed upstream.
* Tue Jun  6 2017 zaitor@opensuse.org
- Add gnome-shell-portalhelper-fixes.patch:
  + Don't go through proxies for captive portals (bgo#769692).
  + Fix auth URI not being passed to window (bgo#783286).
* Thu May 11 2017 zaitor@opensuse.org
- Update to version 3.24.2:
  + Only fetch weather information when there's a valid location
    (bgo#780404).
  + Handle extension errors during reload due to settings change
    (bgo#781728).
  + Fix StEntry::primary-icon-clicked emission (bgo#782190).
  + Allow search providers to provide clipboard text for results
    (bgo#775099).
  + Misc. bug fixes: bgo#781545.
  + Updated translations.
* Wed Apr 26 2017 qzheng@suse.com
- Add gnome-shell-login-fix-session-button-can-be-clicked.patch:
  Disable session selection button when it's hidden in user switch
  dialog (bsc#1034584, bsc#1034827, bgo#781482).
* Tue Apr 25 2017 qzheng@suse.com
- rebase gnome-shell-gdm-login-applet.patch.
* Sat Apr 15 2017 zaitor@opensuse.org
- Update to version 3.24.1:
  + Close Wifi selection dialog on lock (bgo#780054).
  + Fix DND over window previews in overview (bgo#737166).
  + Do not lock the screen when disabled by lockdown settings
    (bgo#780212).
  + Follow GNOME Weather's location permissions (bgo#780252).
  + Fix portals that require a new window to be loaded
    (bgo#759044).
  + Fix restricting menus to screen height on HiDPI displays
    (bgo#753305).
  + Misc. bug fixes and cleanups: bgo#780063, bgo#780321,
    bgo#780381, bgo#780453, bgo#758873, bgo#780606, bgo#642652.
  + Updated translations.
* Mon Mar 20 2017 dimstar@opensuse.org
- Update to version 3.24.0:
  + Updated translations.
* Fri Mar 17 2017 fcrozat@suse.com
- Drop Recommends on browser plugin, we use supplements now.
- Replace Supplements on Firefox with Supplements on Epiphany for
  browser plugin (bsc#1029915).
* Tue Mar 14 2017 dimstar@opensuse.org
- Update to version 3.23.92:
  + Implement DND to overview on wayland (bgo#765003).
  + Make telepathy optional at runtime (bgo#771721, bgo#779878).
  + Don't show forecasts for NYC when geoclue gets stuck
    (bgo#779898).
  + Add bottom edge drag gesture to bring up the OSK (bgo#757712).
  + Allow switching between pads in the same group (bgo#779986).
  + Ignore showBanners policy for critical notifications
    (bgo#779974).
  + Misc. bug fixes: bgo#779435, bgo#779819, bgo#779820.
  + Updated translations.
- Drop pkgconfig(telepathy-glib) and
  pkgconfig(telepathy-logger-0.2) BuildRequires: no longer
  required.
* Thu Mar  2 2017 dimstar@opensuse.org
- Provide dbus(org.freedesktop.Notifications): gnome-shell
  implements the Notifications interface.
* Wed Mar  1 2017 zaitor@opensuse.org
- Update to version 3.23.91:
  + Use the original timestamps for restored notifications
    (bgo#766410).
  + Add weather information to date+time drop-down (bgo#754031).
  + Refine message list layout in date+time drop-down (bgo#775763).
  + Make next/prev media controls insensitive when unavailable
    (bgo#773884).
  + Misc. bug fixes: bgo#772210, bgo#769546, bgo#775799.
  + Updated translations.
- Replace gnome-common with libtool BuildRequires followings
  upstream changes.
* Fri Feb 17 2017 zaitor@opensuse.org
- Update to version 3.23.90:
  + Handle Ctrl+Q and Ctrl+W in portal window (bgo#764133).
  + Allow to scroll through ibus candidates with mouse
    (bgo#776032).
  + Reload apps on .desktop file content changes (bgo#773636).
  + Use private data/cache directories in portal helper
    (bgo#775639).
  + Fix subsurfaces not showing up in previews (bgo#756715).
  + Fix theme node transitions (bgo#778145).
  + Update pad (o)leds on mode switches (bgo#776543).
  + Add security indicators to defend against malicious portals
    (bgo#749197).
  + Don't allow type ahead at the login screen (bgo#766139).
  + Don't fail to load because of TLS errors (bgo#778253).
  + Ensure the network lists remains sorted on rename (bgo#778686).
  + Toggle power-off/suspend button on long-press (bgo#721173).
  + Add "kill-switch" for user extensions (bgo#778664).
  + Add night light indicator to status area (bgo#741224).
  + Misc. bug fixes: bgo#759793, bgo#735233, bgo#762444,
    bgo#777784, bgo#777934, bgo#778158, bgo#776199, bgo#778425,
    bgo#771098, bgo#778552, bgo#777317, bgo#778660, bgo#778661,
    bgo#745626, bgo#778672.
  + Updated translations.
- Replace pkgconfig(libmutter), pkgconfig(mutter-clutter-1.0) and
  pkgconfig(mutter-cogl-pango-1.0)  with pkgconfig(libmutter-0),
  pkgconfig(mutter-clutter-0) and pkgconfig(mutter-cogl-pango-0)
  BuildRequires following upstream changes in mutter.
* Fri Feb 17 2017 dimstar@opensuse.org
- Update to version 3.23.3:
  + Fix replacing of GNotifications (bgo#775149).
  + Prepare for mozjs31 GJS (bgo#775374).
  + Misc. bug fixes: bgo#775507, bgo#776130.
  + Updated translations.
* Fri Feb 17 2017 dimstar@opensuse.org
- Update to version 3.23.2:
  + Implement Pad configuration OSD (bgo#771067).
  + Show overview on three-finger touchpad pinch (bgo#765937).
  + Summarize network sections with too many devices (bgo#773892).
  + Always show primary network icon when connected (bgo#773890).
  + Fix fullscreen transitions on wayland (bgo#770345).
  + Work around portal failures by using a URL without HTPPS
    redirect (bgo#769940).
  + Fix app view hiding when no usage data is available
    (bgo#774381).
  + Misc. bug fixes: bgo#773875, bgo#740043, bgo#773893,
    bgo#774643, bgo#774805.
  + Updated translations.
- Drop
  gnome-shell-bgo774805-guard-against-animations-that-dont-load.patch:
  Fixed upstream.
- Drop gnome-shell-774381-app-window-overlay-app-list.patch:
  Fixed upstream.
* Fri Feb 17 2017 dimstar@opensuse.org
- Update to version 3.23.1:
  + Request periodic scans while WiFi list is open (bgo#767918).
  + Include extension UUID in structured log metadata (bgo#770717).
  + Line-wrap PAM messages on login screen (bgo#764445).
  + Add a way to launch an app on the discrete GPU (bgo#773117).
  + Only allow graphs to lift screen shield when locked
    (bgo#773328).
  + Add reload option to gnome-shell-extension-tool (bgo#772593).
  + Update background animations when resuming from suspend
    (bgo#773265).
  + Misc. bug fixes: bgo#772723, bgo#772287, bgo#756432,
    bgo#772386, bgo#772386, bgo#773085, bgo#773634.
  + Updated translations.
* Fri Feb 17 2017 zaitor@opensuse.org
- Update to version 3.22.3:
  + Work around portal failures by using a URL without HTPPS
    redirect (bgo#769940).
  + Fix replacing of GNotifications (bgo#775149).
  + Reload apps on .desktop file content changes (bgo#773636).
  + Fix subsurfaces not showing up in previews (bgo#756715).
  + Fix theme node transitions (bgo#778145).
  + Don't allow type ahead at the login screen (bgo#766139).
  + Misc. bug fixes: bgo#774643, bgo#774805, bgo#775507,
    bgo#776130, bgo#759793, bgo#745626.
  + Updated translations.
- Drop gnome-shell-bgo774805-guard-against-animations-that-dont-load.patch:
  Fixed upstream.
* Wed Jan  4 2017 federico@suse.com
- Added gnome-shell-bgo774805-guard-against-animations-that-dont-load.patch
  for bgo#774805 - make the authentication dialog work even if some
  animations cannot be loaded.
* Thu Nov 24 2016 xwang@suse.com
- Add gnome-shell-774381-app-window-overlay-app-list.patch:
  Fix app windows overlay app list in overview screen (bsc#1008539,
  bgo#774381).
* Fri Nov 11 2016 dimstar@opensuse.org
- Update to version 3.22.2:
  + Fix OSD popup glitches (bgo#772723, bgo#772287).
  + Request periodic scans while WiFi list is open (bgo#767918).
  + Always show primary network icon when connected (bgo#773890).
  + Misc. bug fixes: bgo#773875, bgo#740043, bgo#773893.
  + Updated translations.
* Mon Nov  7 2016 xwang@suse.com
- Add SUSE logo on lock screen for GNOME theme (bsc#1007468):
  + gnome-shell-1007468-lock-screen-SUSE-logo-missing.patch
  + sle-background.png
* Wed Nov  2 2016 cxiong@suse.com
- Fix SLEClassic Xsettings overrides bug (boo#993341)
  + Also add extra check for other rogue types
* Tue Oct 11 2016 zaitor@opensuse.org
- Update to version 3.22.1:
  + Fix hidden network indicator on startup (bgo#772249).
  + Fix order of windows with modal dialogs in window switcher
    (bgo#747153).
  + Fix feedback loop between StClipboard and X11 bridge
    (bgo#760745).
  + Reliably match windows from Flatpak apps (bgo#772615).
  + Misc. bug fixes: bgo#742249.
  + Updated translations.
- Drop gnome-shell-network-initialize-connections-on-startup.patch
  and gnome-shell-fix-small-memory-leak.patch: Fixed upstream.
* Sat Oct  1 2016 zaitor@opensuse.org
- Add gnome-shell-network-initialize-connections-on-startup.patch:
  Initialize primary and VPN connections on startup (bgo#772249).
* Fri Sep 23 2016 xwang@suse.com
- Drop gnome-shell-sle-theme.patch (bsc#999592): the patch is
  included in gnome-shell-gdm-login-applet.patch.
- Drop source SLE-theme.tar.gz: SLE12SP2 doesn't use this source
  any more.
- Update gnome-shell-gdm-login-applet.patch:
  + Use dbus function to get hostname
- Add aboutMenu.js: Create from gnome-shell-gdm-login-applet.patch
* Thu Sep 22 2016 zaitor@opensuse.org
- Add gnome-shell-fix-small-memory-leak.patch: Fix a small memory
  leak.
* Mon Sep 19 2016 zaitor@opensuse.org
- Update to version 3.22.0:
  + Misc. bug fixes: bgo#771391, bgo#771536, bgo#771656.
  + Updated translations.
* Tue Sep 13 2016 zaitor@opensuse.org
- Update to version 3.21.92:
  + Adjust screen capture to work with multiple stage views
    (bgo#770128).
  + Improve handling of cycle shortcuts (bgo#771063).
  + Fix windows not getting undimmed in some cases (bgo#770163,
    bgo#752524).
  + Disable extension version check by default (bgo#770887).
  + Misc. bug fixes: bgo#770382, bgo#770888, bgo#770328.
  + Updated translations.
* Fri Sep  9 2016 cxiong@suse.com
- Fix gnome-shell-gdm-login-applet.patch (boo#995296)
  + Fix aboutMenu's distribution name to be more general, like openSUSE Leap
  support.
* Tue Aug 30 2016 zaitor@opensuse.org
- Update to version 3.21.91:
  + Updated translations.
* Fri Aug 19 2016 zaitor@opensuse.org
- Update to version 3.21.90.1:
  + Add translator comments to .desktop files.
  + recorder: Print absolute path if output file can't be opened.
  + Updated translations.
* Fri Aug 19 2016 zaitor@opensuse.org
- Update to version 3.21.90:
  + Improve on-screen keyboard on wayland (bgo#765009).
  + Bugs fixed: bgo#769156, bgo#769216, bgo#769074.
  + Updated translations.
- Drop intltool BuildRequires following upstream changes.
- Drop gnome-shell-fix-missing-return.patch: Fixed upstream.
* Fri Aug 19 2016 zaitor@opensuse.org
- Add global Requires exclude for the now private typelib(Meta)
  from mutter.
- Following the above, add an explicit mutter Requires to ensure
  pulling in mutter with the now private typelib.
* Fri Aug 19 2016 badshah400@gmail.com
- Update to version 3.21.4:
  + overview: Fix switching workspaces when scrolling on
    non-primary monitors (bgo#766883, bgo#768316).
  + Fix crash when using screen recorder under wayland
    (bgo#767001).
  + Update theme on video memory purge errors (bgo#739178).
  + Free old backgrounds immediately (bgo#766353).
  + Add support for system upgrades to end session dialog
    (bgo#763611).
  + Fix maximized windows flickering to the wrong size on restart
    (bgo#761566).
  + Hide ignored events in calendar as well (bgo#768538).
  + calendar: Only hide dismissed occurrence of recurring event
    (bgo#748226).
  + Provide org.freedesktop.impl.portal.access implementation
    (bgo#768669).
  + Bugs fixed: bgo#767954, bgo#768317, bgo#746867, bgo#762206,
    bgo#768956, bgo#768979.
  + Updated translations.
- Drop gnome-shell-background-free-MetaBackground.patch: Fixed
  upstream.
* Fri Aug 19 2016 dimstar@opensuse.org
- Add gnome-shell-linking.patch: Fix linking the private mutter
  libraries.
- Add gnome-commons BuildRequires and call to autoreconf, as above
  patch touches the buildsystem.
* Fri Aug 19 2016 zaitor@opensuse.org
- Update to version 3.21.3:
  + Do not disable suspend action when locked (bgo#725960).
  + Remember input sources MRU list (bgo#766826).
  + networkAgent: Handle VPN service aliases (bgo#658484).
  + Plug a memory leak (bgo#710230).
  + Updated translations.
* Fri Aug 19 2016 zaitor@opensuse.org
- Update to version 3.21.2:
  + Fix sorting of hidden apps in app switcher (bgo#766238).
  + Set logind's LockedHint property when locked (bgo#764773).
  + Allocate framebuffers early to fix a crash on NVIDIA
    (bgo#764898).
  + Fix cycle-windows/cycle-group keybindings (bgo#730739).
  + Switch to shared desktop schema for calendar settings
    (bgo#766318).
  + Misc. bug fixes: bgo#766325, bgo#758471, bgo#757556,
    bgo#757019, bgo#766598.
  + Updated translations.
* Fri Aug 19 2016 zaitor@opensuse.org
- Update to version 3.21.1:
  + Save screencasts in HOME if XDG_VIDEO_DIR doesn't exist
    (bgo#765015).
  + Don't show orientation lock when g-s-d won't rotate
    (bgo#765267).
  + Misc. bug fixes: bgo#722752, bgo#765061, bgo#763068,
    bgo#765607, bgo#757676, bgo#760439.
  + Updated translations.
- Replace pkgconfig(clutter-1.0) for pkgconfig(mutter-clutter-1.0)
  and pkgconfig(mutter-cogl-pango-1.0) BuildRequires following
  upstreams merge of clutter/cogl into mutter.
* Fri Aug 19 2016 zaitor@opensuse.org
- Update to version 3.20.4:
  + Free old backgrounds immediately (bgo#766353).
  + Adjust to flatpak PermissionStore API changes (bgo#766598).
  + calendar: Only hide dismissed occurrence of recurring event
    (bgo#748226).
  + Updated translations.
- Drop gnome-shell-background-free-MetaBackground.patch: Fixed
  upstream.
- Add gnome-shell-fix-missing-return.patch: Fix build, add missing
  return value in gnome-calendar.
* Thu Aug 11 2016 qzhao@suse.com
- Add gnome-shell-disable-ibus-when-not-installed.patch: Disable
  ibus when it not installed, especially out of CJK areas
  (bsc#987360).
* Wed Aug  3 2016 cxiong@suse.com
- Update gs-fate318433-prevent-same-account-multi-logins.patch:
  Make cancel button usable after login forbidden (bnc#991051,
  fate#318433).
* Fri Jul  8 2016 zaitor@opensuse.org
- Add gnome-shell-background-free-MetaBackground.patch: Free
  MetaBackground explicitly when its MetaBackgroundActor is
  destroyed (bgo#766353).
* Wed Jul  6 2016 fbui@suse.com
- Remove pkgconfig(libsystemd-*). Nowadays pkgconfig(libsystemd)
  is enough and replaces all libsystemd-* libs which are obsolete.
* Wed Jun 29 2016 zaitor@opensuse.org
- Update to version 3.20.3:
  + Fix sorting of hidden apps in app switcher (bgo#766238).
  + Allocate framebuffers early to fix a crash on NVIDIA
    (bgo#764898).
  + Fix cycle-windows/cycle-group keybindings (bgo#730739).
  + networkAgent: Handle VPN service aliases (bgo#658484).
  + Fix crash when using screen recorder under wayland
    (bgo#767001).
  + Plug a memory leak (bgo#710230).
  + Updated translations.
- Drop gnome-shell-cogl-nvidia-fixes.patch: Fixed upstream.
* Sat May 28 2016 cxiong@suse.com
- Add gs-fate318433-prevent-same-account-multi-logins.patch:
  Prevent multiple simultaneous logins (Requires patched
  accountsservice)(fate#318433).
* Mon May 23 2016 cxiong@suse.com
- Update to GNOME 3.20.2 fate#318572
  + Fix SPEC file issues: remove unused files.
* Mon May 23 2016 tyang@suse.com
- Add gnome-shell-970480-authprompt-wrapping-message.patch:
  Fix the wrapping error message issue when user password change
  operation fails in gdm greeter (bnc#970480).
* Fri May 20 2016 tyang@suse.com
- Update gnome-shell-878951-hide-list-with-no-user.patch:
  Disable the user list if there is only root created (bnc#878951,
  bnc#980451)
* Wed May 11 2016 zaitor@opensuse.org
- Add gnome-shell-cogl-nvidia-fixes.patch: Init framebuffer early
  to fix gnome-shell crash on NVIDIA drivers (boo#976871,
  bgo#764898).
* Wed May 11 2016 zaitor@opensuse.org
- Update to version 3.20.2:
  + Save screencasts in HOME if XDG_VIDEO_DIR doesn't exist
    (bgo#765015).
  + Don't show orientation lock when g-s-d won't rotate
    (bgo#765267).
  + Misc. bug fixes: bgo#722752, bgo#765061, bgo#763068,
    bgo#765607, bgo#757676.
  + Updated translations.
- Conditionally apply translations-update-upstream BuildRequires
  and macro for non-openSUSE only.
* Mon May  9 2016 cxiong@suse.com
- SLE Classic Fixes (REBASING DONE)
  + MERGED gnome-shell-sle-multiple-fixes.patch
  + Enable window-list extension in SLE Classic (fix for previous
    negligence)
  + Add support for AppMenu auto-toggling
  + Simplify patch and SLEClassicExt.js code
* Wed May  4 2016 cxiong@suse.com
- Rebase SLE Classic (basic) Fate#318572
  + DROPPED bnc963119-sle-fix-menu-navigation.patch
    Keyboard navigation is possible in upstream now, though weird.
  + RENAMED&UPDATED sle-classic-ext.patch to
    gs-sle-classic-ext.patch.
  + UPDATED SLEClassicExt.js.
* Tue Apr 19 2016 idonmez@suse.com
- Re-enable theming
* Tue Apr 19 2016 cxiong@suse.com
- Reviewing all none-SLE-classic patches
- Rebase: the following patches are rebased to newer versions
  + gnome-shell-gdm-login-applet.patch
  + gnome-shell-domain.patch
  + gnome-shell-878951-hide-list-with-no-user.patch
  + gnome-shell-screen-disappear.patch
  + endSession-dialog-update-time-label-every-sec.patch
  + gnome-shell-864872-unlock-by-mouse-motion.patch
  + gnome-shell-lock-bg-on-primary.patch
- DROPPED: Upstreamed Patches
  + gnome-shell-use-env-var-for-mode.patch
  + gnome-shell-defer-loading-userlist.patch
  + wired-connection-status.patch
  + gnome-shell-login-focus-lost.patch
  + gnome-shell-874712-use-upower-directly.patch
  + vpn-indicator-and-menu-general-fix.patch
  + gnome-shell-calendar-fix-week-number.patch
  + gnome-shell-917489-only-set-scaling-factor-if-present.patch
  + dont-start-searchprovider-at-login.patch
  + background-image-caching-fix.patch
  + gnome-shell-933768-fix-leaked-signals-in-login-screen.patch
  + gnome-shell-875481-banner-message.patch
- DROPPED: Invalid, no long applicable in newer versions
  + gnome-shell-right-bg-with-resolution-change.patch
  + gnome-shell-prompt-twice.patch
  + gnome-shell-background-image-change.patch
  + gnome-shell-940159-user-logout-issue.patch
  + add-some-indicating-text-to-logout-menu.patch
- DROPPED: low priority and low patch quality
  + login-prompt-preserve-session-choice.patch
  + 898359-fix-clutter-modal-dialog-integration-with-screenshield.patch
  - bnc948802-fix-user-logout-dialog-icon.patch
* Fri Apr 15 2016 hpj@suse.com
- Update to GNOME 3.20 - Fate#318572.
- Temporarily disable all SLE patches. These will be rebased in a
  later update.
* Wed Apr 13 2016 zaitor@opensuse.org
- Update to version 3.20.1:
  + Plug a memory leak (bgo#735705).
  + Updated translations.
- Drop gnome-shell-Fix-offscreen-leak.patch: Fixed upstream.
* Thu Mar 31 2016 zaitor@opensuse.org
- Add gnome-shell-Fix-offscreen-leak.patch: Fix offscreen leak if
  cogl_framebuffer_allocate fails (bgo#735705).
* Wed Mar 23 2016 dimstar@opensuse.org
- Update to version 3.20.0:
  + Updated translations.
* Thu Mar 17 2016 dimstar@opensuse.org
- Update to version 3.19.92:
  + Update location dialog according to latest mockups
    (bgo#762480).
  + Fix deleting chat notifications in calendar (bgo#747991).
  + Updated translations.
* Thu Mar  3 2016 zaitor@opensuse.org
- Update to version 3.19.91:
  + location: Ask user only once (bgo#762559).
  + Fix jiggling when auto-hiding legacy tray (bgo#747957).
  + Misc. bug fixes: bgo#762475, bgo#762507, bgo#755659.
  + Updated translations.
* Wed Feb 24 2016 cxiong@suse.com
- Add bnc963119-sle-fix-menu-navigation.patch:
  Fix the missing initial keyboard navigation for panel menus like
  application menu (bnc#963119).
* Fri Feb 19 2016 zaitor@opensuse.org
- Update to version 3.19.90:
  + Correctly identify VPN secret requests (bgo#760999).
  + Improve week number presentation (bgo#683245).
  + Add audio device selection dialog (bgo#760284).
  + Add media controls to the time and date drop down (bgo#756491).
  + Fix IBus candidate popup position under wayland (bgo#753476).
  + Ask user to grant applications access to location (bgo#762119).
  + Misc. bug fixes: bgo#761208, bgo#761772, bgo#762270.
  + Updated translations.
- Drop gnome-shell-correctly-ident-VPN-secret-req.patch: Fixed
  upstream.
* Wed Feb  3 2016 dimstar@opensuse.org
- Update to version 3.19.4:
  + gdm: Do not allow bypassing disabled Sign In button
    (bgo#746180).
  + Style week numbers in calendar (bgo#683245).
  + Misc. bug fixes: bgo#759708, bgo#760577, bgo#760945.
  + Updated translations.
- Drop gnome-shell-authprompt-bypass-disabled.patch and
  gnome-shell-Fix-double-unref.patch: fixed upstream.
* Tue Feb  2 2016 damjanovic.ivo@gmail.com
- Obsolete gnome-shell-wayland: the package no longer exists since
  version 3.19.2.
* Mon Feb  1 2016 zaitor@opensuse.org
- Add gnome-shell-Fix-double-unref.patch: NetworkAgent: Fix
  double-unref in get_secrets_keyring_cb() (bgo#759708).
- Add gnome-shell-correctly-ident-VPN-secret-req.patch:
  NetworkAgent: correctly identify the VPN secret requests.
  (bgo#760999).
- Add gnome-shell-authprompt-bypass-disabled.patch: Do not allow
  bypassing disabled Sign In button (bgo#746180).
* Mon Feb  1 2016 cxiong@suse.com
- Update 898359-fix-clutter-modal-dialog-integration-with-screenshield.patch
  Do not manage the modal dialog positions on login screen to avoid
  the power dialog from disappearing (bnc#961920).
* Tue Dec 29 2015 zaitor@opensuse.org
- Replace pkgconfig(libcanberra-gtk) for
  pkgconfig(libcanberra-gtk3) BuildRequires: It's what configure
  looks for and needed now that libcanberra-devel was split.
* Thu Dec 17 2015 dimstar@opensuse.org
- Update to version 3.19.3:
  + Fix thumbnail scaling in window switcher on HiDPI (bgo#758676).
  + Update animated backgrounds on timezone changes (bgo#758939).
  + loginDialog: Update user list on user changes (bgo#758568).
  + Fix touch interaction on wayland (bgo#756748).
  + Updated translations.
- Drop gnome-shell-logindialog-fixes.patch and
  gnome-shell-alt-tab-hdpi-fixes.patch: Fixed upstream.
* Sat Dec 12 2015 zaitor@opensuse.org
- Add gnome-shell-logindialog-fixes.patch: Fix misc login dialog
  issues.
- Add gnome-shell-alt-tab-hdpi-fixes.patch: Fix tiny preview in
  alt-tab when using HiDPI screens.
* Thu Nov 26 2015 hpj@suse.com
- Update gnome-shell-lock-bg-on-primary.patch (bsc#939315). This
  prevents flickering on non-primary monitors when unlocking the
  screen lock.
* Wed Nov 25 2015 zaitor@opensuse.org
- Update to version 3.19.2:
  + Make gnome-shell DBus activatable (bgo#741666).
  + Fix browser plugin crash in Firefox (bgo#737932, bgo#757940).
  + Optionally show battery percentage in system status area
    (bgo#735771).
  + Misc. bug fixes: bgo#757418, bgo#757668, bgo#757779,
    bgo#757816, bgo#745626, bgo#758220.
  + Updated translations.
- Rename gnome-shell.desktop to org.gnome.Shell.desktop following
  upstream.
- Drop gnome-shell-wayland subpackage as it is merged into
  gnome-shell.
* Tue Nov 24 2015 zaitor@opensuse.org
- Update to version 3.19.1:
  + Respect text-scaling factor under wayland (bgo#756447).
  + Show the Bluetooth submenu when there were setup devices
    (bgo#723848).
  + Misc. bug fixes: bgo#756697, bgo#756714, bgo#756605,
    bgo#754814, bgo#738942, bgo#756983, bgo#756925, bgo#757011,
    bgo#673235, bgo#75715.
  + Updated translations.
* Wed Nov 18 2015 cxiong@suse.com
- Add bnc948802-fix-user-logout-dialog-icon.patch
  (bnc#948802) Fix user logout screen icon misalignment.
* Tue Nov 17 2015 zaitor@opensuse.org
- Update to version 3.18.3:
  + Fix browser plugin crash in Firefox (bgo#737932, bgo#757940).
- Drop gnome-shell-revert-browser-plugin.patch: Fixed upstream.
* Sat Nov 14 2015 zaitor@opensuse.org
- Add gnome-shell-revert-browser-plugin.patch: Revert upstream
  commit that makes the browser plugin crash in openSUSE
  (bgo#757940, bgo#758035).
* Thu Nov 12 2015 zaitor@opensuse.org
- Update to version 3.18.2:
  + Fix fullscreen animation glitches (bgo#756697, bgo#756714).
  + Fix window menu being closed immediately in top orientation
    (bgo#756605).
  + Respect text-scaling factor under wayland (bgo#756447).
  + Fix login screen getting stuck after authentification
    (bgo#754814).
  + Fix overview being toggled while still animating (bgo#756925).
  + Improve robustness of browser plugin (bgo#737932, bgo#757940).
  + Misc. bug fixes (bgo#756983, bgo#757150, bgo#757779).
  + Updated translations.
- Drop gnome-shell-Fix-nb-translation.patch: Fixed upstream.
* Wed Nov  4 2015 dimstar@opensuse.org
- Drop fortune recommends: Wanda has been removed with GNOME 3.12.
* Fri Oct 30 2015 tyang@suse.com
- Add gnome-shell-940159-user-logout-issue.patch
  Fix user logout causes black screen when switching.(bnc#940159)
* Thu Oct 15 2015 zaitor@opensuse.org
- Update to version 3.18.1:
  + Fix screen freezes when a notification is pushed (bgo#755425).
  + Fix overzealous ellipsization in system status menu
    (bgo#708472).
  + Hide app menu when disabled by setting (bgo#745919).
  + Fix lightbox effect when animations are disabled (bgo#755827).
  + Do not mark hotplug notifications as critical (bgo#657923).
  + Fix icons getting cut off in dash (bgo#745649).
  + Animate fullscreen/unfullscreen operations (bgo#707248).
  + Misc. bug fixes: bgo#748919, bgo#674799, bgo#754581.
  + Updated translations.
* Tue Sep 22 2015 dimstar@opensuse.org
- Update to version 3.18.0:
  + Updated translations.
* Wed Sep 16 2015 dimstar@opensuse.org
- Update to version 3.17.92:
  + Fix race when loading multiple background animations
    (bgo#741453).
  + Updated translations.
* Wed Sep  9 2015 tyang@suse.com
- Add gnome-shell-875481-banner-message.patch
  GDM can't use banner message when disable userlist.
  (bnc#875481 bgo#703972)
* Thu Sep  3 2015 zaitor@opensuse.org
- Update to version 3.17.91:
  + Fix login screen spinner causing wakeups while VT-switched away
    (bgo#753891).
  + Fix scrolling of user list on login screen (bgo#754525).
  + Updated translations.
* Thu Aug 20 2015 zaitor@opensuse.org
- Update to version 3.17.90:
  + Avoid caret/focus viewport changes during pointer movement
    (bgo#752138).
  + Match GTK+'s modal dialogs for system modal dialogs
    (bgo#746108).
  + Refine message list style (bgo#749958).
  + Fix type-ahead behavior for backspace and compose key
    (bgo#753319, bgo#753320).
  + Refine the system status menu (bgo#751377).
  + Misc. bug fixes and cleanups: bgo#752779, bgo#752739,
    bgo#741366, bgo#651503, bgo#753064, bgo#753181, bgo#752881.
  + Updated translations.
- Rebase gnome-shell-Fix-nb-translation.patch.
* Fri Aug 14 2015 cxiong@suse.com
- Add 898359-fix-clutter-modal-dialog-integration-with-screenshield.patch
  (bnc#898359) Two measures are implemented:
  1. Disable most keys (including lock screen) for
    "endSessionDialog", e.g.  logout, power off and etc.
  2. Make sure screenShield covers all Clutter Modal dialog.
* Thu Jul 30 2015 fezhang@suse.com
- Add gnome-shell-933768-fix-leaked-signals-in-login-screen.patch:
  Fix leaked signals which also causes login screen hangs after 3
  failed user verifications (bsc#933768, bgo#738256).
* Wed Jul 29 2015 zaitor@opensuse.org
- Add gnome-shell-Fix-nb-translation.patch: Fix translation for
  Norwegian Bokmål (bgo#740906).
* Thu Jul 23 2015 zaitor@opensuse.org
- Update to version 3.17.4:
  + Fix fuzziness of app menu icon (bgo#747932).
  + Implement 4 finger swipe gesture for touchpads (bgo#752250).
  + Bugs fixed: bgo#751921, bgo#659969, bgo#752438, bgo#752675.
  + Updated translations.
* Mon Jul  6 2015 zaitor@opensuse.org
- Update to version 3.17.3:
  + Handle touch events in OSK on wayland (bgo#750287).
  + Reinstate left/right movement to window menu (bgo#751344).
  + Allow extensions to disable "Window is ready" notification
    (bgo#748846).
  + Bugs fixed: bgo#750465, bgo#751016, bgo#751517, bgo#750714,
    bgo#751541, bgo#751599.
  + Updated translations.
- Add explicit pkgconfig(libsystemd) BuildRequires.
* Thu Jul  2 2015 zaitor@opensuse.org
- Update to version 3.17.2:
  + Remove StTable widget (bgo#703833).
  + Increase visibility of expanders in alt-tab popup (bgo#745058).
  + Ensure suspend inhibitors are released when VT switched away
    (bgo#749228).
  + Use iio-sensor-proxy directly for orientation lock
    (bgo#749671).
  + Bugs fixed: bgo#749279, bgo#749383, bgo#749529, bgo#749490,
    bgo#749742.
  + Updated translations.
* Thu Jul  2 2015 zaitor@opensuse.org
- Update to version 3.17.1:
  + Add Display Settings entry to background menu (bgo#697346).
  + Add window menu option to move to different monitor
    (bgo#633994).
  + Improve switch style in default/highContrast themes
    (bgo#746294, bgo#747912).
  + Make event highlight in calendar more prominent (bgo#747715).
  + Fix keyboard focus when focusing a notification banner
    (bgo#747205).
  + Move notification banners below the dateMenu (bgo#745910).
  + Bugs fixed: bgo#748338, bgo#748541.
* Thu Jul  2 2015 zaitor@opensuse.org
- Update to version 3.16.3:
  + Handle touch events in OSK on wayland (bgo#750287).
  + Bugs fixed: bgo#749383, bgo#749529, bgo#750714, bgo#751517,
    bgo#751541.
* Wed Jun 17 2015 cxiong@suse.com
- Add background-image-caching-fix.patch:
  Fix a bug in image caching that results in malfunction in
  background update (bnc#926800).
* Thu May 14 2015 zaitor@opensuse.org
- Update to version 3.16.2:
  + Make event highlight in calendar more prominent (bgo#747715).
  + Fix keyboard focus when focusing a notification banner
    (bgo#747205).
  + Move notification banners below the dateMenu (bgo#745910).
  + Increase visibility of expanders in alt-tab popup
    (bgo#745058).
  + Ensure suspend inhibitors are released when VT switched away
    (bgo#749228).
  + Misc. bug fixes.
  + Updated translations.
* Wed Apr 15 2015 dimstar@opensuse.org
- Update to version 3.16.1:
  + gdm: Move long session chooser menus to the side
    (bgo#734352).
  + Work around background corruption with NVIDIA driver
    (bgo#739178).
  + Don't allow move-to-workspace for always-sticky windows
    (bgo#746782).
  + Allow switching workspaces with PgUp/PgDown in overview
    (bgo#742581).
  + Bump time PAM messages are displayed (bgo#720885).
  + Fix "stutter" when moving window past the last workspace
    (bgo#712778).
  + Fix blurred text on login screen (bgo#746912).
  + keyboard: Restore whole MRU list after password mode
    (bgo#746605).
  + Pass event timestamps when activating remote actions
    (bgo#747323).
  + Fix hung login screen when password is typed too quickly
    (bgo#737586).
  + Make on-screen keyboard work for shell chrome on wayland
    (bgo#747274).
  + Implement reexec_self() for FreeBSD (bgo#747788).
  + Allow to dismiss resident notifications (bgo#746860).
  + Temporarily reveal legacy tray when icons are added
    (bgo#746025).
  + Make concealed tray smaller to minimize overlap with apps
    (bgo#746787).
  + Misc. bug fixes: bgo#746323, bgo#746579, bgo#746902,
    bgo#746364, bgo#746509, bgo#747636.
  + Updated translations.
* Tue Mar 31 2015 cxiong@suse.com
- Add dont-start-searchprovider-at-login.patch:
  + Inhibit autostart for search providers at login to have correct
    process hierarchy for Nautilus, which is essential for various
    environment vars and CWD setup (bnc#897153 bgo#708830).
* Mon Mar 23 2015 dimstar@opensuse.org
- Update to version 3.16.0:
  + Revert erroneous login dialog changes (bgo#740142).
  + Improve accessibility of legacy tray (bgo#746487).
  + Fix legacy status icons leaking into other monitors
    (bgo#745824).
  + Updated translations.
* Thu Mar 19 2015 cxiong@suse.com
- Move development tools to devel subpackage (bsc#881020).
* Wed Mar 18 2015 dimstar@opensuse.org
- Update to version 3.15.92:
  + gdm: Fix user list accessibility (bgo#729603).
  + Handle multiline questions in mount operations (bgo#745713).
  + Improve classic theme (bgo#745686, bgo#745687).
  + Fix ordering of calendar events (bgo#745988).
  + Pick first input source for new windows when per-window
    (bgo#746037).
  + networkAgent: Show a notification for non-user-initiated
    password requests (bgo#660293).
  + Fix dismissing calendar events (bgo#744927).
  + Add legacy tray to ctrl-alt-tab popup (bgo#746022).
  + Manage on-screen-keyboard visibility in gnome-shell
    (bgo#745977).
  + Add pointer barriers to legacy tray (bgo#746026).
  + Use fallback when app icon cannot be resolved (bgo#746219).
  + Fix handling of removed smartcard at startup (bgo#740143).
  + gdm: Don't pick a random session for the user (bgo#740142).
  + Make menu selection behavior consistent with GTK (bgo#745246).
  + gdm: Fix empty user list on user switching (bgo#719418).
  + Misc bug fixes: bgo#745666, bgo#746019, bgo#745861, bgo#746027,
    bgo#746223, bgo#737502, bgo#746343, bgo#746288.
  + Updated translations.
* Fri Mar  6 2015 hpj@suse.com
- Add gnome-shell-917489-only-set-scaling-factor-if-present.patch
  (bsc#917489). This prevents UI elements from being displayed
  squashed, jumbled or off-screen.
* Thu Mar  5 2015 dimstar@opensuse.org
- Update to version 3.15.91:
  + Don't disable all shortcuts while non-panel menus are open
    (bgo#745039).
  + Do not wake up the screen for disabled notifications
    (bgo#744114).
  + Add unminimize animation (bgo#702662).
  + Change default shortcut for viewing notifications (bgo#687986).
  + Add shortcut to dismiss notifications from list (bgo#745279).
  + Use Polari instead of Empathy for IRC conversations
    (bgo#745431).
  + Add a hideable bottom tray for legacy status icons
    (bgo#745162).
  + Improve accessibility of calendar/message list (bgo#706903,
    bgo#745393).
  + Fix window thumbnail scaling in overview (bgo#744883).
  + Stop handling non-chat notifications for Empathy (bgo#745503).
  + Fix mouse interaction with ibus candidate window (bgo#745167,
    bgo#745245).
  + Misc bug fixes and cleanups: bgo#677412, bgo#744880,
    bgo#744900, bgo#744894, bgo#744907, bgo#745061, bgo#741111,
    bgo#744912, bgo#745175, bgo#745246, bgo#744959, bgo#744575,
    bgo#745570, bgo#652742, bgo#659187, bgo#745412, bgo#745521,
    bgo#745521, bgo#741665, bgo#745574, bgo#745627, bgo#745494,
    bgo#745111, bgo#745132, bgo#745110.
  + Updated translations.
- Drop pkgconfig(caribou-1.0) BuildRequires: dropped upstream.
* Sat Feb 21 2015 dimstar@opensuse.org
- Update to version 3.15.90:
  + gdm: Fix reactivity of first user in user list (bgo#743370).
  + Prevent DND to dash when favorites are locked down
    (bgo#741325).
  + Prevent DND in app picker when favorites are locked down
    (bgo#741325).
  + Implement Display panel's OSD monitor labels in the shell
    (bgo#743744).
  + Remove GSystem dependency (bgo#744457).
  + Do not duplicate "New Window" action in dash (bgo#744446).
  + Fix 'draw-cursor' option of screen recorder (bgo#744599).
  + Fix screencast timestamps (bgo#744642).
  + Allow keybindings for switching to VT8-VT12 (bgo#744800).
  + Implement notification redesign (bgo#744498, bgo#744815,
    bgo#744817, bgo#744850).
  + Fix struts computation of chrome on non-primary monitors
    (bgo#744183).
  + Visual refresh based on GTK+ theme redesign (bgo#737785,
    bg0#744680).
  + Misc. bug fixes and cleanups: bgo#743371, bgo#736182,
    bgo#744013, bgo#743993, bgo#744665.
  + Updated translations.
* Mon Feb 16 2015 fcrozat@suse.com
- Add gnome-shell-calendar-fix-week-number.patch : Fix week number
  computation (bgo#736722 bsc#916534 boo#918046).
* Fri Feb  6 2015 mgorse@suse.com
- Move Evolution calendar support to a separate subpackage
  gnome-shell-calendar, allowing to install GNOME Shell without any
  dependency on evolution-data-server.
- Replaces Requires: evolution-data-server by Recommends:
  gnome-shell-calendar and add a Supplements between
  gnome-shell-calendar and evolution-data-server.
- Lower dependency on NetworkManager-gnome from Requires to
  Recommends, for users who don't want to use NM.
* Thu Jan 29 2015 dimstar@opensuse.org
- Drop --with-nmlibexecdir and --disable-schemas-install configure
  parameters: they are no longer supported.
* Fri Jan 23 2015 zaitor@opensuse.org
- Update to version 3.15.4:
  + Add mode parameter to AcceleratorActivated signal (bgo#711682).
  + Fix PID based window/app association (bgo#736527).
  + Fix current day highlight on day change (bgo#742492).
  + Switch to vp9 for screencast recordings (bgo#742744).
  + Disable IBus input sources on password entries (bgo#730628).
  + Make slider scrolling smoother (bgo#742648).
  + Allow move-up shortcut to move window above top workspace
    (bgo#665764).
  + Misc. bug fixes (bgo#742748, bgo#742824, bgo#741114).
  + Updated translations.
* Fri Dec 19 2014 zaitor@opensuse.org
- Update to version 3.15.3:
  + Add support for high-contrast themes (bgo#740447).
  + Fix banner message on login screen without user list
    (bgo#703972).
  + Fix flicker when activating windows on another workspace
    (bgo#741680).
  + Misc. bugfixes: bgo#735308, bgo#740237.
  + Updated translations.
* Fri Dec 19 2014 zaitor@opensuse.org
- Update to version 3.15.2:
  + Fix visual glitch of window preview outline in overview
    (bgo#699044).
  + Change user facing name of "Captive Portal" to "Network Login"
    (bgo #737198).
  + Port to Python 3 (bgo#732478)
  + Hide Airplane mode indicator when g-s-d says so (bgo #736292),
  + Allow translators to change non-work days (bgo#664645).
  + Delay invocation of caribou daemon until really needed
    (bgo#739712).
  + Don't lock screen after crash if locking is disabled
    (bgo#704884).
  + Improve layout of extension installation dialog (bgo#739888).
  + Fix workspace changes from app picker (bgo#737534).
  + Preload all ibus input sources in user configuration
    (bgo#695428).
  + Properly remove network connections from list (bgo#740227).
  + Support CSS margin property (bgo#728437).
  + Improve handling of BUSY application state (bgo#736492).
  + Fix erroneous week numbers in calendar (bgo#736722).
  + Misc. bugfixes and cleanups: bgo#738725, bgo#739497,
    bgo#739241, bgo#672500, bgo#739822, bgo#740074, bgo#704163,
    bgo#740141.
  + Updated translations.
- Add python(abi) >= 3 BuildRequires: Following upstreams port to
  python 3.
- Drop gnome-shell-fix-week-count.patch: fixed upstream.
* Fri Dec 19 2014 zaitor@opensuse.org
- Update to version 3.15.1:
  + Use GResources for theme loading (bgo#736936).
  + Reset the OSK to primary on monitor changes (bgo#738536).
  + Use LC_TIME locale for format string translations (bgo#738640).
* Fri Dec 19 2014 zaitor@opensuse.org
- Update to version 3.14.3:
  + Properly remove network connections from list (bgo#740227).
  + Fix handling of cancel button on login screen (bgo#740141).
  + Fix build when using dash as default shell (bgo#739241).
  + Make event list in calendar scrollable (bgo#705115).
  + Fix calendar-server crash on DBus timeout (bgo#735308).
  + Fix gestures triggering erroneously (bgo#740237).
- Add gnome-shell-fix-week-count.patch: Fix week count in top-bar
  calendar; patch taken from upstream git master and edited to
  apply cleanly against current version (bgo#736722, boo#910069).
* Wed Nov 12 2014 zaitor@opensuse.org
- Update to version 3.14.2:
  + Do not hard-depend on latest NetworkManager (bgo#738485).
  + Fix check for isToday in calendar (bgo#738725).
  + Fix workspace changes from app picker (bgo#737534).
  + Misc. bug fixes (bgo#739497).
* Wed Oct 29 2014 dliang@suse.com
- Add gnome-shell-lock-bg-on-primary.patch:
  the background on lock(login) screen will always display on the
  primary screen (bnc#894050).
* Wed Oct 15 2014 dimstar@opensuse.org
- Update to version 3.14.1:
  + Fix pulse animation for scrolled app folders (bgo#736885).
  + Fix updating background on file changes (bgo#710756).
  + Obtain keyboard variant from IBus (bgo#735066).
  + Implement Ctrl-u / Ctrl-k keybindings in entries (bgo#737346).
  + Pass VPN hints to auth dialog (bgo#737592).
  + Only allow one screenshot request at a time (bgo#737456).
  + Respect disable-save-to-disc lockdown setting (bgo#737846).
  + Respect scaling-factor for profile pictures (bgo#735419).
  + Focus login screen after lifting the lock screen shield
    (bgo#708105).
  + Speed up pulse animation for few items (bgo#737017).
  + Fix gap between workspace switcher and screen edge
    (bgo#728899).
  + Disable unredirection during recordings (bgo#738226).
  + Ensure there's always at least one input source (bgo#738303).
  + Restrict width of dash icons' context menus (bgo#738054).
  + Misc. bug fixes: bgo#736999, bgo#737382, bgo#737001,
    bgo#738314, bgo#738256, bgo#738147.
  + Updated translations.
* Sun Oct  5 2014 dimstar@opensuse.org
- Rebase and re-enable gnome-shell-private-connection.patch
  (boo#899789).
* Tue Sep 23 2014 dimstar@opensuse.org
- Update to version 3.14.0:
  + Fix exposure of the accessible tree (bgo#736821).
  + Hide empty app folders in app picker (bgo#736910).
  + Updated translations.
* Wed Sep 17 2014 dimstar@opensuse.org
- Update to version 3.13.92:
  + Fix submenu arrow animations (bgo#728927).
  + Always initialize clutter accessibility (bgo#735908).
  + Adapt to mutter background changes (bgo#735638).
  + Improve handling of outOfDate extensions in prefs (bgo#736185).
  + Port offline updates to PackageKit's DBus interface
    (bgo#736337).
  + location: Translate accuracy levels for geoclue (bgo#736479).
  + Implement input source switching (bgo#736435).
  + Fix crash when dragging window from workspace switcher
    (bgo#735972).
  + Clean out list of default favorites (bgo#735682).
  + Add settings link to location submenu (bgo#736542).
  + Fix keynav of message tray menu button (bgo#707799).
  + Misc. bug fixes: bgo#736110, bgo#736329, bgo#736343,
    bgo#735927, bgo#735976.
  + Updated translations.
* Mon Sep  8 2014 dimstar@opensuse.org
- Update to version 3.13.91:
  + Fix keynav into session menu on login screen (bgo#735614).
  + Add gesture to summon message tray (bgo#735625).
  + Accept scrolls/swipes either way on the screen shield
    (bgo#734874).
  + Animate opening the app picker and improve app folder
    animations (bgo#734726).
  + Animate app icons on launching a new window (bgo#734726).
  + Show the on-screen keyboard when touch input is being used
    (bgo#702015).
  + Bugs fixed: bgo#735190, bgo#735385, bgo#735608, bgo#735681.
  + Updated translations.
* Thu Sep  4 2014 cxiong@suse.com
- Add gnome-shell-sle-multiple-fixes.patch.
  + NOTE: this commit work with relevant changes in
    'gnome-shell-extensions'.
  + Restoring xsettings.overrides, which get set by SLE-Classic
    extension (bnc#894048).
  + Change the message tray positioning to adapt to fullscreen
    situation (bnc#891560).
* Mon Aug 25 2014 cxiong@suse.com
- Add vpn-indicator-and-menu-general-fix.patch:
  + Fix multiple issues with current VPN indicator and menus.
  + Fix crash issue (bnc#890855).
  + Backport VPN settings menu entry from upstream.
  + Fix menu status and indicator: they behave very weird under
    some circumstances. The patch offers a solution, though it
    somehow limits user actions.
* Wed Aug 20 2014 dimstar@opensuse.org
- Update to version 3.13.90:
  + Make use of GLSL optional (bgo#733623).
  + Update on-screen-keyboard position on monitor changes
    (bgo#733790).
  + Improve window manager animations (bgo#732857).
  + Handle touch events (bgo#733633).
  + Try to not show "New Window" action for single-window apps
    (bgo#722554).
  + Fix overview exceeding screen size with many apps installed
    (bgo#723496).
  + Add Software to default favorites (bgo#734406).
  + Improve app picker <-> desktop transition (bgo#732901).
  + Remove <shift>-magic for switcher popups (bgo#732296).
  + Add a special background to use for performance testing
    (bgo#734610).
  + Add support for default disabled search providers (bgo#734110).
  + Fix portals that don't redirect properly (bgo#733848).
  + Fix history trimming in chat notifications (bgo#733899).
  + Try to use default calendar application (bgo#722333).
  + Only show location menu when geolocation is in use
    (bgo#731122).
  + Misc. bug fixes and cleanups: bgo#711682, bgo#733840,
    bgo#734483, bgo#734680, bgo#733813, bgo#735062.
  + Updated translations.
* Fri Aug  8 2014 sbrabec@suse.cz
- Mark translatable strings in gnome-shell-domain.patch
  (bnc#877728, refreshed gnome-shell-prompt-twice.patch).
- Add support for gnome-patch-translation.
- Move autoreconf to %%build.
* Thu Aug  7 2014 dimstar@opensuse.org
- Remove build_wayland_backend conditions: the wayland backend is
  regularly built now.
* Thu Jul 31 2014 dliang@suse.com
- Add gnome-shell-hostname-refresh.patch:
  keep tracking of the hostname change (bnc#888806).
* Wed Jul 23 2014 dimstar@opensuse.org
- Update to version 3.13.4:
  + Handle portal login requests (bgo#704416).
  + Scale fonts on wayland on hiDPI devices (bgo#732537).
  + Fix default ibus candidate index labels (bgo#702944).
  + Add gestures for various system actions.
  + Add performance test script for the perf.gnome.org
    (bgo#732350).
  + Use new restart framework to improve restart visuals
    (bgo#733026).
  + Improve keynav in app folder popups (bgo#731477).
  + Fix truncation of app search results (bgo#732416).
  + Automatically update renamed desktop files in favorites
    (bgo#729429).
  + Misc. bug fixes and cleanups: bgo#729823, bgo#726401,
    bgo#732301, bgo#732348, bgo#732349, bgo#733498, bgo#733540.
  + Updated translations.
* Tue Jul 22 2014 dliang@suse.com
- Add gnome-shell-background-image-change.patch (bnc#879178)
  + add animation list to cache animiations
  + use collect image when resolution changes
* Sat Jul 12 2014 dimstar@opensuse.org
- Update to version 3.13.3:
  + Don't allow closing windows with attached modals (bgo#729886).
  + Fix self-restarting on OpenBSD (bgo#727763).
  + Improve behavior of window buttons with compositor menus
    (bgo#731058).
  + Work around atspi-related performance regression (bgo#730118).
  + Misc bug fixes and cleanups: bgo#728271, bog#726460,
    bgo#703833, bgo#731118, bgo#731220, bgo#695487, bgo#730527,
    bgo#728170, bgo#731619, bgo#731738, bgo#731882, bgo#731923.
- Changes from version 3.13.2:
  + Don't always extend struts to the screen edge (bgo#683819).
  + Implement window menus in the shell (bgo#726352).
  + Support resource:// URLs in GNOME_SHELL_JS envvar (bgo#730409).
  + Fix switcher popups with keybindings containing Escape
    (bgo#730739).
  + Update extension-prefs UI to follow GNOME 3 patterns
    (bgo#730829).
  + Add support for fallback app menu in window decorations
    (bgo#730752).
  + Fix keynav escaping open app folders (bgo#726760).
  + Misc. bug fixes: bgo#729429, bgo#728449, bgo#730408,
    bgo#730753, bgo#730653.
- Changes from version 3.13.1:
  + Add shortcuts for switching to the last workspace (bgo#659288).
  + Show OSD window on all monitors (bgo#722684).
  + Improve consistency of labels in network menu (bgo#727163).
  + Fix zombie search providers showing up (bgo#728597).
  + Remove ConsoleKit support (bgo#686626).
  + Fix region screenshots with open shell menus (bgo#709126).
  + Support <shift>insert in text entries (bgo#648318).
  + Improve app picker scrolling on touch (bgo#729064).
  + Don't make date button clickable when on current date
    (bgo#726724).
  + Tweak heuristic for hiding workspace switcher (bgo#662457).
  + Add option to show in Software to app context menu
    (bgo#643043).
  + Misc. bug fixes and cleanups: bgo#727983, bgo#727948,
    bgo#728512, bgo#728681, bgo#728897, bgo#727384, bgo#728820,
    bgo#715042, bgo#728449, bgo#728343.
  + Updated translations.
- Drop pkgconfig(mutter-plugins) BuildRequires: no longer required.
- Drop gnome-icon-theme-symbolic Requires: no longer required.
* Fri Jul 11 2014 cxiong@suse.com
- Add add-some-indicating-text-to-logout-menu.patch
  + add some indicating text to logout menu, see (bnc#886569).
    Also see the discussions in bnc#862615.
* Tue Jul  8 2014 cxiong@suse.com
- Add endSession-dialog-update-time-label-every-sec.patch
  + update time label every second in end session dialog
    (bnc#886132).
* Wed Jul  2 2014 cxiong@suse.com
- Add login-prompt-preserve-session-choice.patch
  + Preserve user-chosen session while in the same verification
    session (bnc#870560)
* Thu Jun 12 2014 cxiong@suse.com
- Move some development tools to devel subpackage (bnc#881020).
* Thu Jun  5 2014 dliang@suse.com
- Add gnome-shell-screen-disappear.patch to fix bnc#870217
* Thu Jun  5 2014 dliang@suse.com
- Add gnome-shell-sle-theme.patch and SLE-theme.tar.gz
  to make a sle style login window
* Fri May 30 2014 dliang@suse.com
- Add gnome-shell-878951-hide-list-with-no-user.patch (bnc#878951)
  Hide the userlist when there is no user listed
* Thu May 22 2014 mgorse@suse.com
- Add gnome-shell-874712-use-upower-directly.patch: fix status
  icon not updating (bnc#874712).
* Sat May 17 2014 zaitor@opensuse.org
-  Update to version 3.12.2:
  + Fix turning off airplane mode (bgo#728512).
  + Handle empty VPN keyfiles (bgo#728681).
  + Fix setting zero-level in osdWindow (bgo#727384).
  + Fix removal of multiple workspace thumbnails at once
    (bgo#728820).
  + Make airplane mode menu insensitive in lock screen
    (bgo#729224).
  + Fix keynav for alternatives in AltSwitcher (bgo#727259).
  + Fix zombie search providers showing up (bgo#728597).
  + Updated translations.
* Mon May 12 2014 dliang@suse.com
- Added patch:
  * gnome-shell-login-focus-lost.patch (bnc#869127)
* Wed Apr 30 2014 dliang@suse.com
- Added patch:
  * gnome-shell-prompt-twice.patch (bnc#871865)
* Wed Apr 23 2014 dliang@suse.com
- Add gnome-shell-right-bg-with-resolution-change.patch (bnc#873216)
  Backport from upstream: update to commit (4cfb000812).
* Wed Apr 16 2014 cxiong@suse.com
- Backport wired connection status from GNOME 3.12
  + Add wired-connection-status.patch
    Relevant upstream commits ids (listed in chronological order):
    3432f715008ca9577daa9bb6297a3430a360002c
    fe7ece1f5a8fb7616fec29422fee5694e1f22778
    bde1451896c3329d49100933cf3202d128f07e7b
    c4aeaf7fe81c31abec5e0dcebbd1243e888efccd
    7051411be7bbfd9e0c2e831762c87872e5bde468
    NOTE: small modifications are made when applying these patche
    s. Also this "backport" has the following differences from
    GNOME 3.12:
    1. Use the 3.8-version wired connection icons as they are
    already in the system.
    2. Without other network connections, disconnected wired is
    always displayed instead of hiding it as in 3.12.
    3. Cable unplugged as a status is shown explicitly in system
    menu instead of hiding the whole wired section as in
    upstream. The status text is also changed to be "cable
    unplugged" instead of the generic "unavailable".
  + Change the place where SLEClassicExt.js is loaded to avoid
    dependency issue.
* Wed Apr 16 2014 dimstar@opensuse.org
- Update to version 3.12.1:
  + Ensure the currently focused app icon is viewable (bgo#726759).
  + Improve language in location menu (bgo#726498).
  + Improve HiDpi support (bgo#726907).
  + Set accessible role for window previews (bgo#726670).
  + Fix bad antialiasing on panel menu buttons (bgo#727336).
  + Don't hide location menu (bgo#727398).
  + Fix IM candidate window obscuring current text (bgo#727579).
  + Fix extension-prefs tool when linked with --as-needed
    (bgo#727948).
  + Don't always extend struts to the screen edge (bgo#663690).
  + Updated translations.
* Tue Apr 15 2014 dimstar@opensuse.org
- Add wayland support (conditional, based on build_wayland_backend
  defines, currently set to 0 - disabled):
  + Add pkgconfig(libmutter-wayland) BuildRequires.
  + Create gnome-shell-wayland subpackage.
* Wed Apr  9 2014 dliang@suse.com
- Update gnome-shell-domain.patch (bnc#872568)
  Change the default domain separator in hint message: '/' -- '\'.
* Wed Apr  2 2014 cxiong@suse.com
- Fix left/right arrow direction
  left/right arrow direction should not be affected by session mode.
  A continued improvement on (bnc#862615).
* Fri Mar 28 2014 cxiong@suse.com
- Add GNOME Shell patch to implement SLE Classic Mode
  Mainly implements conditional arrow directions and conditional
  task panel positioning atm.
  Needed for the SLE Classic Mode to work in
  "gnome-shell-extension".
  + Add SLEClassicExt.js
  + Add sle-classic-ext.patch
* Wed Mar 26 2014 zaitor@opensuse.org
- Update to version 3.12.0:
  + gdm: Reset greeter when coming back to login screen
    (bgo#726989).
  + Updated translations.
* Wed Mar 26 2014 dliang@suse.com
- Add gnome-shell-defer-loading-userlist.patch:
  load the user list until it is needed (bnc#869127, bgo#725905).
- Update gnome-shell-gdm-login-applet.patch:
  remove the 'Welcome' prefix.
* Thu Mar 20 2014 dimstar@opensuse.org
- Update to version 3.11.92:
  + calendar: Grab key focus after changing day (bgo#725606).
  + gdm: Don't load user list if disabled (bgo#725905).
  + Don't show network-offline in the top bar (bgo#725340).
  + Improve radial shade effect of modal dialogs (bgo#725830).
  + Fix broken suspend-on-idle functionality (bgo#712706).
  + Close wifi selection dialog when device disappears
    (bgo#723935).
  + Don't close chats when pressing Escape (bgo#724178).
  + Improve smartcard support in login/lock screen (bgo#726262,
    bgo#726263).
  + Wake up screen when resuming from suspend (bgo#726378).
  + Make bluetooth and location items insensitive when locked
    (bgo#726319).
  + Don't show bluetooth icon when there is no adapter
    (bgo#725057).
  + Make sure to keep the OSK on top of modal dialogs (bgo#719451).
  + Misc. bug fixes and cleanups: bgo#725832, bgo#725958,
    bgo#722149, bgo#724977, bgo#724798, bgo#725020, bgo#723976,
    bgo#726119, bgo#726238, bgo#585500, bgo#704844, bgo#726323,
    bgo#726322, bgo#726120, bgo#726414.
  + Updated translations.
* Tue Mar 11 2014 cxiong@novell.com
- Add gnome-shell-use-env-var-for-mode.patch:
  Use Environment variable instead of command line to specify mode
  so that the session saving can work as expected (bnc#863709,
  bgo#720894).
* Mon Mar 10 2014 dliang@suse.com
- Add gnome-shell-864872-unlock-by-mouse-motion.patch:
  Unlock the screen and turn to the user login interface
  when mouse moved over 100 pixels (bnc#864672).
* Thu Mar  6 2014 dimstar@opensuse.org
- Update to version 3.11.91:
  + Don't use network profile name in menu (bgo#725586).
  + Calendar: Make date label clickable to return to current date
    (bgo#641366).
  + Misc. bug fixes: bgo#724813, bgo#724686, bgo#725082,
    bgo#724870, bgo#724779, bgo#725533.
  + Updated translations.
* Wed Feb 26 2014 fcrozat@suse.com
- Update gnome-shell-gdm-login-applet.patch and
  gnome-shell-domain.patch to properly patch Makefile.am.
- Add autoconf/automake/gnome-common as BuildRequires, needed for
  gnome-shell-gdm-login-applet.patch and gnome-shell-domain.patch.
* Tue Feb 25 2014 dliang@suse.com
- Add gnome-shell-domain.patch to better support AD domain.
  (fate#307773)
* Thu Feb 20 2014 zaitor@opensuse.org
- Update to version 3.11.90:
  + Stop showing two bluetooth entries (bgo#709353).
  + Improve styling of login/lock screen (bgo#723833).
  + Fix magnifier crosshairs (bgo#723709).
  + Make NetworkManager support optional (bgo#669495).
  + Make middle-click open a new instance (bgo#695010).
  + Scale the UI on high resolution displays (bgo#705410,
    bgo#724607).
  + Remove notification counter on screen shield (bgo#709275).
  + Improve app picker transition (bgo#722331).
  + Add geolocation indicator to status menu (bgo#723684).
  + Improve timestamps in chat notifications (bgo#708031,
    bgo#715158).
  + Improve network menus (bgo#723570).
  + Add "VPN Setting" item to VPN submenu (bgo#709167).
  + Improve appearance of disclosure arrows (bgo#720206).
  + Add GSetting key to disable version validation of extensions
    (bgo#724683).
  + Delay auto-removing empty workspaces (bgo#709064).
  + Offer offline updates in the shutdown dialog (bgo#722898).
  + Animate tile previews (bgo#665758).
  + Bugs fixed: bgo#709128, bgo#722342, bgo#723661, bgo#724184,
    bgo#724256, bgo#724293, bgo#724305, bgo#722554, bgo#724282,
    bgo#724690, bgo#722928.
  + Updated translations.
* Thu Feb 20 2014 dimstar@opensuse.org
- Update to version 3.11.5:
  + Fix extension preference tool (bgo#722334).
  + Fix keyboard activation of legacy tray icons (bgo#721267).
  + Add radial background shade for modal dialogs (bgo#669798).
  + Show attached modal windows in the overview (bgo#650843).
  + Add support for desktop actions (bgo#669603).
  + Indicate in system status when location service is used
    (bgo#709372).
  + Add support for extended app folder schema (bgo#723179).
  + Show status icon for wired network connections (bgo#708966).
  + Indicate airplane mode in network selection dialog
    (bgo#709128).
  + Misc bug fixes and cleanups: bgo#722417, bgo#722494,
    bgo#722547, bgo#722593, bgo#722434, bgo#722787, bgo#722690,
    bgo#722840, bgo#722660, bgo#722812, bgo#723197, bgo#722927,
    bgo#723306, bgo#723308, bgo#723523, bgo#709685, bgo#723570.
  + Updated translations.
- Disable gnome-shell-private-connection.patch: needs rebase.
* Thu Feb 20 2014 zaitor@opensuse.org
- Update to version 3.11.4:
  + Fix removal of workspacaes that are not at the end
    (bgo#721417).
  + Allow session mode to be specified in the environment
    (bgo#720894).
  + Special-case launching of terminals (bgo#695010).
  + Always show arrow if app switcher is scrollable (bgo#711467).
  + Implement new app folders system (bgo#722117).
  + Remove arrow from background menu (bgo#699608).
  + Misc bug fixes and cleanups (bgo#721039, bgo#721439,
    bgo#721507, bgo#721629, bgo#721868, bgo#722210).
  + Updated translations.
* Thu Feb 20 2014 dimstar@opensuse.org
- Update to version 3.11.3:
  + Fix fade effect of desktop icons (bgo#707671).
  + Fix issues with background management code (bgo#709313).
  + Use new Glib facilities for application search (bgo#711631).
  + Add focus indication to session menu button (bgo#710539).
  + Fix hover tracking for StEntries (bgo#706749).
  + Fix reentrancy issue in message tray (bgo#711694).
  + Tone down zoom animation on login/unlock (bgo#712362).
  + Allow specifying monitor for OSD (bgo#712664).
  + Fix resetting prompt on user switch (bgo#710456).
  + Stop using gnome-bluetooth-applet (bgo#719341).
  + Add support for EAP-FAST password requests (bgo#719813).
  + Fix entry focus of chat notifications (bgo#709853).
  + Make window previews keyboard navigatable (bgo#644306).
  + Fix app switcher order with dialog windows (bgo#719824).
  + Allow remote search providers without icons (bgo#719965).
  + Fix various alignment issues in RTL locales (bgo#712638,
    bgo#712596, bgo#712594, bgo#712600, bgo#712579).
  + Misc. bug fixes and cleanups: bgo#712727, bgo#712753,
    bgo#719378, bgo#719730, bgo#719803, bgo#710115, bgo#720017,
    bgo#719815, bgo#719567, bgo#720298.
  + Updated translations.
- Drop gnome-shell-tray-reentrant.patch: fixed upstream.
- Drop gnome-shell-hidepassword.patch: fixed upstream.
* Thu Feb 20 2014 dimstar@opensuse.org
- Update to version 3.11.2:
  + Cache search result display actors (bgo#704912).
  + Use username in userWidget if real name doesn't fit
    (bgo#706851).
  + Support shell_global_reexec_self() on OpenBSD (bgo#709571).
  + Support disabling browser plugin (bgo#711218).
  + Restore support for 'disable-restart-buttons' (bgo#711244).
  + Validate parameters of exposed DBus methods (bgo#699752).
  + Connect applications to systemd journal if available
    (bgo#711626).
  + Misc bug fixes and cleanups: bgo#711205, bgo#698486,
    bgo#711416, bgo#644306, bgo#711555, bgo#709806, bgo#711631,
    bgo#711732.
  + Updated translations.
- Drop gnome-shell-extensions-disabling.patch: fixed upstream.
* Thu Feb 20 2014 dimstar@opensuse.org
- Update to version 3.11.1:
  + power: Use UPower directly instead of gnome-settings-daemon
    (bgo#710273).
  + Implement support for new GTK+ notification API (bgo#710137,
    bgo#710596).
  + gdm: Don't allow user-list to fill up the entire screen
    (bgo#710555).
  + Don't autostart remote search providers at login (bgo#708830).
  + Fix spacing in end-session dialog (bgo#710543).
  + Prepare for js24 (bgo#711052).
  + Misc bug fixes and cleanups: bgo#710347, bgo#710144,
    bgo#710541, bgo#691409, bgo#710745, bgo#688331, bgo#704912.
  + Updated translations.
- Add gcc-c++ BuildRequires: gnome-js was ported to C++.
* Thu Feb 20 2014 zaitor@opensuse.org
- Update to version 3.10.4:
  + Fix keyboard activation of legacy tray icons (bgo#721267).
  + Fix regressions from window-tracking changes in 3.10.3
    (bgo#722434, bgo#722690, bgo#722840, bgo#723308, bgo#722928).
  + Scale UI on high-resolution displays (bgo#705410).
  + Bugs fixed: bgo#722547, bgo#723197, bgo#724256).
  + Updated translations.
* Tue Feb 18 2014 dliang@suse.com
- Add gnome-shell-gdm-login-applet.patch to display suse icon,
  product name, hostname on an applet in the login interface
  (bnc#855739, fate#314545).
* Thu Feb 13 2014 fcrozat@suse.com
- Move Evolution calendar support to a separate subpackage
  gnome-shell-calendar, allowing to install GNOME Shell without any
  dependency on evolution-data-server.
- Replaces Requires: evolution-data-server by Recommends:
  gnome-shell-calendar and add a Supplements between
  gnome-shell-calendar and evolution-data-server.
- Lower dependency on NetworkManager-gnome from Requires to
  Recommends, for users who don't want to use NM.
* Sat Jan 18 2014 zaitor@opensuse.org
- Update to version 3.10.3:
  + Fix reentrancy issue in message tray (bgo#711694).
  + Fix resetting prompt on user switch (bgo#710456).
  + Fix screen shield on login screen (bgo#719378).
  + Catch more extension errors on enable/disable (bgo#688331).
  + Fix entry focus of chat notifications (bgo#709853).
  + Fix app switcher order with dialog windows (bgo#719824).
  + Allow remote search providers without icons (bgo#719965).
  + Fix ref-counting issue in ShellApp (bgo#721439).
  + Updated translations.
- Drop gnome-shell-hidepassword.patch,
  gnome-shell-extensions-disabling.patch and
  gnome-shell-tray-reentrant.patch, fixed upstream.
* Wed Nov 27 2013 dimstar@opensuse.org
- Add gnome-shell-hidepassword.patch: authPrompt: propagate gdm
  "reset" signal after user switching. Fixed GDM showing showing
  passwords on user switching (bnc#852490, bgo#710456).
- Add gnome-shell-extensions-disabling.patch: catch more errors on
  extensions enable() and disable(). Fixes gnome-shell extensions
  disabled on screen unlock (bnc#852527, bgo#688331, bgo#719378).
- Add gnome-shell-tray-reentrant.patch: messageTray: Prevent
  reentrancy issues in _updateState (bgo#711694).
* Fri Nov 15 2013 dimstar@opensuse.org
- Update to version 3.10.2.1 (bnc#849913):
  + Lower mutter requirement to not end up without wayland support.
* Thu Nov 14 2013 dimstar@opensuse.org
- Update to version 3.10.2 (bnc#849913):
  + gdm: Don't allow user-list to fill up the entire screen
    (bgo#710555).
  + Restore support for 'disable-restart-buttons' (bgo#711244).
  + Validate parameters of exposed DBus methods (bgo#699752).
  + Misc. bug fixes: bgo#709806.
  + Updated translations.
* Mon Oct 21 2013 dimstar@opensuse.org
- Drop gnome-shell-no_clear_hint.patch: we found a better
  workardound that even results in the loading of the background
  image. The code is of course not fixed.
- Create /usr/share/gnome-shell/modes: by this, the erronous code
  path is not being triggered, likely due to async calls happening
  in the expected order. It even results in loading the branded
  background image (and explains why users with gnome-shell-classic
  installed never saw this).
* Fri Oct 18 2013 dimstar@opensuse.org
- Add gnome-shell-no_clear_hint.patch: Work around refresh issues.
  This is not the final solution; the wallpaper is often not
  loaded, but at least it stops the screen from flickering wildly,
  giving a much less broken experience (bgo#709313, bnc#844891).
* Wed Oct 16 2013 dimstar@opensuse.org
- Update to version 3.10.1:
  + Make sure lock screen is drawn once before switching user
    (bgo#708051).
  + Fix signal strength indicators in network selector
    (bgo#708442).
  + Scroll search results when focusing provider icons
    (bgo#708868).
  + Add separate hover/active states to page indicators
    (bgo#708852).
  + Tweak appearance of user name and avatar (bgo#702309).
  + Hide "Turn On" in network menu when disabled by hardware
    (bgo#709635).
  + Cancel open keyring prompts when the screen is locked
    (bgo#708910).
  + Differentiate "Not Connected" and "Off" in network menu
    (bgo#709043).
  + Make network settings items point to the right device
    (bgo#709246).
  + Remove animation of window preview titles (bgo#709392).
  + Add 'Notifications' switch to tray menu (bgo#707073).
  + Make dropdown arrows consistent (bgo#709564).
  + power: Use icon from primary device for status (bgo#709925).
  + Fix XDND drags to overview (bgo#708887).
  + Fix workspace switcher disappearing with too many workspaces
    (bgo#694881).
  + Handle search results with 'special:' prefix specially
    (bgo#707055).
  + gdm: Support pre-authenticated logins from oVirt (bgo#702162).
  + Use ARROW role for labels representing arrows (bgo#710120).
  + Make selected view in app picker persistent (bgo#710042).
  + Make network selector navigable by keyboard (bgo#710144).
  + Misc bug fixes: bgo#709034, bgo#709263, bgo#698486,
    bgo#709286, bgo#709248, bgo#709543, bgo#696564, bgo#703265,
    bgo#709638, bgo#709866, bgo#709998, bgo#710019, bgo#710104,
    bgo#710115.
  + Updated translations.
- Rebease gnome-shell-private-connection.patch (Gary Lin).
* Wed Oct  2 2013 glin@suse.com
- Rebase gnome-shell-private-connection.patch (bnc#751211)
* Tue Sep 24 2013 dimstar@opensuse.org
- Update to version 3.10.0.1:
  + Fix login screen (bgo#708691).
* Tue Sep 24 2013 dimstar@opensuse.org
- Update to version 3.10.0:
  + Fix fade effect in ScrollViews (bgo#708256).
  + network: Resync when activating connection changes
    (bgo#708322).
  + Close run dialog when the screen locks (bgo#708218).
  + Fix entry growing out of password dialogs (bgo#708324,
    bgo#703833).
  + Vertically center labels in submenu items (bgo#708330).
  + Fix bluetooth icon not being added to status menu
    (bgo#708541).
  + Fix GNOME 2 keyring dialogs appearing on lock screen
    (bgo#708187).
  + Fix passwords being cleared twice when authentication fails
    (bgo#708186).
  + Fix message tray appearing in a11y popup on login screen
    (bgo#708380).
  + Increase width of aggregate menu popup (bgo#708472).
  + Other bugs fixed: bgo#708387.
  + Updated translations.
* Tue Sep 17 2013 dimstar@opensuse.org
- Update to version 3.9.92:
  + Don't show page indicators if there's only one page
    (bgo#707363).
  + Make :active style of app and non-app results consistent
    (bgo#704714).
  + Fade app pages when scrolled (bgo#707409).
  + Don't block scrolling on page indicators (bgo#707609).
  + Tweak visual appearance of folder views (bgo#707662).
  + Don't put minimized apps at the end of the app switcher
    (bgo#707663).
  + Merge the wayland branch (bgo#707467).
  + Make search entry behave better in RTL locales (bgo#705779).
  + Allow to change app pages with pageUp/pageDown keys
    (bgo#707979).
  + Set approriate a11y states on expandable menu items
    (bgo#708038).
  + Improve page indicator animation (bgo#707565).
  + Misc bug fixes and cleanups: bgo#707308, bgo#707430,
    bgo#707508, bgo#707557, bgo#707600, bgo#707614, bgo#707666,
    bgo#707814, bgo#707806, bgo#707801, bgo#707889, bgo#707892,
    bgo#707935, bgo#707842, bgo#707940, bgo#707996, bgo#708007,
    bgo#708009, bgo#708020, bgo#707580, bgo#708080.
  + Updated translations.
* Tue Sep  3 2013 dimstar@opensuse.org
- Update to version 3.9.91:
  + Improve submenu styling (bgo#706037).
  + Fix changing slider values via keyboard (bgo#706386).
  + Fix accessibility of sliders (bgo#706391).
  + Tweak system actions style (bgo#706638).
  + Add support for auth without username / fix Not Listed?
    (bgo#706607).
  + Dash: Don't show tooltips for apps with open popups
    (bgo#705611).
  + Implement new end-session/power-off dialog design (bgo#706612).
  + Implement building separate binaries for x11 and wayland
    (bgo#705497).
  + authPrompt: Fix controls moving when showing messages
    (bgo#706670).
  + Tweak padding between system status icons (bgo#706796).
  + Add a generic accessible usable by JS code (bgo#648623).
  + Improve keynav and accessibility of the calendar (bgo#706903).
  + Update to new NetworkManager APIs (bgo#706098).
  + Hide system actions section in the lock screen (bgo#706852).
  + Don't show other logged in users at log out (bgo#707124).
  + Remove "Session" subtitle heading in login dialog (bgo#707072).
  + dash: Reload favorites when installed apps change (bgo#706878).
  + Don't open overview after closing last window on workspace
    (bgo#662581).
  + Add FocusApp DBus method (bgo#654086).
  + Add ShowApplications DBus method (bgo#698743).
  + Implement new app picker design (bgo#706081).
  + Improve frequent apps being empty by default (bgo#694710).
  + Extend clickable area of page indicators (bgo#707314).
  + Misc bug fixes: bgo#706542, bgo#706654, bgo#706005,
    bgo#706681, bgo#706841, bgo#706843, bgo#707064, bgo#706262,
    bgo#707197, bgo#707269.
  + Updated translations.
* Thu Aug 22 2013 dimstar@opensuse.org
- Update to version 3.9.90:
  + workspaceThumbnails: Exclude transient windows when shifting
    workspaces (bgo#705174).
  + Never show a horizontal scrollbar on lock screen (bgo#704327).
  + authPrompt: Fix disable-user-list / Not Listed? (bgo#705370).
  + Animate the lock screen notification transitions (bgo#687660).
  + Wake up the screen when new notifications appear (bgo#703084).
  + Use StartupWMClass for application matching (bgo#673657,
    bgo#705801).
  + dateMenu: Add style class for the clock label (bgo#705634).
  + keyboard: Translate IBus IME name if possible (bgo#695673).
  + power: Display single digit minutes correctly (bgo#705803).
  + Implement new aggregate status menu (bgo#705845).
  + Improve triangle animation when expanding sub-menus
    (bgo#703109).
  + Fix alignment of search provider icons (bgo#695760).
  + Slide dash and workspace switcher on overview transitions
    (bgo#694262).
  + Respect always-show-universal-access-status setting
    (bgo#705733).
  + Handle .desktop files with capital letters (bgo#706252).
  + authPrompt: Add smartcard support (bgo#683437).
  + Fix call notifications in busy mode (bgo#666221).
  + Improve triangle animation when expanding sub-menus
    (bgo#703109).
  + Move message tray menu to a tray button (bgo#699272).
  + Wi-fi dialog improvements (bgo#705916, bgo#706136).
  + Work towards running as wayland compositor.
  - Switch to Mutter abstraction layer for cursor tracking
    (bgo#705911).
  - Add confirmation dialog for display changes (bgo#706208).
  + Use a different background in screen shield (bgo#688210).
  + Add fade animation before blanking the screen (bgo#699112).
  + Misc. bugfixes and cleanups: bgo#704448, bgo#702536,
    bgo#686855, bgo#695581, bgo#700901, bgo#701761, bgo#701495,
    bgo#701848, bgo#697833, bgo#701731, bgo#705664, bgo#705840,
    bgo#705898, bgo#706089, bgo#706153, bgo#704646, bgo#706262,
    bgo#706324, bgo#703810, bgo#703811, bgo#704015, bgo#706232,
    bgo#705917, bgo#706536.
  + Updated translations.
- Drop pkgconfig(xfixes) BuildRequires: no longer needed.
- Add pkgconfig(xtst) BuildRequires: new dependency.
* Tue Jul 30 2013 dimstar@opensuse.org
- Update to version 3.9.5:
  + Fix width changes of the calendar popup (bgo#704200).
  + Work towards aggregate status menu (bgo#702539, bgo#704336,
    bgo#704368, bgo#704670).
  + Update design of lock screen notifications (bgo#702305).
  + Don't show empty backgroundMenu (bgo#703868).
  + Add option to limit app switcher to current workspace
    (bgo#703538).
  + Consolidate design of login screen and unlock dialog
    (bgo#702308, bgo#704795).
  + Respect hasWorkspace property of session mode (bgo#698593).
  + Fix fade of app menu icon in RTL locales (bgo#704583).
  + Destroy notifications when the close button is clicked
    (bgo#687016).
  + Fix clicks on legacy tray icons in the message tray
    (bgo#704095).
  + authPrompt: Fade out message if users start to type
    (bgo#704817).
  + Export timestamps of global shortcuts on DBus (bgo#704859).
  + Fix duplicate search provider results (bgo#700283).
  + Misc bug fixes and cleanups (bgo#703859, bgo#703540,
    bgo#704077, bgo#703997, bgo#704318, bgo#704347, bgo#704265,
    bgo#704411, bgo#704430, bgo#704347, bgo#704453, bgo#704471,
    bgo#704542, bgo#704707, bgo#703905, bgo#705037.
  + Updated translations.
* Wed Jul 10 2013 zaitor@opensuse.org
- Update to version 3.9.4:
  + Fix chat entries not being focused when expanded (bgo#698778).
  + Fix alignment of "Not Listed?" label (bgo#702307).
  + Fix alignment of time stamps in chat notifications
    (bgo#687809).
  + Round the ends of slider trough (bgo#702825).
  + Add support for "box-shadow: none" (bgo#702782).
  + Keep chrome below popup windows (bgo#702338).
  + Move the session list to a popup menu (bgo#702818).
  + Fix autorun notifications for "non-native" volumes
    (bgo#703418).
  + dnd: Speed up by not picking on each motion event (bgo#703443).
  + Fix management of asynchronous background loading (bgo#703001).
  + Rework focus handling (bgo#700735).
  + Optimize box-shadow rendering (bgo#689858).
  + Remove support for fixed positioning in BoxLayouts
    (bgo#703808).
  + Bugs fixed: bgo#702849, bgo#610279, bgo#703132, bgo#703105,
    bgo#703160, bgo#703126, bgo#703304, bgo#703403, bgo#698593,
    bgo#703442, bgo#703565, bgo#700901, bgo#703874, bgo#703807,
    bgo#703893, bgo#703909.
  + Updated translations.
* Thu Jun 20 2013 dimstar@opensuse.org
- Update to version 3.9.3:
  + Don't push window thumbs when workspace switcher is hidden
    (bgo#701167).
  + Tweak timeout for activating windows during XDND (bgo#700150).
  + Fix ellipsization in control buttons in app picker
    (bgo#696307).
  + Fix DND to empty dash (bgo#684618).
  + Fix OSD window appearing below system modal dialogs
    (bgo#701269).
  + Clear clipboard on screen lock to prevent information leak
    (bgo#698922).
  + Allow session mode specific overrides schema (bgo#701717).
  + window-switcher: Only show windows from current workspace by
    default (bgo#701214).
  + logout dialog: Show the correct text right away (bgo#702056).
  + bluetooth: Port to bluez 5 (bgo#700891).
  + dateMenu: Allow events to span multiple lines (bgo#701231).
  + gdm: Clear message queue when no more messages are pending
    (bgo#702458).
  + Misc bug fixes and cleanups: bgo#693836, bgo#700972,
    bgo#701386, bgo#700877, bgo#701755, bgo#698918, bgo#701224,
    bgo#702125, bgo#701954, bgo#701849, bgo#702121.
  + Updated translations.
* Tue May 28 2013 dimstar@opensuse.org
- Update to version 3.9.2:
  + Use a symbolic icon for DESKTOP windows (bgo#697914).
  + Move paint state cache into StWidget (bgo#697274).
  + gdm: Fix regression where domain login hint not shown
    (bgo#698200).
  + Make calendar keyboard navigable (bgo#667434).
  + Hide "Open Calendar" item when no calendar app is installed
    (bgo#697725).
  + Update how branding appears on login screen (bgo#694912,
    bgo#699877).
  + Allow OSD popups to grow if necessary (bgo#696523).
  + Fix offset of shadow offscreen rendering (bgo#698301).
  + Fix insensitive button preventing empty keyring password
    (bgo#696304).
  + Allow cancelling keyring dialog between prompts (bgo#682830).
  + modalDialog: Show spinner while working (bgo#684438).
  + overview: Only show close buttons for windows that may close
    (bgo#699269).
  + Add input purpose and hints to StEntry and StIMText
    (bgo#691392).
  + Set input-purpose property for password entries (bgo#700043).
  + Provide a DBus API for screencasting (bgo#696247).
  + overview: Disable hotcorner during DND (bgo#698484).
  + polkitAgent: Allow retrying after mistyped passwords
    (bgo#684431).
  + Add a way to get backtraces from criticals and warnings
    (bgo#700262).
  + Allow switch-to-workspace-n keybindings in overview
    (bgo#649977).
  + Update man page (bgo#700339).
  + Add FocusSearch DBus method (bgo#700536).
  + Hide frequent view when app monitoring is disabled
    (bgo#699714).
  + Show switcher popup for switch-to-workspace-n keybindings
    (bgo#659288).
  + gdm: Update the session chooser style (bgo#695742).
  + Fix some app folders getting truncated at the top (bgo#694371).
  + Don't block the message tray while a notification is showing
    (bgo#700639).
  + popupMenu: Allow for an optional border for slider handle
    (bgo#697917).
  + Re-lock screen when restarted after a crash (bgo#691987).
  + Synchronize input source switching with key events
    (bgo#697007).
  + Switch input source on modifiers-only accelerator (bgo#697008).
  + Allow input source switching in message tray (bgo#697009).
  + Other fixed bugs: bgo#698863, bgo#699799, bgo#699800,
    bgo#676285, bgo#699975, bgo#700097, bgo#698812, bgo#698486,
    bgo#700194, bgo#695314, bgo#700257, bgo#699678, bgp#700356,
    bgo#700322, bgo#700394, bgo#700409, bgo#700595, bgo#700625,
    bgo#691746, bgo#700620, bgo#700807, bgo#659288, bgo#700784,
    bgo#700842, bgo#700847, bgo#700488, bgo#700735, bgo#696159,
    bgo#700900, bgo#700853, bgo#700923, bgo#700944, bgo#697661,
    bgo#700854, bgo#700190, bgo#699189, bgo#701097.
  + Updated translations.
- Replace pkgconfig(gcr-3) BuildRequires with
  pkgconfig(gcr-base-3), following upstream.
* Wed May  1 2013 dimstar@opensuse.org
- Update to version 3.9.1:
  + Add additional toggle-overview keybinding (bgo#698251).
  + Disable <super> shortcut when sticky keys are enabled
    (bgo#685974).
  + Disable tray context menu while a notification displays
    (bgo#695800).
  + Watch GApplication busy state (bgo#697207).
  + Disable style transitions if animations are disabled
    (bgo#698391).
  + Filter out hidden applications from "Frequent" view
    (bgo#696949).
  + Fix window previews swapping place randomly (bgo#694469,
    bgo#698776).
  + Add support for serialized GIcons in remote search providers
    (bgo#698761).
  + Fix hotcorner regression in RTL locales (bgo#698884).
  + Allow some keybindings to work while a top bar menu is open
    (bgo#698938).
  + Make open-app-menu keybinding a toggle action (bgo#686756).
  + Only recognize common URL schemes in notification messages
    (bgo#661225).
  + Misc fixes and cleanups: bgo#698531, bgo#698622, bgo#698427,
    bgo#698483, bgo#698513, bgo#697203, bgo#698959, bgo#698918,
    bgo#699029, bgo#699075, bgo#696720, bgo#649748.
  + Updated translations.
* Thu Apr 25 2013 dimstar@opensuse.org
- Add gnome-clocks Recommends: the dateTime applet in the panel
  starts it when the user selects "Open Clocks".
* Tue Apr 16 2013 dimstar@opensuse.org
- Update to version 3.8.1:
  + Clip window group during startup animation (bgo#696323).
  + Check for logind rather than systemd (bgo#696252).
  + Don't special-case last remote search provider position
    (bgo#694974).
  + Fix memory leaks (bgo#697119, bgo#697295, bgo#697300
    bgo#697395).
  + AppSwitcherPopup: Activate only the selected window if any
    (bgo#697480).
  + Enable screen recorder keybinding in all modes (bgo#696200).
  + Remove box-shadow from screen shield for performance reasons
    (bgo#697274).
  + Add support for -st-natural-width/height CSS properties
    (bgo#664411).
  + Remove excessive padding from notification buttons
    (bgo#664411).
  + Fix thumbnail dragging in overview (bgo#697504).
  + theme-node: Add get_url()/lookup_url() methods (bgo#693688).
  + Misc bug fixes and cleanups: bgo#695859, bgo#696259,
    bgo#696585, bgo#696436, bgo#697432, bgo#697435, bgo#697560,
    bgo#697722, bgo#697709.
  + Updated translations.
* Wed Mar 27 2013 dimstar@opensuse.org
- Drop gnome-shell-nmlibexecdir.patch: this was a temporary
  solution until NetworkManager fixes their .name files
  (bnc#806377).
- Drop gnome-common BuildRequires and call to gnome-autogen.sh, as
  we don't carry patches touching the build system anymore.
* Wed Mar 27 2013 dimstar@opensuse.org
- Update to version 3.8.0.1:
  + Background bug fixes (bgo#696712).
* Tue Mar 26 2013 dimstar@opensuse.org
- Update to version 3.8.0:
  + Remove blur and desaturation from lock screen (bgo#696322).
  + Remove scroll view fade near edges (bgo#696404).
  + dateMenu: Open calendar component when using Evolution
    (bgo#696432).
  + Fix unlocking on fast user switch (bgo#696287).
  + Tweak screen shield animation (bgo#696380).
  + Fix major memory leak when changing backgrounds (bgo#696157).
  + Misc bug fixes: bgo#696199, bgo#696212, bgo#696422, bgo#696447,
    bgo#696235.
  + Updated translations.
* Tue Mar 19 2013 zaitor@opensuse.org
- Update to version 3.7.92:
  + Drop fallback lock implementation (bgo#693403).
  + Don't let the user trigger message-tray when in fullscreen
    (bgo#694997).
  + Scroll search results when using keynav (bgo#689681).
  + Allow raising the shield by starting to type the password
    (bgo#686740).
  + Improve tracking of fullscreen windows (bgo#649748).
  + Improve animation of new windows in overview (bgo#695582).
  + workspace switcher: Animate new workspaces created by DND
    (bgo#685285).
  + Give user time to read messages on login screen (bgo#694688).
  + Bugs fixed: bgo#695154, bgo#694993, bgo#695272, bgo#691578,
    bgo#694321, bgo#695338, bgo#695409, bgo#695458, bgo#695526,
    bgo#695601, bgo#695471, bgo#695324, bgo#695650, bgo#695656,
    bgo#695659, bgo#695485, bgo#695395, bgo#694951, bgo#695824,
    bgo#695841, bgo#695801, bgo#694321, bgo#693708, bgo#695800,
    bgo#695607, bgo#695882, bgo#691578, bgo#685851, bgo#694371,
    bgo#690857, bgo#694092, bgo#695747, bgo#696007, bgo#693438,
    bgo#696064, bgo#696102.
  + Updated translations.
- Drop gnome-shell-error-in-fallback-hotcorner.patch, fixed
  upstream.
* Sun Mar 10 2013 dimstar@opensuse.org
- Add gnome-shell-error-in-fallback-hotcorner.patch: Fix errors in
  fallback HotCorner function. Fixes startup of gnome-shell.
* Tue Mar  5 2013 dimstar@opensuse.org
- Update to version 3.7.91:
  + Overview:
  - Fade out controls during DND that are not targets
    (bgo#686984)
  - Keep open when a Control key is held (bgo#686984).
  + Improve login screen => session transition (bgo#694321).
  + Center application grid horizontally (bgo#694261).
  + Fix hiding panel when fullscreen windows span multiple monitors
    (bgo#646861)
  + Tweak thresholds of pressure barrier (bgo#694467).
  + Tweak window picker layout (bgo#694902).
  + Expose key grab DBus API to gnome-settings-daemon (bgo#643111).
  + Don't always show message tray in overview, add message
    indicator (bgo#687787).
  + Tweak startup animation (bgo#694326).
  + Add OSD popups and expose them to gnome-settings-daemon
    (bgo#613543).
  + Move loupe icon to the start of the search entry (bgo#695069).
  + Don't show the input switcher with less than 2 items
    (bgo#695000).
  + Fix auto-completion of system modals immediately upon display
    (bgo#692937).
  + Ignore workspaces in alt-tab (bgo#661156).
  + Disable copying text from password entries (bgo#695104).
  + Use standard styling for ibus candidate popups (bgo#694796).
  + Fix calendar changing height on month changes (bgo#641383).
  + Port the hot corner to use pressure barriers (bgo#663661).
  + Misc bug fixes and cleanups: bgo#685849, bgo#690643,
    bgo#694292, bgo#693814, bgo#694234, bgo#694365, bgo#694287,
    bgo#694336, bgo#694256, bgo#694261, bgo#663601, bgo#694441,
    bgo#694284, bgo#694463, bgo#694475, bgo#687248, bgo#694394,
    bgo#694320, bgo#694701, bgo#694784, bgo#694858, bgo#694906,
    bgo#694327, bgo#694876, bgo#694905, bgo#694969, bgo#694970,
    bgo#694988, bgo#695006, bgo#695001, bgo#694998, bgo#695023,
    bgo#695002, bgo#695073, bgo#695126, bgo#687748, bgo#694837,
    bgo#693907, bgo#679851, bgo#694988.
  + Updated translations.
- Drop pkgconfig(telepathy-logger-0.2) BuildRequires: no longer
  needed.
- Replace pkgconfig(gnome-keyring-1) BuildRequires with
  pkgconfig(libsecret-unstable), following upstreams changes.
* Wed Feb 27 2013 dimstar@opensuse.org
- Update to version 3.7.90:
  + Let GNOME Shell work on EGL and GLES2 (bgo#693225, bgo#693438,
    bgo#693339)
  + Implement middle-click paste (bgo#645019).
  + Fix top bar transition between session modes (bgo#692966).
  + Trigger the message tray with downward pressure (bgo#677215).
  + Don't ask for a password on shutdown (bgo#693385).
  + Add a context menu to the message tray (bgo#691035, bgo#693887)
  + Use unicode formatting in the date menu (bgo#689251).
  + Use proper ellipsis instead of three dots (bgo#689542).
  + Tweak screen shield animation (bgo#691964).
  + Always hide the OSK when showing the message tray (bgo#662687).
  + Support sound in notifications (bgo#642831).
  + Place application popup menus above chrome (bgo#633620).
  + Hide overview elements while searching (bgo#682050).
  + Implement updated IBus candidate popup designs (bgo#691902).
  + Add support for enable-animations preference (bgo#655746).
  + Don't always show the message tray in the overview
    (bgo#693987).
  + Improve arrangement of window previews (bgo#690313).
  + Remove builtin settings provider (bgo#690824).
  + Minimize fullscreen windows when they end up in the background
    (bgo#693991).
  + Add context menu to the background actor (bgo#681540).
  + Handle backgrounds in the shell, improve startup animation
    (bgo#682429).
  + Hide universal access menu when not needed (bgo#681528).
  + Implement updated app picker designs (bgo#694192).
  + Improve login manager -> session transition (bgo#694062).
  + Don't use a grid layout in window picker (bgo#694210).
  + Use scroll wheel for workspace switching rather than zoom
    (bgo#686639).
  + Misc bug fixes and cleanups: bgo#693284, bgo#692680,
    bgo#691746, bgo#693303, bgo#693162, bgo#693161, bgo#693522,
    bgo#693385, bgo#691715, bgo#688915, bgo#689106, bgo#682429,
    bgo#693570, bgo#693737, bgo#693458, bgo#692845, bgo#693836,
    bgo#681540, bgo#679925, bgo#688227, bgo#692773, bgo#693909,
    bgo#683288, bgo#693854, bgo#693746, bgo#693931, bgo#693924,
    bgo#693940, bgo#693970, bgo#693935, bgo#693937, bgo#693974,
    bgo#693936, bgo#693975, bgo#693822, bgo#694030, bgo#685849,
    bgo#694052, bgo#694035, bgo#694038, bgo#694079, bgo#694064,
    bgo#681735, bgo#694100, bgo#694057, bgo#694070, bgo#693572,
    bgo#693896, bgo#686984, bgo#694123, bgo#694125, bgo#693756,
    bgo#693757, bgo#687556, bgo#694215, bgo#694062, bgo#694227,
    bgo#694240, bgo#694234, bog#694264, bgo#694276, bgo#694282,
    bgo#694241, bgo#689394, bgo#694202, bgo#694265, bgo#694289,
    bgo#691806, bgo#694290, bgo#694296.
  + Updated translations.
- Add pkgconfig(caribou-1.0) BuildRequires: new dependency.
- Drop pkgconfig(gl) BuildRequires: no longer needed.
* Tue Feb 26 2013 dimstar@opensuse.org
- Update to version 3.7.5:
  + MessageTray: pass keyboard events to tray icons (bgo#687425).
  + network: add support for virtual devices (bgo#677144).
  + gdm: Allow right-clicking buttons for left-handed users
    (bgo#688748)
  + Make list search results span all available horizontal space
    (bgo#691967)
  + Make Show-Applications button depress when held down
    (bgo#692319)
  + Set a max width on search results (bgo#692453).
  + Reserve scrollbar allocation for automatic policy (bgo#686881).
  + Improve scaling algorithm for window thumbnails (bgo#686944).
  + Fix launching settings panels after g-c-c changes (bgo#692483).
  + Stop launching applications from empty searches (bgo#692391).
  + Implement per-source notification filtering (bgo#685926).
  + ScreenShield:
  - Omit ActiveChanged() signal at end of fade (bgo#691964).
  - ower the shield on idle before locking (bgo#692560).
  - Only show lock icon when actually locked (bgo#693007)
  - Inhibit suspend until the screen is locked (bgo#686482).
  + Make previews of minimized windows translucent in overview
    (bgo#692999).
  + windowManager: Respect icon geometry when minimizing
    (bgo#692997).
  + general:
  - Use & instead of 'and' for Settings panels (bgo#689590).
  - Consistently use Title Case in top bar (bgo#689589).
  + Network:
  - Add support for new ModemManager1 interface (bgo#687359).
  - Handle LTE-only modems as GSM ones (bgo#688144).
  + mobile-providers: Port to libnm-gtk (bgo#688943).
  + panel: Add :overview pseudo class while in overview
    (bgo#693218)
  + sessionMode: Add support for mode-specific styling (bgo#693219)
  + Misc bugfixes: bgo#691745, bgo#691731, bgo#690171, bgo#689091,
    bgo#691976, bgo#691963, bgo#684279, bgo#692052, bgo#692091,
    bgo#642831, bgo#692454, bgo#692715, bgo#692678, bgo#692723,
    bgo#692677, bgo#683986, bgo#692693, bgo#692749, bgo#692948,
    bgo#692995, bgo#692996, bgo#692994, bgo#677215, bgo#692586,
    bgo#693067, bgo#693031, bgo#693049, bgo#643111, bgo#693161,
    bgo#693220.
  + Updated translations.
- Add pkgconfig(libcanberra-gtk) BuildRequires: new dependency.
- Add pkgconfig(libnm-gtk) BuildRequires: new dependency.
- Drop upstream fixed patches:
  + g-s-honor-lock-delay-GSettings.patch
  + g-s-use-the-right-getter.patch
  + gnome-shell-ScreenShield-become-modal-and-catch.patch
- Disable gnome-shell-private-connection.patch: needs rebase.
* Tue Feb 26 2013 dimstar@opensuse.org
- Update to version 3.7.4.1:
  + userMenu: Use show-full-name-in-top-bar setting (bgo#689561).
  + dateMenu: Add "Open Clocks" entry (bgo#644390).
  + screenshot: Immediately show the flash spot (bgo#691875).
  + Misc. bug fixes.
  + Updated translations.
* Tue Feb 26 2013 dimstar@opensuse.org
- Update to version 3.7.4:
  + Make menu separators crisp (bgo#641745)
  + power: Update for new D-Bus name (bgo#690506)
  + Add smooth scrolling support (bgo#687573)
  + Tweak notification layout (bgo#688506)
  + Ping the active window when using the app menu (bgo#684340)
  + Make password entries insensitive after submission (bgo#690594,
    bgo#690895)
  + Honor lock-delay GSettings key (bgo#690766, bgo#691170)
  + Use text/calendar preferred app as the calendar app
    (bgo#690767)
  + lookingGlass: Move to an inspect() function (bgo#690726)
  + Make OSK animation quicker, snappier (bgo#688642)
  + Allow to close chat notifications with Escape (bgo#690897)
  + Honor org.gnome.desktop.screensaver.user-switch-enabled
    (bgo#691042)
  + Add a SelectArea() DBus method (bgo#687954)
  + Support non-absolute paths when saving screenshots (bgo#688004)
  + OSK: Fix extended keys popups (bgo#674955)
  + Don't hide or show the keyboard immediately (bgo#688646)
  + Improve padding in power menu (bgo#689297)
  + Add per-window input source switching (bgo#691414)
  + Other bugs fixed: bgo#690608, bgo#690589, bgo#690539,
    bgo#687081, bgo#690667, bgo#690665, bgo#690666, bgo#685856,
    bgo#690858, bgo#690895, bgo#680414, bgo#690965, bgo#691019,
    bgo#690590, bgo#681376, bgo#690180, bgo#685513, bgo#689263,
    bgo#691553, bgo#691720, bgo#691743, bgo#691750
  + Updated translations.
* Mon Feb 25 2013 dimstar@opensuse.org
- Update to version 3.7.3.1:
  + Do not depend on NMGTK-0.9.7, which hasn't been released yet.
* Mon Feb 25 2013 dimstar@opensuse.org
- Update to version 3.7.3:
  + Add 'No Messages' label when message tray is empty (bgo#686738)
  + Use better icons in Ctrl-Alt-Tab popup (bgo#641303)
  + Show the OSK on the monitor where the focused window lives (bgo#685856)
  + Highlight window clone and caption when hovered (bgo#665310)
  + Improve login process indication (Sbgo#687113)
  + Omit empty categories in apps view (bgo#687970)
  + Style panel differently according to mode (bgo#684573)
  + Make it possible to hide the user name (bgo#688577)
  + Consolidate and improve chat connection notifications (bgo#687213)
  + Improve notification scrollbar appearance (bgo#688393)
  + Fade scroll view fade near scrolling edges (bgo#689249)
  + Add a read-only org.gnome.Shell.Mode property (bgo#689300)
  + Don't close message tray after using context menus (bgo#689296)
  + Port swipe-scrolling to ClutterPanAction (bgo#689062, bgo#689552)
  + Remember state of 'Remember Password' checkbox (bgo#688039)
  + Improve timestamp format in chat notifications (bgo#680989)
  + Improve style of missed-messages counter (bgo#686472)
  + Omit connection failure notifications if cancelled by user (bgo#684823)
  + Add window-based Alt-Tab popup (bgo#688913)
  + Support external session mode definitions (bgo#689304)
  + Support session-mode-specific extensions (bgo#689305)
  + Support 'parentMode' property in session modes (bgo#689308)
  + Support a new org.gnome.ShellSearchProvider2 DBus interface
    (bgo#689735, bgo#690009)
  + Add "windows" to Ctrl-Alt-Tab popup (bgo#689653)
  + Port PopupMenu to GrabHelper (bgo#689109, bgo#689954)
  + Show headphone icon when headphones are plugged in (bgo#675902)
  + Display (non-app) search results as list (bgo#681797)
  + Skip diacritical marks in search terms (bgo#648587)
  + Expose all engine options in input sources (bgo#682318)
  + Add input source switcher popup (bgo#682315)
  + Add minimal support for InfiniBand in network menu (bgo#677150)
  + Misc bug fixes and cleanups bgo#688422, bgo#688379, bgo#688750,
    bgo#688771, bgo#686800, bgo#688133, bgo#688895, bgo#688966,
    bgo#683986, bgo#688004, bgo#689108, bgo#689029, bgo#683449,
    bgo#688196, bgo#689304, bgo#689243, bgo#689295, bgo#689325,
    bgo#689400, bgo#679168, bgo#689568, bgo#689537, bgo#689528,
    bgo#689749, bgo#689789, bgo#689353, bgo#689820, bgo#689868,
    bgo#689778, bgo#689959, bgo#688589, bgo#688589, bgo#689955,
    bgo#687250, bgo#689965, bgo#690046, bgo#690049, bgo#689884,
    bgo#682286, bgo#690173, bgo#690174, bgo#672941, bgo#689876,
    bgo#687881, bgo#690171, bgo#690241, bgo#690312, bgo#690175,
    bgo#687955, bgo#650843, bgo#688234, bgo#690427.
  + Updated translations.
- Add pkgconfig(libpulse) BuildRequires: new explicitly verified
  and versioned dependency.
- Drop g-s-fix-notification-expansion.patch: fixed upstream.
* Sun Feb 24 2013 dimstar@opensuse.org
- Update to version 3.7.2.1:
  + Revert 490206b to not depend on NMGTK-0.9.7, which hasn't been
    released yet
- Changes from version 3.7.2:
  + Enforce RTL in he for messages that might end up as LTR
    (bgo#686630)
  + gdm: Move logo into the panel (bgo#685852)
  + Hide notifications when closed button is clicked (bgo#682237)
  + Tweak screenShield animations (bgo#686745)
  + Restore Fittsability of summary items in message tray
    (bgo#686474)
  + Save screencasts as recent item (bgo#680647)
  + overview: Resize window captions on content change (bgo#620874)
  + App search: Match GenericName too (bgo#687121)
  + runDialog: Better match style of other modal dialogs
    (bog#687127)
  + Improve the button insensitive style (bgo#687110)
  + network: Don't use a global switch for all VPN connections
    (bgo#682929)
  + appMenu: Update on icon theme changes (bgo#687224)
  + Show 'Log out' in more situations (bgo#686736)
  + Add a setting to force the 'Log out' menuitem (bgo#686057)
  + overview: Improve styling of search box (bgo#686479)
  + Implement 'disable-user-list' in login screen (bgo#660660)
  + Fix auto-scroll to bottom in chat notifications (bgo#686571)
  + Show feedback notifications when user is busy (bgo#662900)
  + Disable login button when there is no input (bgo#687112)
  + Use non-linear overview shade for background (bgo#669798)
  + Reduce blocking in compositor thread (bgo#687465)
  + network: new country-specific type to gather providers
    (bgo#687356)
  + Update man page (bgo#680601)
  + st-entry: Change the pointer cursor on enter/leave events
    (bgo#687130)
  + screenShield: Blur and desaturate the background (bgo#682536)
  + Change height of chat notifications to have more context
    (bgo#665255)
  + screenShield: Account for motion velocity when hiding
    (bgo#682537)
  + screenShield: hide the cursor while the lock screen is on
    (bgo#682535)
  + Support remote search provider settings (bgo#687491)
  + unlockDialog: Improve label of confirmation button (bgo#687656)
  + userMenu: Rename "System Settings" item to "Settings"
    (bgo#687738)
  + messageTray: Add keybinding to focus current notification
    (bgo#652082)
  + Remove shell-screen-grabber (bgo#685915)
  + main: Stop using Metacity's keybinding files (bgo#687672)
  + Bluetooth: Remove ObexFTP functionality (bgo#688160)
  + a11y: Also set WM theme when HighContrast is switched on
    (bgo#688256)
  + network: Rework multiple NIC support (bgo#677142)
  + Rework keybindings to allow selective blocking/processing
    (bgo#688202)
  + recorder: Show indicator on primary monitor (bgo#688470)
  + recorder: Set frame duration to fix broken video headers
    (bgo#688487)
  + Misc. bugfixes and cleanup: bgo#686484, bgo#686728, bgo#686805,
    bgo#686574, bgo#686763, bgo#682428, bgo#687132, bgo#685239,
    bgo#687189, bgo#687226, bgo#658091, bgo#670687, bgo#687457,
    bgo#687242, bgo#687287, bgo#687020, bgo#686583, bgo#661194,
    bgo#687491, bgo#657315, bgo#687958, bgo#683986, bgo#688089,
    bgo#687708, bgo#686530, bgo#684810, bgo#688181, bgo#688475,
    bgo#688557, bgo#688507, bgo#638351
  + Updated translations.
* Sat Feb 23 2013 dimstar@opensuse.org
- Update to version 3.7.1:
  + Add shortcut to open application view directly (bgo#685738)
  + Expose '<Super>F10' shortcut in System Settings (bgo#672909)
  + Clean up timestamp format in chat notifications (bgo#680989)
  + loginScreen: Add support for 'disable-restart-buttons'
    (bgo#686247)
  + Update textures automatically on file changes (bgo#679268)
  + Implement org.gnome.ScreenSaver.GetActiveTime (bgo#686064)
  + Add missing translations for GSetting schema (bgo#686413)
  + Hide workspace switcher completely when it's not necessary
    (bgo#686483)
  + Explicitly load gnome-screensaver when not running GDM
    (bgo#683060)
  + ort to GnomeIdleMonitor (bgo#682224)
  + Set Empathy as preferred handler when delegating channels
    (bgo#686296)
  + Allow testing GDM login dialog from the session (bgo#683725)
  + Use all available space for windows in window picker
    (bgo#582650)
  + Use logind for suspend if available (bgo#686482)
  + Misc. fixes and cleanups: bgo#677426, bgo#680426, bgo#686233,
    bgo#686241, bgo#686318, bgo#686240, bgo#686484, bgo#686002,
    bgo#684650, bgo#686487.
  + Updated translations.
* Fri Feb 22 2013 zaitor@opensuse.org
- Update to version 3.6.3.1:
  + Fix regression in reentrancy fix for 3.6.3 (bgo#689295).
  + Updated translations.
- Drop g-s-fix-notification-expansion.patch: fixed upstream.
* Thu Feb 14 2013 badshah400@gmail.com
- Add g-s-fix-notification-expansion.patch: fix notification not
  expanding to the right height into the screen, regression
  intrduced in version 3.6.3 (bgo#689295).
* Tue Feb 12 2013 badshah400@gmail.com
- Update to version 3.6.3 (bnc#801797):
  + recorder: Set frame duration to fix broken video headers
    (bgo#688487)
  + Block cancellation of unlock dialog during drags (bgo#686800)
  + Honor lock-delay GSettings key (bgo#690766,bgo#691170)
  + Fix reentrancy problem causing the tray to disappear
    (bgo#683986)
- Drop the following patches, which have been merged upstream:
  + g-s-honor-lock-delay-GSettings.patch
  + g-s-use-the-right-getter.patch
- Rebase gnome-shell-nmlibexecdir.patch.
* Mon Feb 11 2013 dimstar@opensuse.org
- Add gnome-shell-nmlibexecdir.patch: Allow NetworkManager to use
  a different libexecdir that gnome-shell.
- Add gnome-common BuildRequires and call to gnome-autogen.sh, as
  above patch touches the build system.
- Pass --with-nmlibexecdir=%%{_libexecdir} to configure.
* Mon Feb 11 2013 badshah400@gmail.com
- Remove gnome-shell-ScreenShield-become-modal-and-catch.patch: it
  caused screen lock and suspend to fail completely.
* Mon Feb  4 2013 badshah400@gmail.com
- Add gnome-shell-ScreenShield-become-modal-and-catch.patch: fix an
  issue where the screen would not return to the desktop properly
  when resuming from screen lock (bnc#801797, rh#878736,
  bgo#689106).
* Mon Jan 21 2013 zaitor@opensuse.org
- Add g-s-honor-lock-delay-GSettings.patch,
  org.gnome.desktop.screensaver.lock-delay contains the grace
  period of the screensaver: if deactivated within that many
  seconds from the start of the idle period, the shell should not
  prompt for a password. This setting correspond to the "Lock
  screen after" combo in screen and privacy panels. (bgo#690766).
- Add g-s-use-the-right-getter.patch, org.gnome.desktop.screensaver
  lock-delay is an integer, so don't use get_bool() on it.
  (bgo#691170).
* Tue Jan 15 2013 mike.catanzaro@gmail.com
- Don't obsolete Alternative Status Menu extension; it's still
  needed to suspend without pressing Alt and *to hibernate at all*.
* Sun Jan 13 2013 dimstar@opensuse.org
- Add evolution-data-server requires: gnome-shell fails to start
  without, as the calendar applet interfaces with e-d-s directly
  (bnc#795793).
* Tue Nov 13 2012 dimstar@opensuse.org
- Update to version 3.6.2:
  + Implement org.gnome.ScreenSaver.GetActiveTime (bgo#686064)
  + Explicitly load gnome-screensaver when not running GDM
    (bgo#683060)
  + Set Empathy as preferred handler when delegating channels
    (bgo#686296)
  + Add setting to force log out menuitem (bgo#686057)
  + Implement 'disable-user-list' in login screen (bgo#660660)
  + Bugs fixed: bgo#686745, bgo#686474, bgo#687121, bgo#686571,
    bgo#680601, bgo#682237, bgo#685915, bgo#686233, bgo#686484,
    bgo#686487, bgo#686630, bgo#686728, bgo#686574, bgo#686574,
    bgo#686574, bgo#686879, bgo#686763, bgo#685239, bgo#687189,
    bgo#686736, bgo#686583, bgo#687132, bgo#687958, bgo#687020,
    bgo#687708, bgo#686888, bgo#686530, bgo#684810, bgo#688181.
  + Updated translations.
- Add docbook-xsl-stylesheets and xsltproc BuildRequires: newly
  needed to build the man pages.
* Wed Oct 24 2012 dimstar@opensuse.org
- Obsolete gnome-shell-extension-alternative-status-menu: the
  alternative-status-menu was meant to bring 'power off' to the
  user menu, which is there by default in gnome-shell 3.6, thus
  making the extension obsolete.
* Tue Oct 16 2012 dimstar@opensuse.org
- Update to version 3.6.1:
  + dash: Make padding even on the top/bottom of the dash
    (bgo#684619)
  + Fix a crash when dragging search results (bgo#684888)
  + workspaceThumbnail: Fix dragging with static workspaces
    (bgo#684641)
  + Really hide 'Show Keyboard Layout' on the lock screen
  + Misc. improvements to jhbuild setup (bgo#685352, bgo#685353,
    bgo#685354, bgo#685355)
  + Show message tray in Ctrl+Alt+Tab outside of the overview
    (bgo#684633, bgo#685914)
  + Disable hotplug sniffer on remote filesystems (bgo#684093)
  + userMenu: Remove 'Switch Session' item (bgo#685062)
  + unlockDialog: Make prompt entry insensitive while logging in
    (bgo#685444)
  + messageTray: Don't animate desktop clone for failed grabs
    (bgo#685342)
  + Fix crash on dragging windows between workspaces (bgo#681399)
  + userMenu: Ignore 'lock-enabled' setting for user switching
    (bgo#685536)
  + gdm: Fix key-focus on first user (bgo#684650)
  + Make grid button insensitive when dragging non-favorites
    (bgo#685313)
  + Calendar: hide all actions when on the login screen
    (bgo#685142)
  + Adapt unlock dialog layout for the login screen
    (bgo#685201)
  + Make focus-follows-mouse work better with Shell UI (bgo#678169)
  + Improve look of screen shield (bgo#685919)
  + Fix keynav in the login screen (bgo#684730)
  + dateMenu: Hide "Open Calendar" item if calendar unavailable
    (bgo#686050)
  + unlockDialog: Reset UI on verification failure (bgo#685441)
  + Show unlock dialog on primary monitor when using keynav
    (bgo#685855)
  + Fix height changes of entries when entering text (bgo#685534)
  + Fix show-apps label after successful drags (bgo#684627)
  + Misc. bugfixes and cleanups: bgo#685434, bgo#685511,
    bgo#685466, bgo#685341, bgo#685156, bgo#681159, bgo#673189,
    bgo#686016, bgo684869, bgo#686079, bgo#686063
  + Updated translations.
* Tue Sep 25 2012 dimstar@opensuse.org
- Update to version 3.6.0:
  + keyboard: Make input source items accessible (bgo#684462)
  + Don't show network dialogs in the lock screen (bgo#684384)
  + popupMenu: Fix initial visibility of settings items
    (bgo#684473)
  + userMenu:
  - Close menu immediately on user/session switch (bgo#684459)
  - Fix texture updates on icon changes (bgo#679268)
  + Fix alignment of search section headers in RTL locales
    (bgo#684379)
  + screenShield: Fix unlock animation (bgo#684591)
  + Don't open the tray from a dwell while in a modal grab
    (bgo#684458)
  + Fix a11y support in the login screen (bgo#684727, bgo#684728,
    bgo#684748)
  + Make On-Screen-Keyboard usable with new message tray
    (bgo#683546)
  + Fix initial visibility of input volume in lock-screen
    (bgo#684611)
  + Updated translations.
* Wed Sep 19 2012 dimstar@opensuse.org
- Update to version 3.5.92:
  + Login/UnlockDialog: Don't reset immediately if auth fails
    (bgo#682544)
  + Allow changing session mode at runtime (bgo#683156)
  + Add zoom out animation on login (bgo#683170)
  + Bluetooth: don't restrict the length of non numeric PINs
    (bgo#683356)
  + Force chat notification to stay open when focusing entry
    (bgo#682236)
  + Make sure the screen is fully locked before suspending
    (bgo#683448)
  + st-texture-cache: Fix a case of distorted textures (bgo#683483)
  + popupSubMenu: Fix padding for non-scrolled submenus
    (bgo#683009)
  + popupMenu: Fix width changes on submenu open/close (bgo#683485)
  + boxpointer: Avoid malformed boxpointer arrow (bgo#680077)
  + Change stage background color to grey (bgo#683514)
  + messageTray: Update style of summary counters (bgo#682891)
  + Don't fail if a legacy tray icon has no WM_CLASS (bgo#683724)
  + PolkitAgent: Fix a crash if there is no avatar (bgo#683707)
  + Hide the a11y menu in the lock screen, but show it in the login
    screen (bgo#682542)
  + Fix show-apps button dropping off the dash (bgo#683340)
  + Fix committing strings to shell entries from input method
    (bgo#658325)
  + Make IBus display strings consistent with control-center
    (bgo#683124)
  + Fix missing short codes for some input sources (bgo#683613)
  + Remove support for long-press from entry context menus
    (bgo#683509)
  + screenShield: Add box-shadow to the shield
  + Don't show a right-click menu for the hotplug source
    (bgo#683438)
  + Fix extension styling (bgo#682128)
  + Fix on-screen keyboard not working with system-modal dialogs
    (bgo#664309)
  + Fix insensitive styling for popup menu items (bgo#683988)
  + Disable the message tray dwell when the user is interacting
    (bgo#683811)
  + Animate going from the unlock dialog to the lock screen
    (bgo#681143)
  + Autostart fprintd when necessary (bgo#683131)
  + UnlockDialog: Allow typing before the first PAM question
    (bgo#681576)
  + Make Return key dismiss screenshield (bgo#683889)
  + Fix keyboard navigation in the message tray (bgo#682243)
  + Remove the places & devices search provider (bgo#683506)
  + Enable hot corner while the message tray is up (bgo#682255)
  + Port screen recorder to new GStreamer vp8enc API (bgo#684206)
  + Fix fish flickering (bgo#684154)
  + Fix extension ordering with !important (bgo#684163)
  + Allow the shell to run without the screenshield (bgo#683060)
  + Add menu items for IBus Anthy's InputMode, TypingMode
    (bgo#682314)
  + Improve transition to the login dialog (bgo#682428)
  + Keep unlock dialog around until shield animation ends
    (bgo#684342)
  + Expose shell keybindings in System Settings (bgo#671010)
  + Misc. bugfixes and cleanups: bgo#672790, bgo#677434,
    bgo#683305, bgo#683357, bgo#683369, bgo#683377, bgo#683378,
    bgo#683400, bgo#683449, bgo#683472, bgo#683482, bgo#683487,
    bgo#683488, bgo#683526, bgo#683529, bgo#683546, bgo#683583,
    bgo#683628, bgo#683705, bgo#683982, bgo#683989, bgo#684035,
    bgo#684036, bgo#684040, bgo#684162, bgo#684214, bgo#684343
  + Updated translations.
- Add pkgconfig(gnome-keybindings) BuildRequires: new dependency.
- Rebase gnome-shell-private-connection.patch.
* Wed Sep 12 2012 vuntz@opensuse.org
- Remove gnome-contacts Requires: search results for contacts are
  provided by gnome-contacts via its search provider, so
  gnome-contacts will already be installed if we display contacts
  in the search results.
- Remove gnome-screensaver Requires: gnome-shell uses its own lock
  screen now.
* Fri Sep  7 2012 vuntz@opensuse.org
- Remove --with-ca-certificates configure flag: it has been removed
  upstream as it's directly handled by libsoup now.
* Tue Sep  4 2012 dimstar@opensuse.org
- Update to version 3.5.91:
  + Improve modal dialog styling of network secret prompts
    (bgo#682412)
  + Fix visibility of non-active workspaces during overview
    transition (bgo#682002)
  + Improve scrollbar theming (bgo#682476)
  + Make sure the app menu remains hidden in locked state
    (bgo#682475)
  + Add tooltip to show-applications icon (bgo#682445)
  + Do not add duplicate remote search providers (bgo#682470)
  + Handle 'popup-menu' signal on summary items (bgo#682486)
  + Fix dwelling during mouse-down (bgo#682385)
  + Set label actor for endSessionDialog.ListItem (bgo#677503)
  + Don't match on comments when searching applications
    (bgo#682529)
  + Make workspace selector more similar to the mockup (bgo#662087)
  + Fix extension installation and reloading (bgo#682578)
  + Hide removable devices in the lock screen (bgo#681143)
  + Reset cancellable after hitting Escape on login screen
    (bgo#681537)
  + Fix suspend from the user menu (bgo#682746)
  + Set label actor for summary items in message tray (bgo#677229)
  + Set label for the "Show applications" dash button (bgo#682366)
  + Load extensions as late as possible (bgo#682822)
  + Improve mount operation dialogs (bgo#682645)
  + Remove "Connect to ..." item from places search (bgo#682817)
  + Don't auto-expand notifications with actions (bgo#682738)
  + Add a new lock screen menu to combine volume network and power
    (bgo#682540)
  + Add support for pre-edit to StIMText (bgo#664041)
  + Remove StIconType (bgo#682540)
  + Use monitor geometry for dwelling (bgo#683044)
  + Add support for surrounding-text to StIMText (bgo#683015)
  + Improve the placement and style of the "No results" text
    (bgo#683135)
  + Remove broken network device activation policy (bgo#683136)
  + Hide power status icon when no battery is present (bgo#683080)
  + Ensure summary items are square and have spacing (bgo#682248)
  + Fix close buttons overlapping screen edge (bgo#682343)
  + Escape the tray when a legacy icon is clicked (bgo#682244)
  + Update arrow in the screen shield to match latest mockups
    (bgo#682285)
  + Allow lifting the screen shield with the mouse wheel
    (bgo#683164)
  + Make sure to show the app menu after unlocking the screen
    (bgo#683154)
  + Bugs fixed: bgo#582650, bgo#667439, bgo#682238, bgo#682268,
    bgo#682429, bgo#682455, bgo#682544, bgo#682546, bgo#682683,
    bgo#682710, bgo#682998, bgo#683073, bgo#683073, bgo#683156.
  + Updated translations.
- Drop gnome-shell-cancellable.patch: fixed upstream.
- Rebase gnome-shell-private-connection.patch.
* Mon Aug 27 2012 dimstar@opensuse.org
- Add gnome-shell-cancellable.patch: fix issue where second attempt
  to login after pressing "escape" key on the login "freeze" and
  raise an exception about IOError operation cancelled.
* Wed Aug 22 2012 dimstar@opensuse.org
- Update to version 3.5.90:
  + Use symbolic icons for workspace switch OSD (bgo#680738)
  + Lock screen improvements:
  - Hide user menu and a11y menu in the screen lock (bgo#681143)
  - Bump the lock screen slightly when pressing a key
    (bgo#681143)
  - Constrain vertical movement of the screen shield (bgo#681143)
  - Return to lock screen on idle (bgo#682041)
  - Unlock screen automatically after fast-user switching
    (bgo#682096)
  - Fix "other user" label (bgo#681750)
  + Constrain content of system modals to primary monitor
    (bgo#681743)
  + Respect automatic lock setting on suspend/user-switch
    (bgo#680231)
  + Improve styling of keyring prompt (bgo#681821)
  + Do not hard-code <super> as overlay-key (bgo#665547)
  + Update style of attached modal dialogs (bgo#681601)
  + a11y: allow navigation on non reactive items (bgo#667439,
    bgo#667439)
  + Implement mode-less overview design (bgo#682109)
  + Implement message-tray redesign:
  - Restyle the message tray (bgo#677213, bgo#682342)
  - Move the desktop upwards when showing the tray (bgo#681392)
  - Add a close button to notifications (bgo#682253)
  - Add a keybinding to toggle the tray (bgo#681392)
  - Make the tray keyboard navigable (bgo#681519)
  - Add dwelling at the bottom of the screen to open the tray
    (bgo#682310)
  - Don't time out banners when the user is inactive
  - Misc fixes and cleanups
  + Fix showing "Next Week" on Sundays (bgo#682198)
  + Delay restoring IM presence until the network comes up
    (bgo#677982)
  + Display enterprise login hint (bgo#681975)
  + Ignore unrecognized/irrelevant network devices/connections
    (bgo#682364)
  + Misc bug fixes and cleanups: bgo#643687, bgo#682045, bgo#682189
  + Updated translations.
* Tue Aug  7 2012 dimstar@opensuse.org
- Update to version 3.5.5:
  + Update style to match mockups
  - improve calendar layout and legibility
  - update notifications and menus
  - use a common style for entries
  - update scrollbars to match GTK+
  - improve lock/unlock button in lock screen
  - update polkit dialogs
  + Fix login dialog growing when selecting different users
    (bgo#675076)
  + Implement screen lock in the shell (bgo#619955, bgo#681143)
  + Minor login dialog improvements
  - update style to match the overall visuals (bgo#660913)
  - indicate whether users are logged in (bgo#658185)
  + Add support for background-repeat CSS property (bgo#680801)
  + Add :active pseudo class on scroll handles
  + Remove markup from translated strings (bgo#681270)
  + Misc bug fixes: bgo#677893, bgo#679944, bgo#680064, bgo#680170,
    bgo#680216, bgo#680426, bgo#681101, bgo#681382
  + Updated translations.
- Rebase gnome-shell-private-connection.patch.
* Sat Jul 21 2012 dimstar@opensuse.org
- Update to version 3.5.4:
  + Fix wrong result handling of remote calls (bgo#678852)
  + dateMenu: Fix regression that caused no date to be displayed
  + WindowTracker: Fix refcounting bug in get_app_for_window()
    (bgo#678992)
  + Show the workspace switcher for move-to-workspace keybinding
    (bgo#674104, bgo#660839, bgo#679005)
  + userMenu: Move "Power off" item to the bottom (bgo#678887)
  + Remove contacts search provider (bgo#677442)
  + network: don't ask for always-ask secrets when interaction
    isn't allowed (bgo#679091)
  + PolkitAgent: Look for the right password prompt (bgo#675300)
  + Implement extension updates (bgo#679099)
  + userMenu: Don't disconnect account signals when disabled
    (bgo#669112)
  + Fix startup notification when opening calendar (bgo#677907)
  + networkAgent: use absolute path if configured (bgo#679212)
  + recorder: Port to GStreamer-1.0 API (bgo#679445)
  + telepathyClient: don't add log messages on presence changes
    (bgo#669508)
  + lookingGlass: Don't use a signal callback on 'paint' to draw
    the border (bgo#679464)
  + Add support for inhibiting automount (bgo#678597)
  + Implemented banner support for the login screen (bgo#665346)
  + boxpointer:
  - Flip side if we would end outside the monitor (bgo#678164)
  - Change 'animate' parameter on show/hide to a bitmask
    (bgo#678337)
  + Add a grayscale effect (bgo#676782, bgo#674499)
  + UserMenu: show "Install Updates & Restart" when appropriate
    (bgo#677394, bgo#680080)
  + messageTray: don't show the message tray when a new
    notification is shown (bgo#677210)
  + panel: don't break when indicator has no menu (bgo#678694)
  + appMenu: Disable app menu during startup animations
    (bgo#672322)
  + autorun: Add a notification when unmounting drives (bgo#676125)
  + st-icon: Fix potential crash involving shadows (bgo#679776)
  + Remove manual garbage collection on tweeners end (bgo#679832)
  + dash: hide tooltips when overview begins hiding (bgo#674241)
  + Update modal dialog animation for new centered position
    (bgo#674499)
  + calendar: Fix grid lines in RTL locales (bgo#679879)
  + Integrate IBus with keyboard indicator (bgo#641531)
  + Move ibus status icon under keyboard
  + gdm: port from libgdmgreeter to libgdm (bgo#676401)
  + Misc bug fixes and cleanups: bgo#678978, bgo#672790,
    bgo#679847, bgo#679944
  + Updated translations.
- Replace pkgconfig(gstreamer-(base-)0.10) BuildRequires with
  pkgconfig(gstreamer-(base-)1.0), following upstreams move.
- Drop pkgconfig(folks) BuildRequires: dependency dropped upstream.
- Drop gnome-shell-fix-memory-leaks.patch: fixed upstream.
* Sat Jul 21 2012 dimstar@opensuse.org
- Update to version 3.5.3:
  + calendar: Adapt to Evolution-Data-Server API changes
    [bgo#677402]
  + messageTray: Don't show non urgent notifications while in
    fullscreen [bgo#677590]
  + modalDialog: show dialogs on monitor with the mouse pointer
    [bgo#642591]
  + extensionSystem: Prepare for extension updating system
    [bgo#677586]
  + appDisplay: Don't show apps in NoDisplay categories in the All
    view [bgo#658176]
  + st: Trigger theme updates on resolution changes [bgo#677975]
  + Always enable a11y [bgo#678095]
  + telepathyClient: ignore invalidated channels [bgo#677457]
  + shell-app: Update app menu if necessary [bgo#676238]
  + Enable the Screen Reader menu item [bgo#663256]
  + Disable unredirection when a modal operation is active
  + Make folks optional
  + Improve mount-operation support
  - Fix exception when showing password entry [bgo#678428]
  - Close the password entry on operation abort [bgo#673787]
  - autorun: Don't allow autorun for things we mount on startup
    [bgo#660595]
  - Turn passphrase prompt into a dialog [bgo#674962]
  - Implement org.Gtk.MountOperationHandler [bgo#678516]
  + Network menu improvements
  - Sort Wifi networks by strength [bgo#658946]
  - Prefer wifi/3g over VPN in the panel [bgo#672591]
  + clock: Switch to using GnomeWallClock [bgo#657074]
  + remoteSearch: Allow to reference .desktop file for Title/Icon
    [bgo#678816]
  + Bugs fixed: bgo#658955, bgo#677426, bgo#677497, bgo#677515,
    bgo#678079, bgo#678096, bgo#678396, bgo#678406, bgo#678416,
    bgo#678502, bgo#678737.
  + Updated translations.
- Add pkgconfig(atk-bridge-2.0) BuildRequires: new dependency.
- Drop gnome-shell-link-ext.patch: fixed upstream.
- Drop gnome-common BuildRequires and call to gnome-autogen.sh: we
  no longer carry any patches touching the build system.
* Sat Jul 21 2012 dimstar@opensuse.org
- Update to version 3.5.2:
  + notificationDaemon: Match app based on WM_CLASS [bgo#673761]
  + NetworkMenu: use network-offline while loading [bgo#674426]
  + lookingGlass: Remove the Errors tab [bgo#675104]
  + Accessibility fixes [bgo#672242, bgo#675307, bgo#675341]
  + Magnifier: Add brightness and contrast functionality
    [bgo#639851]
  + theme: use a smaller border-radius for top bar [bgo#672430]
  + placeDisplay: use new bookmark file location [bgo#675443]
  + port all synchronous search providers to the async API
    [bgo#675328]
  + NetworkAgent: disallow multiple requests for the same
    connection/setting [bgo#674961]
  + userMenu: Update to latest mockups [bgo#675802]
  + Fix formatting of bluetooth passkey [bgo#651251]
  + notificationDaemon: Filter out file-transfer notifications
    [bgo#676175]
  + Fix broken extension loading in some distributions [bgo#670477]
  + shell-app: Raise windows in reverse order to preserve the
    stacking [bgo#676371]
  + Generalize gdm-mode [bgo#676156]
  + panel: Refuse to add (legacy) status icons not part of the
    session mode [bgo#677058]
  + Add an initial-setup mode [bgo#676697]
  + status/keyboard: Port to the new input sources settings
    [bgo#641531]
  + NetworkMenu: show notifications for failed VPN connections
    [bgo#676330]
  + userMenu: Indicate progress on status changes [bgo#659067]
  + recorder: Honor "disable-save-to-disk" lockdown key
    [bgo#673630]
  + Fix empathy's appMenu freezing the shell [bgo#676447]
  + Code cleanups: bgo#672807, bgo#672413, bgo#676837, bgo#676850,
    bgo#672272
  + Misc bug fixes: bgo#659968, bgo#661236, bgo#661615, bgo#672192,
    bgo#672711, bgo#672713, bgo#673177, bgo#673198, bgo#674210,
    bgo#674323, bgo#674377, bgo#674424, bgo#674961, bgo#675006,
    bgo#675078, bgo#675128, bgo#675301, bgo#675370, bgo#675479,
    bgo#675527, bgo#675789, bgo#676316, bgo#676347, bgo#676806,
    bgo#677001, bgo#677097, bog#675790.
  + Updated translations.
- Add pkgconfig(gnome-desktop-3.0) BuildRequires: new dependency.
- Add pkgconfig(gsettings-desktop-schemas) BuildRequires so it can
  be versioned.
* Sat Jul 21 2012 badshah400@gmail.com
- Update to version 3.4.2:
  + Mirror Evolution calendar settings into our own schema
    [bgo#674424]
  + gdm: don't fail if fprintd unavailable [bgo#675006]
  + Fix broken extension loading [bgo#670477]
  + Fix filtering of Empathy notifications [bgo#675370]
  + telepathyClient: Ignore invalidated channels [bgo#677457]
  + popupMenu: Fix freeze when appMenu is not populated in one go
    [bgo#676447]
  + mount-operation: fix exceptions when showing password entry
    [bgo#678428]
  + Misc. fixes [bgo#677441, bgo#676175]
- Drop gnome-shell-load-ext.patch: fixed upstream.
- Drop gnome-shell-chat-notifications-fix.patch: fixed upstream.
* Thu Jul 19 2012 badshah400@gmail.com
- Add gnome-shell-chat-notifications-fix.patch to fix several
  issues with chat notifications in gnome-shell including a
  regression introduced in the 3.4.x series [bgo#677457,
  bgo#676175, bgo#675370]; all patches came from upstream git
  commits.
* Sat Jul 14 2012 badshah400@gmail.com
- Add various memory-leak fixes for gnome-shell from upstream git
  as gnome-shell-fix-memory-leaks.patch [bgo#678079, bgo#678406,
  bnc#771565].
* Thu Jun 28 2012 dimstar@opensuse.org
- Add gnome-shell-private-connection.patch: create private
  connections if the user is not authorized. [bnc#751211].
* Wed May  2 2012 dimstar@opensuse.org
- Add gnome-shell-link-ext.patch: Link libgnome-shell-js.so into
  gnome-shell binary to ensure it the typelib can be loaded. This
  is rather hacky, but as the .typelib is interfaced and loads
  libs from non-standard folders this fails badly (bnc#755862,
  bgo#670477).
- Add gnome-common BuildRequires and call to gnome-autogen.sh, as
  above patch touches the build system.
* Wed Apr 18 2012 vuntz@opensuse.org
- Update to version 3.4.1:
  + Fix crash that occurred when an icon theme change caused
    unexpected reentrancy in the icon loading code [bgo#673512]
  + Don't show system and other disabled users in the GDM user list
    [bgo#673784]
  + Make gnome-shell-calendar-server initialize GTK+ so it can
    display password prompts if needed [bgo#673608]
  + Adapt to Mutter API change for keybinding addition [bgo#673014]
  + Fix crash when an extension was installed as both a user
    extension and a system extension [bgo#673613]
  + Fix bug where chat entry could end up partially offscreen
    [bgo#661944]
  + Fix problem where icons weren't updating when theme was changed
    [bgo#672941]
  + Look for Evolution calendar settings in GSettings, not GConf
    [bgo#673610]
  + Add <super>F10 for the application menu [bgo#672909]
  + Fix %%Id format characters to work in translations [bgo#673106]
  + Fix error when NetworkManager restarts [bgo#673043]
  + Improve efficiency of overview redraws by working around
    Clutter issue [bgo#670636]
  + Misc bug fixes [bgo#672592, bgo#672641, bgo#672719, bgo#673187,
    bgo#673233, bgo#673656]
  + Updated translations.
* Mon Mar 26 2012 vuntz@opensuse.org
- Update to version 3.4.0:
  + Don't crash when taking screenshots [bgo#672775]
  + Fix dialog-resizing problem [bgo#672543]
  + Updated translations.
* Tue Mar 20 2012 dimstar@opensuse.org
- Update to version 3.3.92:
  + Add shell-dialogs for GNOME Keyring prompts (bgo#652459,
    bgo#652460 and bgo#671034)
  + When the user returns from idle, bring up the message tray if
    there were messages while they were away (bgo#643014)
  + https://live.gnome.org/EveryDetailMatters
  - Make the workspace thumbnails clickable all the way to the
    edge of the screen (bgo#643319)
  - Don't slide out the workspace thumbnails if the mouse is over
    them when entering the overview (bgo#651092)
  - Fix placeholder jumps while dragging a dash item (bgo#651842)
  - Don't favorite apps if they are dropped back at the same
    position (bgo#656333)
  - To avoid confusion, don't allow removing running apps from
    favorites (bgo#644853)
  - Fix creation of new workspaces by dragging application
    launchers (bgo#664202)
  - Make it easier to drag dash items without triggering the menu
  + Accessibility:
  - Add StWidget API for easily adding accessible states and
    setting roles, names (bgo#668366, bgo#667432 and bgo#671378)
  - Set accessibility information on UI elements (bgo#644255,
    bgo#667432, bgo#668361, bgo#672047, bgo#670308, bgo#670312,
    bgo#670719 and bgo#671404)
  + Improve key-navigation in the overview (bgo#663901)
  + Key navigation bug fixes (bgo#662493, bgo#663437, bgo#665215
    and bgo#671998)
  + Honor a 'org.gnome.shell.overrides.dynamic-workspaces' setting
    that determines whether the workspace count is dynamic and
    unsaved in GSettings or static and saved (bgo#671568)
  + Avoid saving user presence to GSettings when not necessary
    (bgo#665701, bgo#668214)
  + Save screencasts in the users Videos/ directory (bgo#670749)
    and use a "human readable" filename (bgo#670753)
  + Allow dragging from the empty part of the top panel to
    unmaximize a window (bgo#666359)
  + Fix hangs that could occur when switching away to a VT
    (bgo#653833)
  + Fix problems with installing from extensions.gnome.org
    (bgo#671134)
  + Fix locking the screen when suspending via menu (bgo#670820)
  + Fix browser plugin with Konqueror and Opera
  + Fix shell restart not to bring up failure screen (bgo#648384)
  + Reorganize and clean up CSS theming (bgo#668209)
  + Improve appearance of modal dialogs (bgo#670227, bgo#668209)
  + Update the calendar code to use ECalClient (bgo#671177)
  + Update jhbuild script to use the main moduleset (bgo#668440)
  + StTextureCache: code cleanup, evict unused icons, merge
    together simulataneous requests for the same icon (bgo#670771,
    bgo#671656 and bgo#672273)
  + Clean up St for recent Clutter changes and fix bugs.
    StContainer and StGroup are removed (bgo#670034, bgo#670640,
    bgo#670904)
  + Code cleanup (bgo#613194, bgo#671086, bgo#671103)
  + Misc bugs fixed: bgo#651130, bgo#658946, bgo#667552,
    bgo#670076, bgo#671001, bgo#670979, bgo#671410, bgo#671411,
    bgo#671556, bgo#671656, bgo#671657, bgo#672011, bgo#672024,
    bgo#672240, bgo#672265, bgo#672270, bgo#672321, bgo#672326,
    bgo#672413, bgo#672471.
  + Updated translations.
- Add pkgconfig(gcr-3) BuildRequires for the new keyring dialogs.
* Tue Feb 28 2012 dimstar@opensuse.org
- Add fortune Recommends for Wanda to work.
* Thu Feb 23 2012 vuntz@opensuse.org
- Update to version 3.3.90:
  + Allow other applications to implement search providers via
    D-Bus [bgo#663125, bgo#670148]
  + Remove "Recent Items" search, as replaced by Documents search
    [bgo#663125]
  + Allow NetworkManager VPN plugins to use a shell-themed dialog
    [bgo#658484]
  + Port away from deprecated Clutter API [bgo#670034]
  - StTooltip is removed
  - StWidget is now a concrete class and can be instantiated
  - st_container_destroy_children(),
    st_box_layout_insert_actor(), and other functions removed in
    favor of new replacements in Clutter.
  + Use systemd for console/session handling when available
  + Visual improvements to contact search, padding, top panel,
    checkboxes [bgo#669489, bgo#669811, bgo#669993]
  + Add a include_cursor parameter to Screenshot and
    ScreenshotWindow D-Bus methods [bgo#670086]
  + Add a "FlashArea" D-Bus method to do the screenshot flash
    without a screenshot [bgo#669660]
  + Build fixes [bgo#658484, bgo#669637]
  + Misc bug fixes [bgo#642135, bgo#658484, bgo#658908, bgo#667694,
    bgo#669098, bgo#669921, bgo#669662, bgo#669694, bgo#669776,
    bgo#669887, bgo#669921, bgo#670005, bgo#670006, bgo#670319,
    bgo#670418, bgo#670489]
  + Updated translations.
- Add pkgconfig(libsystemd-daemon) and pkgconfig(libsystemd-login)
  BuildRequires: build systemd support. Note that it nicely falls
  back to ConsoleKit if systemd is not used on the system.
- Remove pkgconfig(gnome-desktop-3.0) BuildRequires: not needed
  anymore.
- Add gnome-shell-search-provider-documents Recommends: this is the
  D-Bus service in gnome-documents that allow searching in
  documents from the shell.
- Manually create the %%{_datadir}/gnome-shell/search-providers
  directory in install, so that we can own this directory where
  search providers install a .ini file.
* Wed Feb  8 2012 vuntz@opensuse.org
- Update to version 3.3.5:
  + Extension system: [bgo#668429]
    http://blog.mecheye.net/2012/02/more-extension-api-breaks/
  - Add a 'gnome-shell-extension-prefs' application for displaying
    extension preferences as provided by the extension in a
    prefs.js file.
  - Allow launching gnome-shell-extension-prefs from
    extensions.gnome.org through the browser plugin.
  - Add ExtensionUtils.getCurrentExtension() for an extension to
    get a handle to an extension object, to get local imports or
    paths.
  - Add an onshellrestart callback to the browser plugin
    [bgo#668517]
  + Screenshots:
  - Move the screenshot "flash" to the shell [bgo#668618]
  - Move saving screenshots to a thread [bgo#652952]
  - Correctly screenshot rounded decorations [bgo#662486]
  + Screen recorder:
  - Change the default pipeline to favor speed over quality
    [bgo#669066]
  - Drop frames to keep from running the user out of memory
    [bgo#669066]
  + Work around a slow implementation of glReadPixels() in the
    Intel drivers, improving performance for screenshots and the
    screen recorder [bgo#669065]
  + Use Keywords field in desktop files when search for
    applications [bgo#609702]
  + Strip debian- when matching desktop file names [bgo#665647]
  + Fix up various problems from CSS background size-addition
    [bgo#668430, bgo#633462]
  + UI tweaks and behavior fixes [bgo#643867, bgo#666197,
    bgo#664622]
  + Some improvements to exported accessibility information
    [bgo#667376]
  + Don't show contacts without IM information as offline
    [bgo#662685]
  + Don't change status from hidden to extended_away when going
    idle [bgo#642408]
  + Cleanups [bgo#662152, bgo#669239]
  + Misc bug fixes [bgo#633462, bgo#643867, bgo#662213, bgo#662386,
    bgo#662747, bgo#665000, bgo#665017, bgo#665322, bgo#667371,
    bgo#667860, bgo#668020, bgo#668517, bgo#668541, bgo#669236]
  + Updated translations.
- Remove xz BuildRequires now that it comes for free in the build
  system.
* Sat Jan 21 2012 vuntz@opensuse.org
- Update to version 3.3.4:
  + https://live.gnome.org/EveryDetailMatters
  - Add "browse" for labels for dash items: once a tooltip is
    showing, switch to other items without a delay [bgo#666170]
  - Always scale down windows in the overview at least to 70%%
    [bgo#646704]
  - Fix the new-workspace drop indicator sometimes getting stuck
    [bgo#664201]
  - Delay rearranging windows in the overview as long as the
    pointer is over a window [bgo#645325]
  + Add a GConf => DConf migration file for overriden Mutter
    settings [bgo#667636]
  + When a VPN connection is active, show that as the network icon
    [bgo#665115]
  + Handle the "ExtendedAway" IM status as away, not offline
    [bgo#667813]
  + Improve the appearance of the labels in "Applications"
    [bgo#642392]
  + Adjust for GTK+ and Mutter API changes for application menu
    [bgo#668118]
  + Add section label support to the application menu [bgo#666681]
  + Fix screenshot methods to work again [bgo#667662]
  + Fix several crashers related to updating workspace thumbnails
    [bgo#667652]
  + Fix memory management error causing gnome-shell-hotplug-sniffer
    to crash [bgo#667378]
  + Build fixes [bgo#667864]
  + Code cleanups [bgo#668087]
  + Misc bug fixes [bgo#633028, bgo#658817, bgo#664138, bgo#667881,
    bgo#668048, bgo#668050]
  + Updated translations.
- Drop gnome-shell-link-gl.patch: fixed upstream.
- Remove gnome-common BuildRequires and call to gnome-autogen.sh:
  those were only needed for patch above.
* Wed Jan 18 2012 vuntz@opensuse.org
- Add gnome-shell-link-gl.patch: explicitly link to GL as cogl
  doesn't do that anymore.
- Add gnome-common BuildRequires and call to gnome-autogen.sh,
  needed for above patch.
- Add pkgconfig(gl) BuildRequires: new dependency.
* Thu Jan  5 2012 vuntz@opensuse.org
- Update to version 3.3.3:
  + https://live.gnome.org/EveryDetailMatters
  - Stop flashing the window labels on actions in overview
    [bgo#644861]
  - Improve the look of window captions in the overview
    [bgo#664487]
  - Move dash tooltips beside the icon [bgo#666166]
  + Support application menus exported from applications via new
    GLib API and D-Bus protocol.
  + For removable device prompts, show "Open with Rhythmbox",
    rather than "Open with Rhythmbox Music Player" [bgo#664561]
  + Switch to activating the message tray only with a hot corner
    rather than a full row of pixels, allowing mouse events to apps
    [bgo#663366]
  + Fully handle the case where the workspaces-only-on-primary
    GSetting is set to false [bgo#652580]
  + Add support for background-size CSS property to St [bgo#633462]
  + Port to new GJS Lang.Class framework [bgo#664436]
  + Finish port to GDBus [bgo#664436]
  + Stop using the deprecated Clutter default stage [bgo#664052]
  + Fix bugs that kept browser plugin from working in WebKit-based
    browser [bgo#666444]
  + Fix typo that made uninstalling extensions not work
  + Fix crash in browser plugin if shell is not run
  + Reintroduce piscine paschal ovum [bgo#666606]
  + Network menu bug fixes [bgo#664124, bgo#665194, bgo#665680,
    bgo#666429, bgo#666614]
  + Misc bug fixes [bgo#647587, bgo#659272, bgo#665261, bgo#666020,
    bgo#666243]
  + Updated translations.
- Add xz BuildRequires because we can't build a package for a
  xz-compressed tarball without explicitly specifying that... See
  bnc#697467 for more details.
- Remove dbus-1-python Requires: there's no python script requiring
  dbus anymore, since quite some time.
* Wed Dec 21 2011 vuntz@opensuse.org
- Remove pkgconfig(dbus-glib-1) and pkgconfig(gconf-2.0)
  BuildRequires: the dependencies has been removed in 3.3.2.
- Create devel subpackage for the API documentation.
* Mon Dec 12 2011 vuntz@opensuse.org
- Drop gnome-shell-clutter-1.10.patch: this actually breaks
  gnome-shell as we need a clutter patch too, which is not ready
  yet.
* Tue Nov 22 2011 dimstar@opensuse.org
- Update to version 3.3.2:
  + Port D-Bus usage in the shell to GDBus [bgo#648651, bgo#658078,
    bgo#663902, bgo#663941]
  + Message tray:
  - Add right-click option to chats to mute the conversation
    [bgo#659962]
  - Don't steal the focus when popping up under the pointer
    [bgo#661358]
  + Looking Glass:
  - Add alt-Tab completion [bgo#661054]
  - Show errors from extensions in the extensions tab
    [bgo#660546]
  - Allow switching tabs with <Control>PageUp/PageDown
  - Theme consistently with the rest of the shell [bgo#650900]
  + Extension system:
  - Don't try to load disabled extensions at all [bgo#661815,
    bgo#662704]
  - Enable and disable plugins in a consistent order [bgo#661815,
    bgo#662704]
  - Add options to enable/disable extensions to
    gnome-shell-extension-tool [bgo#661815]
  + Adapt to Mutter change to GSettings [bgo#663429]
  + Allow creating a new workspace by dragging a window or launcher
    in the middle of two existing ones [bgo#646409]
  + Allow using Alt-Tab while during drag-and-drop and other
    operations that grab the pointer [bgo#660457]
  + Do a better job of finding the right user to authenticate as
    when showing a PolKit dialog [bgo#651547]
  + Control the D-Bus Eval() method by the developer-tools GSetting
    which is used for looking glass and screen recorder.
    [bgo#662891]
  + Fix browser plugin to work under WebKit-based browser
    [bgo#663823]
  + Fix certain stacking issues with alt-Tab [bgo#660650]
  + Fixes for GLib deprecations [bgo#662011]
  + Fixes for GTK+ deprecations [bgo#662245]
  + Fixes for Clutter deprecations [bgo#662627]
  + Visual improvements and UI tweaks [bgo#662800, bgo#658096,
    bgo#662226]
  + Hard-code "Home" as the name for the home dir, rather than
    looking it up via GSettings; avoids schema dependency
    [bgo#559895]
  + Don't show "Switch User" on single user machines [bgo#657011]
  + Generate documentation for St toolkit
  + Improve marking of strings for translation [bgo#658664]
  + Networking menu bug fixes [bgo#650007, bgo#651378, bgo#659277,
    bgo#663278]
  + Code cleanups and leak fixes to StTextureCache [bgo#660968,
    bgo#662998]
  + Code cleanups [bgo#662238, bgo#663584]
  + Build fixes
  + Bugs fixed: bgo#660520, bgo#661029, bgo#661231, bgo#661623,
    bgo#661921, bgo#662235, bgo#662236, bgo#662502, bgo#662394,
    bgo#662799, bgo#662969, bgo#663175, bgo#663277, bgo#663815,
    bgo#663891, bgo#662967
  + Updated translations.
- Drop gnome-shell-cleanup-signal-handlers-on-destroy.patch and
  gnome-shell-fix-deprecated-call.patch: fixed upstream.
- Add gnome-shell-clutter-1.10.patch: Fix build with clutter 1.10.
- Remove gconf schema handling scriptlets, there are no more gconf
  schemas being used.
* Wed Oct 26 2011 fcrozat@suse.com
- Add dependencies on libaccountsservice0, libgdmgreeter1 and
  libcaribou0 for 11.4.
* Mon Oct 24 2011 fcrozat@suse.com
- Add gnome-shell-fix-deprecated-call.patch: fix deprecated call in
  telepathy client [bgo#661231]
* Thu Oct 20 2011 sysrich@linux.com
- Add gnome-shell-cleanup-signal-handlers-on-destroy.patch to fix
  some issue when using extensions changing the usermenu
  [bgo#660520 and bnc#725004]
* Tue Oct 18 2011 dimstar@opensuse.org
- Update to version 3.2.1:
  + Restore the IM state on startup: if you were available when you
    logged out, then you'll be set available again when you log in.
    [bgo#659021, bgo#661485]
  + Improve searching for contacts in the overview: search more
    fields, show a more meaningful name, require that all search
    terms match. [bgo#660580]
  + Improve search for applications in the overview: take frequency
    into account and tweak match algorithm [bgo#623372]
  + Remove the "Show Password" switch from network password prompts
    and move the functionality to a right-click menu [bgo#658948]
  + Add context menus with Cut/Paste options to most entries
    [bgo#659275]
  + On screen keyboard:
  - Show the keyboard immediately when it's enabled [bgo#659743]
  - Fix problem where keyboard would hide when starting to type
    in the search entry [bgo#661340]
  - Fix problem with keyboard hiding when selected accented
    characters [bgo#661707]
  + Login mode:
  - Allow hitting Enter to select the first user [bgo#657996]
  - Fix flicker of a fingerprint prompt that could show up
    [bgo#660792]
  - Fix password bullets vanishing during login [bgo#657894]
  - Misc bug fixes and visual tweaks [bgo#659763, bgo#660919,
    bgo#661479]
  + Display a caps-lock warning in password entries [bgo#660806]
  + Show the state of installed extensions in Looking Glass
    [bgo#660494]
  + Load user extensions after system ones [bgo#661815]
  + Fix problem with many applications showing extra-large icons in
    notifications [bgo#659158]
  + Fix a problem where alt-Tab had trouble tracking the current
    application with certain applications such as Emacs
    [bgo#645026]
  + Fix confusion between different users avatar images
    [bgo#660585]
  + Remove behavior where you could switch workspaces by bumping a
    dragged window in the overview against a screen edge; it was
    leftover and just confusing. [bgo#660838]
  + Fix long-standing bug where the Dash in the overview could end
    up mis-sized and run off the screen [bgo#649248]
  + Fix automatic launching of applications when media is inserted
    [bgo#660821]
  + Fix handling of vertically stacked monitors with NVIDIA drivers
    [bgo#661387]
  + Code cleanups and warning fixes [bgo#659822, bgo#659940,
    bgo#660122, bgo#660358, bgo#660968 and bgo#661231]
  + Small memory leak fixes [bgo#661231]
  + Misc bug fixes [bgo#659274, bgo#659861, bgo#660166, bgo#660310,
    bgo#660397, bgo#660608, bgo#660606, bgo#660674, bgo#660774.
    bgo#660848, bgo#661151, bgo#661617]
  + Updated translations.
* Mon Sep 26 2011 vuntz@opensuse.org
- Update to version 3.2.0:
  + Prevent the fallback on-screen keyboard from showing up while
    GNOME Shell is running [bgo#659865]
  + Disable code to reposition windows around the on-screen
    keyboard; it wasn't finished or working properly. [bgo#659643]
  + Fix interaction between on-screen keyboard and notifications
    [bgo#658603]
  + Fix menu-sizing problems in right-to-left locales. [bgo#659827]
  + Update chat icons in the message tray when an avatar image
    changes [bgo#659768]
  + Fix problem with empty notification bubbles being left
    [bgo#659862]
  + Fix problem with chat notifications bouncing when new messages
    come in. [bgo#659768]
  + Fix bug that was causing SIP calls to automatically be accepted
    in some circumstances [bgo#660084]
  + Fix string that should have been marked translatable
  + Fix a crash that could happen during CSS transitions
    [bgo#659676]
  + Build fixes
  + Updated translations.
* Wed Sep 21 2011 vuntz@opensuse.org
- Update to version 3.1.92:
  + Login screen
  - Add the ability to set a logo at the top of the user list
    [bgo#658062]
  - Add fingerprint reader support [bgo#657823]
  - Add a power button offering the choice of
    Suspend/Restart/Power off [bgo#657822]
  - Remove the option to view the current keyboad layout
    [bgo#659164]
  - Make Control-Alt-Tab work for full keyboard access
    [bgo#659177]
  + Frequently initiate a full garbage collection; Spidermonkey
    isn't very good at tracking the amount of resources we have
    allocated so this hopefully will improve memory usage without
    affecting performance too much [bgo#659254]
  + Stop adding a notification when the network connection is lost
    [bgo#658954]
  + When disabling notifications; display a notification "Your chat
    status will be set to busy" [bgo#652718]
  + Fix keynav in network dialogs [bgo#659133]
  + Improve calendar styling [bgo#641135, bgo#651299]
  + Shrink padding around panel buttons for narrow screens
    [bgo#651299]
  + Allow enabling the onscreen keyboard through the accessibility
    menu [bgo#612662]
  + Fix problem that was causing VPN secret dialogs to be delayed
    before showing [bgo#658484]
  + Make custom-keybindings for the window switcher that don't use
    alt work correctly [bgo#645200]
  + Fix duplicate application icons in the Activities Overview
    [bgo#659351]
  + Bug fixes for dimming windows with attached modal dialogs
    [bgo#659302, bgo#659634]
  + Add build-time support for BROWSER_PLUGIN_DIR environment
    variable [bgo#659123]
  + Build fixes [bgo#659194]
  + Code cleanups and test cases [bgo#651299, bgo#658092,
    bgo#658939]
  + Misc bug fixes [bgo#651299, bgo#652837, bgo#657249, bgo#658004,
    bgo#658150, bgo#658239, bgo#658469, bgo#658598, bgo#658605,
    bgo#659050, bgo#659159, bgo#659210, bgo#659270, bgo#659370,
    bgo#659633]
  + Updated translations.
- Drop gnome-shell-fix-service.patch: fixed upstream.
- Drop gnome-shell-plugin-dir.patch: fixed upstream.
- Remove gnome-common BuildRequires and call to gnome-autogen.sh:
  those were needed only for the patches above.
* Thu Sep 15 2011 vuntz@opensuse.org
- Update to version 3.1.91.1:
  + Add a browser plugin: this plugin, tied to extensions.gnome.org,
    allows users to download and install shell extensions, and
    enable, disable, and uninstall extensions they already have
    installed. [bgo#658070, bgo#658612]
  + Improve adding links to URLs in notifications [bgo#636252]
  + Remove "connection lost" notifications after reconnecting
    [bgo#658049]
  + Hide the onscreen keyboard when leaving a text entry
    [bgo#658591]
  + Fixes for translated strings [bgo#639987, bgo#644097,
    bgo#645037]
  + Bug fixes for network menu [bgo#658492]
  + Code cleanup [bgo#646934]
  + Build fixes
  + Misc bug fixes [bgo#652837, bgo#658423, bgo#658503, bgo#658525,
    bgo#658562, bgo#658624, bgo#658640, bgo#658983]
  + Updated translations.
- Add pkgconfig(json-glib-1.0): new dependency.
- Add --with-ca-certificates=%%{_sysconfdir}/ssl/ca-bundle.pem to
  configure, so that gnome-shell knows where to find the
  certificates.
- Add gnome-shell-fix-service.patch: fix build of a dbus .service
  file so that it's created from the correct file (instead of
  duplicating another .service file).
- Fix browser plugin installation:
  + Add gnome-shell-plugin-dir.patch: let us easily specify where
    the browser plugin should get installed.
  + Add gnome-common BuildRequires and call to gnome-autogen.sh,
    needed for above patch.
  + Export BROWSER_PLUGIN_DIR=%%{_libdir}/browser-plugins to install
    the browser plugin in the right directory.
- Create a gnome-shell-browser-plugin subpackage for this new
  browser plugin. Add a Recommends for it to gnome-shell, since it
  makes sense to have it by default.
* Wed Sep  7 2011 vuntz@opensuse.org
- Update to version 3.1.91:
  + Fix problem with applications vanishing from alt-Tab when
    desktop files change. [bgo#657990]
  + Fix interaction of on-screen keyboard with run-dialog and
    Looking Glass console [bgo#657986]
  + Add public API for adding and removing search providers
    [bgo#657548, bgo#658113]
  + Allow changing IM status with scroll wheel [bgo#657973]
  + Limit volume slider to 100%% [bgo#657607]
  + Change "Do Not Disturb" to "Notifications" in user menu
    [bgo#652718]
  + Switch browser in default favorites to Epiphany [bgo#650616]
  + Misc bug fixes [bgo#649631, bgo#655069, bgo#656142, bgo#657703,
    bgo#657759, bgo#658007, bgo#658065, bgo#658176]
  + Updated translations.
* Mon Sep  5 2011 vuntz@opensuse.org
- Update to version 3.1.90.1:
  + Fix typo that was breaking the "Login Screen" mode
  + Fix build with new gobject-introspection
  + Use a better icon for removable devices [bgo#657757]
  + Add support for asynchronous search provides [bgo#655220]
  + Misc bug fixes [bgo#657657, bgo#657696]
  + Misc build fixes [bgo#657697]
  + Updated translations.
- Changes from version 3.1.90:
  + Add an on-screen keyboard that uses Caribou as a backend
    [bgo#612662]
  + Allow searching for people in the overview using libfolks
    as the backend [bgo#643018]
  + Add a "Login Screen" mode to be used when GDM is running; this
    mode has a stripped down user interface, and also contains the
    code to display the user list and authentication. [bgo#657082]
  + Rework user menu to separate out "Do Not Disturb" from the IM
    status and to visually match GNOME Contacts. [bgo#652837]
  + Implement displaying images such as cover-art in notifications
    [bgo#621009]
  + Support default actions for notifications [bgo#655818]
  + Networking:
  - Stop using nm-applet for dialogs; do them as proper system
    modal dialogs in the shell code. [bgo#650244]
  - Fix handling of hidden access points [bgo#646454]
  + Telepathy integration:
  - Support subscription requests [bgo#653941]
  - Notify on account connection errors [bgo#654159]
  - Allow approving file transfers [bgo#653940]
  - Improve styling of messages [bgo#640271]
  + Extension system [bgo#654770]:
  - Support live enabling and disabling of extensions
  - Add the ability to install extensions from HTTP
  - Enhance D-Bus interface for controlling extensions
  - Collect errors separately for each extension
  + Add Main.panel.addToStatusArea for extension convenience
    [bgo#653205]
  + Port to the new gnome-menus API. Clean up and speed up
    application information loading [bgo#648149, bgo#656546]
  + Use the accountsservice library rather than cut-and-pasted GDM
    code [bgo#650893]
  + Add a D-Bus interface to take a screenshot; this will avoid
    various race conditions with the current gnome-screenshot
    approach [bgo#652952]
  + Show numeric indicators to distinguish duplicate keyboard names
    [bgo#650128]
  + Add GNOME Documents to the favorites list [bgo#657520]
  + Update the clock immediately on resume from suspend
    [bgo#656403]
  + Remove animation support from StAdjustment [bgo#657082]
  + Support configuration of calendar applications via gsettings
    [bgo#651190]
  + Don't fade in alt-Tab - wait a bit and show it instantly
    [bgo#652346]
  + Darken workspace background on all workspaces [bgo#656433]
  + Improve detection of the starting day of the week [bgo#649078]
  + Add StButtonAccessible
  + Visual tweaks to match mockups [bgo#640271, bgo#655627,
    bgo#655428, bgo#656732]
  + Misc bug fixes [bgo#645708, bgo#646761, bgo#653119, bgo#654398,
    bgo#656125, bgo#654707, bgo#654898, bgo#654638, bgo#656335,
    bgo#657111]
  + Code cleanups [bgo#652718, bgo#654639, bgo#648651, bgo#655813,
    bgo#657082]
  + String tweaks [bgo#652984, bgo#640271]
  + Build fixes [bgo#644275, bgo#655812]
  + Updated translations.
- Add pkgconfig(folks), pkgconfig(gnome-keyring-1),
  pkgconfig(libnm-util) BuildRequires: new dependencies.
- Change pkgconfig(libgnome-menu) BuildRequires to
  pkgconfig(libgnome-menu-3.0): this follows the move to the new
  gnome-menus API.
- Add gnome-contacts Requires: this is the application used to open
  contacts.
* Mon Aug  8 2011 dimstar@opensuse.org
- Use versioned BuildRequires.
* Thu Jul 28 2011 vuntz@opensuse.org
- Update to version 3.1.4:
  + Take over inserted media handling and autorun from
    gnome-settings-daemon
  + Message Tray:
  - Display a count of unread notifications on icons [bgo#649356,
    bgo#654139]
  - Only remove icons when the sender quits from D-Bus, not when
    it closes its last window [bgo#645764]
  - Solve problems switching chats between shell and Empathy
    [bgo#654237]
  - Fix handling of bad GMarkup in messages [bgo#650298]
  - Never show notifications when the screensaver is active
    [bgo#654550]
  + Telepathy integration:
  - Implement Telepathy Debug interface to enable
    empathy-debugger [bgo#652816]
  - Allow approving room invitations, and audio/video calls
    [bgo#653740, bgo#653939]
  - Send typing notifications [bgo#650196]
  + Fix selection highlighting for light-on-dark entries
    [bgo#643768]
  + Make control-Return in the overview open a new window
  + Delay showing the alt-Tab switcher to reduce visual noise when
    flipping betweeen windows [bgo#652346]
  + When we have vertically stacked monitors, put the message tray
    on the bottom one [bgo#636963]
  + Fix various problems with keynav and the Activities button
    [bgo#641253, bgo#645759]
  + Ensure screensaver is locked when switching users [bgo#654565]
  + Improve extension creation tool [bgo#653206]
  + Fix compatibility with latest GJS [bgo#654349]
  + Code cleanups [bgo#645759, bgo#654577, bgo#654791, bgo#654987]
  + Misc bug fixes [bgo#647175, bgo#649513, bgo#650452, bgo#651082,
    bgo#653700, bgo#653989, bgo#654105, bgo#654791, bgo#654267,
    bgo#654269, bgo#654527, bgo#655446]
  + Build fixes [bgo#654300]
- Add pkgconfig() BuildRequires for new dependencies:
  gdk-pixbuf-2.0, libsoup-2.4.
* Mon Jul 25 2011 vuntz@opensuse.org
- Remove gnome-power-manager Requires, as the features are now
  provided by gnome-settings-daemon (already in Requires).
* Wed Jul 20 2011 vuntz@opensuse.org
- Add gnome-themes-accessibility Requires for the "High Contrast"
  item in the accessibility status icon. Fix bnc#690176.
* Thu Jul  7 2011 vuntz@opensuse.org
- Drop default-applications.patch: the default applications are now
  set in gio-branding. Fix bnc#689610.
* Sat Jul  2 2011 vuntz@opensuse.org
- Remove hack to use Meta-3.1.gir for the build: mutter 3.1.3.1
  reverted back to Meta-3.0.gir.
- Remove gjs Requires: gnome-shell is now a binary, and uses
  libgjs, not the gjs binary.
- Add gnome-bluetooth, gnome-control-center, gnome-power-manager,
  gnome-screensaver, NetworkManager-gnome Requires: the bluetooth,
  power and network system icons, and the "System settings"/"Lock
  screen" menu items need the services provided by those packages
  to work.
* Fri Jul  1 2011 dimstar@opensuse.org
- Update to version 3.1.3:
  + Bluetooth
  - Show "hardware disabled" when disabled by rfkill
  - Fix bug updating status of devices
  + LookingGlass console:
  - Add a "Memory" tab
  - Make escape work from any page
  - Provide a way to refer to panel items as, e.g.,
    Main.panel._activities
  + Networking
  - keep wirelesss networks in predictable order
  - Show unmanaged devices in the menu
  - Fix overflow with too many VPN connections
  + Telepathy IM framework integration:
  - Switch to using telepathy-glib rather than talking to
    Telepathy via D-Bus
  - Acknowledge messages when the user clicks on them
  - Fix problem with telepathy icon blinking for incoming
    messages even though the user has been notified of them
  + User menu
  - Fix problem with suspend menu option locking the screen even
    when the user disabled that.
  - Hide "power off..." option if shutdown is disabled via
    PolicyKit
  + bgo#650971: Fix problem with "user theme extension" breaking
    the CSS for other extensions
  + Track changes to WM_CLASS: fixes problems with LibreOffice
    tracking
  + Remove app tracking workarounds for Firefox and LibreOffice
  + Use upstream gettext autoconfigury rather than glib version
  + Show messages in the message tray when an application is
    fullscreen
  + Don't autohide the workspace pager if there is more than one
    workspace
  + Don't always slide out the workspace pager at drag begin
  + Only offer to remove a favorite app when dragging it's icon
  + Allow dropping an icon anywhere on a workspace
  + st-scroll-view: Make the fade effect and offset themable
  + Obey the user's preference when running an application in a
    terminal from the run dialog
  + Consistently exit overview when launching external applications
  + Adapt to changes in GJS for how GObject APIs are bound
  + Fix problems with scrolling in overflow for alt-Tab switcher
  + Mark relationships between labels and actors for accessibility
  + Add org.gnome.shell.enabled-extensions complementing
    disabled-extensions GSetting
  + Visual tweaks
  + Switch to building against clutter-1.7 with independent Cogl
  + Code cleanups
  + Memory leak fixes
  + Build Fixes
  + Bugs fixed: bgo#608667, bgo#620105, bgo#631576, bgo#633620,
    bgo#639459, bgo#641570, bgo#642793, bgo#642895, bgo#643513,
    bgo#643594, bgo#645031, bgo#645585, bgo#645848, bgo#645990,
    bgo#646261, bgo#646580, bgo#646915, bgo#646919, bgo#646946,
    bgo#647186, bgo#647303, bgo#647395, bgo#647565, bgo#647807,
    bgo#647893, bgo#647907, bgo#648006, bgo#648048, bgo#648305,
    bgo#648410, bgo#648422, bgo#648562, bgo#648755, bgo#648758,
    bgo#648760, bgo#648894, bgo#649001, bgo#649203, bgo#649315,
    bgo#649508, bgo#649517, bgo#649633, bgo#649981, bgo#650317,
    bgo#650692, bgo#650869, bgo#650934, bgo#651012, bgo#651015,
    bgo#651086, bgo#651088, bgo#651138, bgo#651227, bgo#651569,
    bgo#651602, bgo#651606, bgo#651813, bgo#651866, bgo#652038,
    bgo#652079, bgo#652313, bgo#652327, bgo#652388, bgo#652597,
    bgo#652714, bgo#652715, bgo#652730, bgo#653078, bgo#653095,
    bgo#653142, bgo#653199, bgo#653275, bgo#653397, bgo#653511.
- Drop gnome-shell-no-file_get_contents.patch: fixed upstream.
- Add a hack to fix build against Mutter 3.1.3, which changed
  Meta-3.0.gir to Meta-3.1.gir. A simple find/replace in
  src/Makefile.{am,in} is enough. The build will fail with a new
  tarball that will have this fixed, to ensure the hack gets
  removed again. Reported as bgo#653795.
* Mon Jun 27 2011 vuntz@opensuse.org
- Add gnome-shell-no-file_get_contents.patch to fix a crash on
  startup. This is taken from git.
* Thu Jun  9 2011 vuntz@opensuse.org
- Remove unneeded Requires since gnome-shell is now a real binary
  (and not a python script calling mutter anymore): mutter,
  python-gconf, python-gobject.
* Thu May 26 2011 dimstar@opensuse.org
- Update to version 3.0.2:
  + Network Menu:
  - bgo#648174: Fix connecting to WPA2 Enterprise access points
  - bgo#649318: Show the mobile broadband wizard when selecting
    3G network
  - Bugs fixed: bgo#648648, bgo#650124
  + bgo#648739: Fix duplicate icons in the application browser
  + bgo#646660: Make clicking anywhere on the volume icon slider
    work
  + bgo#649427: Fix a case where activating and clicking the hot
    corner at the same time could result in immediately leaving the
    overview
  + bgo#643302: Fix a case where applications became misordered in
    Alt-Tab
  + bgo#650219: Fix a bug where messages you send could show up in
    notifications as if someone else sent them
  + Bugs fixed: bgo#642652, bgo#649508, bgo#649497, bgo#649596,
    bgo#648765, bgo#648983, bgo#649632.
  + Updated translations.
* Thu Apr 28 2011 malcolmlewis@opensuse.org
- Manually create %%{_datadir}/gnome-shell/extensions and own it:
  we don't want every extension to have to own it.
* Wed Apr 27 2011 fcrozat@novell.com
- Update to version 3.0.1:
  + Network menu:
  - bgo#646395: fix problems updating the menu for mobile
    broadband devices.
  - bgo#646074: fix missing device descriptions with multiple
    devices of the same type.
  - bgo#646141: label ad-hoc neworks with an appropriate icon.
  - bgo#646946: fix displaying some devices states as "invalid".
  - bgo#647040: fix problems with access points that don't report
    a SSID.
  - Miscellaneous minor bug fixes: bgo#645981, bgo#646558,
    bgo#646443, bgo#646708, bgo#646968.
  + Application menu and icon:
  - bgo#644122: fix bug where application menu icon was missing
    at GNOME Shell startup.
  - bgo#647082: fix missing application menu for dialog windows.
  - bgo#646689: when launching an application through an
    alternate launcher (like for a System Settings pane),
    association the windows with the application, not the
    launcher.
  + Activities overview:
  - bgo#647778: load the applications view incrementally to avoid
    potentially freezing for multiple seconds.
  - bgo#645801: fix bug where package installation while the
    overview was up could result in a corrupted application
    display.
  - bgo#645990: fix dragging from the search results to launch
    apps and docs.
  - bgo#646019: fix flickering of selection when searching in the
    overview.
  - bgo#636341: fix bug when typing into the search box when text
    was already selected.
  + bgo#646921: fix layout of notifications for right-to-left
    languages.
  + bgo#648132: remove a confusing special case where Alt-Tab
    sometimes switched to a different window of the same
    application rather than to a different application.
  + bgo#648132: fix a crash that could happen when a window was
    opened on a workspace that was immediately removed.
  + bgo#646740: fix keyboard navigation in logout/reboot dialogs.
  + Fix missing inspector icon in Looking Glass console.
  + Miscellaneous minor bug fixes: bgo#645648, bgo#646205,
    bgo#646257, bgo#646855, bgo#647098, bgo#646730.
- Update default-applications.patch to use correct .desktop
  filename for libreoffice.
- Drop gnome-shell-fix-gnome-bluetooth.patch: fixed upstream.
* Thu Apr  7 2011 fcrozat@novell.com
- Update to version 3.0.0.2:
  + bgo#646333: fix missing import that was preventing extensions
    from loading.
  + Updated translations.
* Wed Apr  6 2011 fcrozat@novell.com
- Update to version 3.0.0.1:
  + bgo#646825: fix problem with stuck event handling if network
    menu pops down while user is using the scrollbar.
* Tue Apr  5 2011 fcrozat@novell.com
- Update to version 3.0.0:
  + Add shell_get_file_contents_utf8_sync(), use it instead of gio
    temporarily.
  + gnome-shell.css: fix multiple calendar layout issues
  + network:
  - fix alignment of secure vs insecure wireless icons
  - fix parameters to _findConnection
  - fix VPN connection state
  - ignore invalid and unsupported connection types
  - fix logic bug in checking whether to activate or deactive.
  + end-session-dialog: Show default icon if user icon is unset
  + use scrollbar in sub-menu if needed
  + notificationDaemon: only ignore 'chat' and 'presence'
    notifications from Empathy (bgo#645932)
  + Updated translations.
- Drop 0001-src-add-more-stuff-to-gnome_shell_real_LDADD.patch: no
  longer needed.
* Tue Mar 29 2011 fcrozat@novell.com
- Update to version 2.91.93:
  + Move GSettings schemas under /org/gnome
  + Telepathy chat in message tray:
  - Add proper timestamps between old messages and log messages,
    gray out log messages.
  - Fix duplicate messages
  + Network indicator:
  - Show "firmware missing" when firmware is not available
  - Mark WEP/WPA wireless networks with a security icon
  - Misc bug fixes
  + If present, put the IBus status tray icon in the system status
    area.
  + Look for preferences panel destop files in gnomecc.menus not in
    settings.menus.
  + Change implementation of --replace so that we don't connect to
    XSMP and trigger a gnome-session restart loop.
  + Restore accesss to notifications associated with legacy status
    icons.
  + Fix badly aligned and fuzzy toggle switches in menus.
  + Fix flash of Activities button when entering hot corner.
  + Fix visual artifacts during message tray animations.
  + Fix URL links in notifications.
  + Fix positioning and animations for menus and notification
    bubbles.
  + Fix bug that would result in left-over application menu when no
    application is active.
  + Fixes to translated strings.
  + Misc bug fixes.
  + Build fixes
  + Updated translations.
- Changes from version 2.91.92:
  + New network indicator for NetworkManager 0.9. This mostly
    completes replacing all legacy status icons in the status area
    with native implementations. If NetworkManager 0.9 is not
    found, the old nm-applet status icon will be shown in the
    status area as before.
  + Multi monitor improvements:
  - Rewrite window positioning code to enable multi-monitor
    goodness.
  - Enable new Mutter feature workspaces_only_on_primary so that
    workspace switching only affects the primary monitor and
    windows on other monitors are unaffected.
  - In the overview, show windows for each monitor on that
    monitor rather than scrunching them oddly onto the primary
    monitor.
  - Use new "pointer barriers" feature of XFixes extension to
    trap the mouse cursor at hot screen corners even when there
    are adjacent monitors the cursor could slide onto.
  - Don't use a slideout for the workspace selector if it's at a
    monitor boundary.
  + Message Tray:
  - Combine multiple notifications from the same source into a
    "stack" instead of filling the summary area with identical
    icons.
  - Queue up incoming notifications while the user is interacting
    with the summary area.
  - Don't show resident (permanent) notifications from apps that
    are currently active.
  - Improve styling of items in the message tray to make click
    targets and states more obvious.
  - For legacy status icons, forward clicks on the message tray
    label to the icon.
  - For legacy status icons, kick out of the Activies Overview
    when the icon or label is clicked.
  - Fix scrolling to the bottom when new messages arrive
  - Misc bug fixes
  + Greatly speed up search by not creating objects for
    non-displayed results.
  + Fix long delay on entering overview on certain AMD cards by not
    repeatedly looking for the actor at pointer.
  + Message Tray chat:
  - Add history navigation to entry
  - Handle and display aliases correctly
  - Carry conversations across shell restart
  - Support "actions" like the IRC /me command
  - Retrieve chat history from TelepathyLogger
  + When removing an empty workspace, merge it with the empty
    workspace and enter the overview instead of animating to a
    random adjacent workspace.
  + Performance testing framework
  - Use standardized window confgurations instead of whatever
    windows the user has around.
  - Add new performance metrics for switching to the app view and
    for overview performance with different numbers of windows
    open.
  + Fix up StTooltip (fix bugs, add hover timeouts, and constrain
    tooltips to monitors) and use to display labels on hover over
    applications in the Dash.
  + Allow dragging over the workspace selector during a XDND drag
    to change workspaces.
  + Add Restart button to shutdown dialog.
  + Remove Screen Reader and Screen Keyboard from Accessibility
    menu; not ready to be a prominent feature of GNOME 3.0, though
    still available through System Settings.
  + Honor relevant lockdown GSettings keys
  + Improve appearance of PolicyKit dialogs
  + Fixes for RTL layout
  + Remove sliding startup indicator in favor of a fixed one
  + Obey global GNOME text size setting
  + Visual tweaks
  + Code cleanups
  + Build fixes
  + Bug fixes
- Changes from version 2.91.91:
  + Create a real gnome-shell executable using the new
    libmutter-wm.
  + Launcher script:
  - Don't use the launcher script installed except when built
    with --enable-jhbuild-wrapper-script configure option
  - Remove --eval-file option
  - Move --create-extension option to separate
    gnome-shell-extension-tool script
  - Remove complicated checks to force indirect rendering for
    DRI1.
  + Push status from user menu to Telepathy.
  + Message tray:
  - Add a right click menu with Open/Remove options
  - Remove icons when the associated application exits
  + Add keynav around the overview using Control-Alt-Tab
  + Update style of search display
  + Move calendar handling out of process to avoid probplems if
    evolution-data-server blocks on network traffic.
  + Put one hot corner to activate the Activities Overview on each
    monitor.
  + Try to handle apps with initial splashscreen in automatic
    workspace management code.
  + Show the "New Window" menu item even for non-running
    applications.
  + Allow mouse-wheel scrolling over categories in application
    browser.
  + Scale icons rather than using small icons in the overview and
    Alt-Tab.
  + StWidget: automatically add rtl/ltr pseudoclasses depending on
    the direction of the locale.
  + StWidget: add a popup-menu signal
  + Fixes for right-to-left locales
  + Claim D-Bus names early to avoid race conditions where the old
    notification daemon could be started by D-Bus activation.
  + Drop the custom gs-applications.menu and use the standard GNOME
    menu files for categories.
  + Visual tweaks
  + Code cleanups
  + Build fixes
  + Bug fixes
  + Updated translations.
- Drop gnome-shell-handle-broken-glxinfo.patch: this is obsolete.
- Add 0001-src-add-more-stuff-to-gnome_shell_real_LDADD.patch and
  gnome-shell-fix-gnome-bluetooth.patch: fix startup.
- Add default-applications.patch: this fixes Firefox launcher.
- Remove old gnome3 preview session (gnome-shell-session and
  gnome3.desktop source files): we don't need a preview mode now
  that we have the full GNOME 3.
- Add BuildRequires pkgconfig(libmutter), pkgconfig(libnm-glib),
  pkgconfig(telepathy-logger-0.2)
* Fri Mar  4 2011 vuntz@opensuse.org
- Drop BUILD_AGAINST_GNOME3 magic: now we always build for GNOME 3:
  + Always have a gnome-settings-daemon Requires.
  + Drop gnome-shell-integrate_114.patch.
* Wed Mar  2 2011 fcrozat@novell.com
- Update to version 2.91.90:
  + Workspace handling
  - Replace existing workspace controls in the overview with a
    vertical list of workspace thumbnails.
  - Change workspace orientation in the main view to vertical
  - Workspaces are automatically managed: empty workspaces are
    removed, other than the last workspace which is always empty,
    a new workspace is added when something is started on that
    workspace.
  - Add ability to change workspace by mousewheel scrolling over
    thumbnails
  + Add a PolicyKit authentication agent; requests to the user for
    authentication from PolicyKit now show up as shell-themed
    dialogs.
  + Visual refresh
  - Improve the appearance and behavior of the overview "dash"
  - Use larger icons in the Application browser
  - Improve the appearance of the top panel and round the corners
    of the screen
  - Improve the appearance of the search entry in the overview
  + Remove minimize and maximize buttons from the titlebar
  + Change the options for stopping the system; Suspend is now in
    the menu, while Power Off... is hidden, but can be accessed by
    holding down Alt when browsing the user status menu
  + Port telepathy integration to telepathy-glib from hand-written
    D-Bus code
  + Remove the window filtering and highlighting when using the
    dash application menu - it was confusing and buggy rather than
    helpful
  + Use the alt-tab switcher when <Alt>Above_Tab (alt-` typically)
    is pressed, and fix keybinding handling durng alt-tab.
  + Message tray
  - Improve the expand/collapse behavior of for greater stability
  - Hold notifications while the user is marked busy
  - Group chat messages together
  - Fix bug that resulted in missing icons for contacts without
    avatars
  - Enable navigation using arrow keys between buttons in
    notifications
  + Add audio feedback when scrolling over the volume status icon
  + Add a "Show Layout" item to the input source selector menu
  + Use GLib application launching API, to allow us to associate
    windows with applications in a broader range of circumstances
  + Unify history management between run dialog and looking glass,
    giving consistent behavior
  + Pass extension metadata object to extensions so they can be
    configured in metadata.json
  + Support symbolic colors for legacy tray icons
  + Shell Toolkit: implement ability to specify inset shadows in
    CSS
  + Remove no-longer-useful --xephyr option from gnome-shell
    wrapper script
  + Improve the drawing of the "box pointer" used for menus and
    notifications
  + Memory leak fixes
  + Code cleanups
  + Bug fixes
  + Build fixes
  + Visual tweaks
  + Bugs fixed: bgo#588050, bgo#594071, bgo#594324, bgo#597859,
    bgo#599334, bgo#600771, bgo#603759, bgo#604237, bgo#609791,
    bgo#610818, bgo#612548, bgo#617225, bgo#620416, bgo#631995,
    bgo#632595, bgo#633667, bgo#636156, bgo#636370, bgo#636680,
    bgo#637687, bgo#637745, bgo#638720, bgo#638990, bgo#639324,
    bgo#639341, bgo#639428, bgo#639468, bgo#639943, bgo#640361,
    bgo#640363, bgo#640465, bgo#640583, bgo#640976, bgo#640978,
    bgo#640996, bgo#641060, bgo#641117, bgo#641245, bgo#641359,
    bgo#641415, bgo#641522, bgo#641533, bgo#641537, bgo#641538,
    bgo#641605, bgo#641677, bgo#641726, bgo#641728, bgo#641809,
    bgo#641810, bgo#641879, bgo#641880, bgo#641881, bgo#641886,
    bgo#641887, bgo#641896, bgo#641931, bgo#641973, bgo#641977,
    bgo#641987, bgo#642005, bgo#642031, bgo#642034, bgo#642058,
    bgo#642059, bgo#642117, bgo#642124, bgo#642175, bgo#642189,
    bgo#642192, bgo#642194, bgo#642196, bgo#642207, bgo#642208,
    bgo#642209, bgo#642237, bgo#642287, bgo#642295, bgo#642303,
    bgo#642329, bgo#642333, bgo#642334, bgo#642335, bgo#642483,
    bgo#642510, bgo#642600, bgo#642641, bgo#642672, bgo#642697,
    bgo#642699, bgo#642721, bgo#642726, bgo#642834, bgo#642886,
    bgo#642925.
  + Updated translations.
- Add pkgconfig(gnome-bluetooth-1.0), pkgconfig(polkit-agent-1) and
  pkgconfig(telepathy-glib) BuildRequires.
* Fri Feb 18 2011 vuntz@opensuse.org
- Add gnome-shell-handle-broken-glxinfo.patch to not crash if
  glxinfo doesn't work. Fix bnc#672953.
* Tue Feb 15 2011 sbrabec@suse.cz
- Added support for translation-update-upstream.
* Tue Feb 15 2011 vuntz@opensuse.org
- Fix build: BUILD_AGAINST_GNOME3 is not necessarily defined, so
  use %%{?BUILD_AGAINST_GNOME3}.
* Sun Feb 13 2011 vuntz@opensuse.org
- Call relevant macros in %%post/%%postun:
  + %%desktop_database_post/postun because the package ships at
    least one desktop file.
- Pass %%{?no_lang_C} to %%find_lang so that english documentation
  can be packaged with the program, and not in the lang subpackage.
- Change python-gnome Requires to python-gconf and python-gobject
  Requires: that should be enough.
* Wed Feb  9 2011 fcrozat@novell.com
- Add explicit Requires on dbus-1-python, gjs,
  gdk-pixbuf-loader-rsvg, gnome-icon-theme-symbolic.
* Mon Feb  7 2011 dimstar@opensuse.org
- Drop gnome-shell-old-gsd.patch, obsoleted by new patch.
- Add gnome-shell-integrate_114.patch: contains the feature from
  gnome-shell-old-gsd.patch plus any other modification required to
  properly integrate on openSUSE 11.4. Current fixes are:
  + Work with old gsd
  + Launch yast2 timezone from the dateMenu
  + launch gnomecc instead of gnome-control-ceter (systemMenu)
  + launch gnome-about-me for 'My Accounts' (systemMenu)
  + Remove keyboard indicator applet.
  + Disable accessibility features that do not function (better not
    show than not work).
* Thu Feb  3 2011 dimstar@opensuse.org
- Update to version 2.91.6:
  + Implement new calendar design with Evolution Data Server
    integration to show calendar appointments
  + Add DBus-activatable shell-themed dialogs for logout and
    shutdown
  + Add buttons to search via Google or Wikipedia to the search
    results in the overview. OpenSearch XML files can be used to
    extend the options.
  + Add a keyboard layout selector to the system status area that
    shows up when a keyboard with multiple layouts is configured
  + Switch the default font for the shell UI to Cantarell
  + Accessibility (exposing UI via ATK to assistive technologies)
  - Initialize accessibility
  - Add accessibility support for StWidget and StLabel
  + Improve shadow support in St
  - Allow border images and gradients to be combined
  - Split st-shadow into box-shadow/st-background-image-shadow
    and icon-shadow
  - Clip background and any shadow of the background to the border
  + Use Clutter effects and GL shaders to properly implement faded
    edges for StScrollView
  + Work around problems with keyboard input when IBus is in use
  + Centralize application launching and display errors in the
    message tray
  + Add a generic modal dialog base class used for run dialog and
    for new system dialogs
  + Require shell extensions to declare the versions they are
    compatible with
  + Fix ShellRecorder to work again and switch the default format
    to webm
  + Fix drawing of "bubbles" when pointing to items near a corner
  + Add Main.get/setThemeStylesheet for extensions to modify
  + UI tweaks
  - Add a timeout when mousing over the application switcher
    popup
  - Improve "swipe scrolling in the overview" by allowing swiping
    anywhere on the background and extending it the the
    app/search views as well as the workspace view
  - Make it easier to activate a window by hovering during
    inter-app drag-and-drop
  + Visual tweaks
  + Bugs fixed: bgo#600771, bgo#601393, bgo#612599, bgo#620391,
    bgo#621659, bgo#623708, bgo#626658, bgo#629557, bgo#632109,
    bgo#632595, bgo#634226, bgo#635034, bgo#635089, bgo#636650,
    bgo#636717, bgo#636976, bgo#637187, bgo#638071, bgo#638896,
    bgo#639236, bgo#639255, bgo#639460, bgo#639461, bgo#639474,
    bgo#639689, bgo#639704, bgo#639853, bgo#639914, bgo#639959,
    bgo#639979, bgo#640085, bgo#640206, bgo#640415, bgo#640447,
    bgo#640464, bgo#640493, bgo#640494, bgo#640508, bgo#640560,
    bgo#640688, bgo#641049, bgo#641067.
- Add pkgconfig(libedataserver-1.2) BuildRequires.
* Fri Jan 14 2011 vuntz@opensuse.org
- Update to version 2.91.5:
  + When dragging from an application, allow switching to a
    different application by entering the Activities Overview and
    then hovering over the target application
  + Prioritize chat messages when displaying notifications
  + Don't time out critical notifications
  + Bluetooth indicator fixes:
  - Hide the indicator if no devices present, and fix keynav
    for hidden indicators
  - Move the "Send To" item to the bottom
  - Misc bug fixes
  + Shell Toolkit:
  - Add st_box_layout_insert_before
  + Add another secret run dialog command ('rt') to reload just the
    CSS
  + Fix a bug that was causing the hot corner to not work after
    unlocking the screen saver.
  + Make Alt-F1 leave the overview as well as enter it
  + Further fixes to LD_LIBRARY_PATH setting
  + Pick up clock settings from system preferences
  + Build fixes, work with GTK+-2.99
  + Code cleanups
  + Visual and behavior tweaks
  + Misc bug fixes
  + Bugs fixed: bgo#601731, bgo#604336, bgo#630934, bgo#630942,
    bgo#632151, bgo#633200, bgo#635695, bgo#636371, bgo#636971,
    bgo#637104, bgo#637681, bgo#637690, bgo#637803, bgo#637810,
    bgo#637829, bgo#637830, bgo#638158, bgo#638306, bgo#638315,
    bgo#638453, bgo#638728, bgo#638815, bgo#638990, bgo#639213.
  + Updated translations.
- Drop gnome-shell-CVE-2010-4000.patch: fixed upstream.
- Add Url tag.
- Define a BUILD_AGAINST_GNOME3 macro, to help for the build: some
  things need to be changed when we don't build against a real
  GNOME 3 desktop, but only as a preview.
- Add gnome-shell-old-gsd.patch that we apply when we build
  gnome-shell as a preview only: this disables the "Large text"
  item in the accessibility status menu, that requires
  gnome-settings-daemon 3.
- Add gnome-settings-daemon Requires when we build against GNOME 3.
- Add gsettings-desktop-schemas Requires.
* Fri Jan  7 2011 vuntz@opensuse.org
- Update to version 2.91.4:
  + Add Bluetooth system status indicator
  + Implement inline expandable submenus
  + Add category filters to application browser
  + Add resident and transient notifications to message tray:
  - transient: temporary message that doesn't migrate to summary
  - area resident: stays around as long as application is running
  + Implement keynav to the panel and message tray with
    Control-Alt-Tab
  + Implement different border widths for different sides in
    Shell Toolkit CSS handling
  + Rework magnifier code to avoid overhead when not magnifying
  + Improve algorithm for proportional tracking in magnifier
  + Update for GTK+ 3 changes
  + Fix workspaces switching and menus for RTL
  + Use symbolic icons for system notifications
  + Don't animate windows on other workspaces when going to the
    overview
  + Don't do slide-out animation when scrubbing between menus
  + Fix blinking when updating status icons
  + Tweaks and fixes for visual bugs
  + String translation marking fixes
  + Code cleanups
  + Build fixes
  + Miscellaneous bug fixes
  + Bugs fixed: bgo#595379, bgo#618312, bgo#618885, bgo#622451,
    bgo#623706, bgo#624900, bgo#624935, bgo#626132, bgo#629950,
    bgo#629984, bgo#631004, bgo#633412, bgo#633476, bgo#633553,
    bgo#633582, bgo#633719, bgo#634550, bgo#634560, bgo#634691,
    bgo#634755, bgo#634814, bgo#635393, bgo#635647, bgo#635728,
    bgo#635880, bgo#635991, bgo#636137, bgo#636151, bgo#636155,
    bgo#636317, bgo#636330, bgo#636489, bgo#636975, bgo#636982,
    bgo#636983, bgo#637353, bgo#637477, bgo#637559.
  + Updated translations.
- Changes from version 2.91.3:
  + New layout for overview
  - The complex dash is replaced with a narrower line of icons,
    giving more space for the windows
  - A set of "tabs" is added at the top of the overview for
    selecting between Windows/Applications (and eventually files)
  - Grid vs. linear workspace view distinction is gone
  - Desktop background stays fixed rather than zooming
  - Enhanced feedback is added while dragging and dropping
    favorites
  + Native power and battery status icon and drop-down
  + Optimization:
  - Report paint volumes to take advantage of partial stage
    repaints in Clutter 1.5
  - Skip drawing transparent backgrounds and borders
  - Use new smart background drawing functionality in Mutter
  - Don't clear the stage since we paint over all of it
  - Use a more efficient way of tracking actor under the drag
    icon during DND
  + Make links in message tray messages clickable
  + Add timestamps to expanded chat
  + StIcon
  - Import MxIcon
  - Make colorize symbolic icons and follow icon theme changes
  - Add ability to load GIcon
  - Add drop shadow support
  + Use StLabel for StTooltip to support full CSS styling
  + Visual and UI tweaks
  - invisible status is removed from the user menu as raising
    various problematical IM interactions
  - Restart option is removed from the user menu as less
    generally useful and not worth the clutter
  - Make the volume dropdown much simpler
  + Use the raw WM_CLASS value rather than the window title for
    applications that aren't properly associated with a desktop
    file
  + Fix interaction of accessibility menu with GSettings keys
  + Fix annoying misbehavior with window snapback during DND in the
    linear workspace view
  + Correct copyright and license notices for St
  + When creating an extension, print where we created it
  + Fix memory management crashers
  + Build fixes
  + Misc bug fixes
  + Bugs fixed: bgo#610219, bgo#613448, bgo#622450, bgo#622451,
    bgo#624361, bgo#624584, bgo#630752, bgo#630932, bgo#632824,
    bgo#633036, bgo#633595, bgo#633657, bgo#633853, bgo#633865,
    bgo#633866, bgo#634225, bgo#634329, bgo#634451, bgo#634550,
    bgo#634552, bgo#634555, bgo#634693, bgo#634736, bgo#634752,
    bgo#634767, bgo#634769, bgo#634781, bgo#634836, bgo#634865,
    bgo#634948, bgo#635141, bgo#635199, bgo#635264, bgo#635272,
    bgo#635278, bgo#635288, bgo#635367, bgo#635471, bgo#635608,
    bgo#635712.
  + Updated translations.
- Drop gnome-shell-fix-include.patch,
  gnome-shell-gtk3-2.91.6.patch: both are fixed upstream.
* Wed Jan  5 2011 vuntz@opensuse.org
- Add gnome-shell-CVE-2010-4000.patch to really safely set
  LD_LIBRARY_PATH. Fix bnc#642827 and CVE-2010-4000.
* Wed Dec 15 2010 vuntz@opensuse.org
- Add gnome-shell-fix-include.patch to fix the build after a change
  in gnome-desktop; taken from git.
- Add gnome-shell-gtk3-2.91.6.patch to fix build with gtk3 2.91.6;
  taken from git.
* Thu Nov 18 2010 vuntz@opensuse.org
- Update to version 2.91.2:
  + Use GNOME 3 WM theme by default
  + Add general keyboard focus support to the Shell Toolkit
  + Support new notification spec 'action-icons' to turn on icon
    buttons.
  + Pay attention to the distance the mouse has moved from the
    message tray when deciding how quickly to hide the tray
  + Change magnifier defaults to be full screen
  + Fix creating many one-shot Clutter materials and compiling many
    shader programs per frame
  + Visual tweaks
  + Bug fixes, including: bgo#593844, bgo#621671, bgo#621880,
    bgo#625545, bgo#629884, bgo#630546, bgo#630767, bgo#633340,
    bgo#633418, bgo#633490, bgo#633591, bgo#633668, bgo#633853,
    bgo#634103.
  + Build fixes
  + Updated translations.
* Thu Oct 28 2010 vuntz@opensuse.org
- Update to version 2.91.1:
  + Add native volume-control status icon:
  - Import gnome-volume-control pulse-audio wrapper code
  - Add mousewheel support
  + Message tray:
  - Fix wobbling during mouse-over animation
  - Don't show the tray when a status is added then immediately
    removed
  - Advertise a 'persistence' notification server capability to
    allow applications to act different if their notifications
    won't be lost
  - Use a "box pointer" when displaying notifications
  - Bug fixes
  + Shell Toolkit:
  - Simplify the API for custom style properties
  - Support different border radii for different corners
  + Update cut-and-paste GDM user manager code to newer version
    that talks to the account service
  + Find desktop files in /usr/local/share/applications
  + Visual improvements to menus to match mockups
  + Add animation when showing menus and status notifications
  + Fix problem where StDrawingArea was constantly redrawing
  + Only show starting applications on the current workspace
  + Misc bug fixes
  + Build fixes
  + Bugs fixed: bgo#582653, bgo#583348, bgo#591406, bgo#593887,
    bgo#598347, bgo#603838, bgo#603992, bgo#611647, bgo#614879,
    bgo#617917, bgo#620389, bgo#623688, bgo#628169, bgo#629455,
    bgo#630546, bgo#630866, bgo#630939, bgo#631042, bgo#631193,
    bgo#631510, bgo#631566, bgo#631722, bgo#631888, bgo#632147,
    bgo#632151, bgo#632197, bgo#632477, bgo#632500, bgo#632733,
    bgo#632743, bgo#632868.
  + Updated translations.
- Add pkgconfig(libcanberra), pkgconfig(libpulse-mainloop-glib)
  BuildRequires.
* Tue Oct  5 2010 vuntz@opensuse.org
- Update to version 2.91.0:
  + Move application tray icons from the system status area to the
    message tray
  + Turn on the new Mutter feature for attaching modal dialogs to
    their parents, and add visual effects of sliding in and dimming
    the parent window
  + Turn on the new Mutter feature for side-by-side tiling
  + System status area:
  - Add Universal Access status indicator
  - Implement an API for in-process system status indicators
  - Allow dynamically adding and removing menus from
    PopupMenuManager
  - Add toggle-switch menu items
  - Add horizontal sliders for PopupMenus
  - Add support for sub-menus
  - Use symbolic icons when available
  + Shell Toolkit
  - Add :first-child, :last-child pseudo-class support
  - Add basic suport for background-position CSS property
  - Add text-shadow CSS property and implement for St.Label
  - Make padding work for St.Scrollbar
  - Support symbolic icons for St.TextureCache.load_icon_name()
  + Message tray
  - Focus notifications when clicking on them to display
    notification, or hovering over them to expand them
  - Make Esc hide the tray when a notification has focus
  - Make the whole notification clickable
  - For expanded notifications, line-wrap long titles rather than
    ellipsizing
  - Visual improvements
  - Auto-expand urgent notifications
  - Bug and behavior fixes
  + Change cursor during drag-and-drop of items to reflect state
  + Looking Glass
  - Enable scroll-wheel to pick parent/child actors
  - Close inspector on escape
  + Remove Alt+W/A/S/D hack for navigation in alt-Tab -
    was just a Xephyr bug workaround
  + Fixes for GTK+-3 changes
  + Adapt introspection build and annotations for g-ir-scanner
    changes
  + Add Dash.addSearchProvider(provider) so extensions can register
    search providers
  + Port magnifier to GSettings
  + Support compiling and running with XulRunner 2.0
  + Optimizations for theme transitions
  + Switch to building against Clutter 1.4
  + Build fixes
  + Cleanups
  + Misc bug fixes
  + Updated translations.
- Drop gnome-shell-fix-recent-gtk3.patch,
  gnome-shell-fix-recent-clutter.patch,
  gnome-shell-secure-LD_LIBRARY_PATH.patch: fixed upstream.
* Thu Sep 30 2010 vuntz@opensuse.org
- Add gnome-shell-secure-LD_LIBRARY_PATH.patch to make sure to not
  add empty elements to LD_LIBRARY_PATH. Fix bnc#642827.
* Mon Sep 20 2010 vuntz@opensuse.org
- Add gnome-shell-fix-recent-clutter.patch: gnome-shell failed to
  run because it was using some API gone in clutter 1.3.14.
* Sat Sep 18 2010 vuntz@opensuse.org
- Drop gir-repository BuildRequires: this was only needed for the
  DBusGLib gir, which is now part of gobject-introspection.
- Update gnome-shell-fix-recent-gtk3.patch to fix build with GTK+
  2.90.7.
* Thu Sep  9 2010 vuntz@opensuse.org
- Add gnome-shell-fix-recent-gtk3.patch to fix build with recent
  GTK+ 3.
- Drop gnome-shell-libmozjs.patch: it was needed for 11.1 only, and
  the package won't work there anyway. Also remove the workaround
  for the 11.1 build.
- Change old-style BuildRequires to pkgconfig() style
  BuildRequires:
  + old-style: clutter-devel, dbus-1-glib-devel, gconf2-devel,
    gnome-menus-devel, gstreamer-0_10-devel,
    gstreamer-0_10-plugins-base-devel, libgjs-devel, mutter-devel,
    xorg-x11-devel.
  + new-style: clutter-1.0, dbus-glib-1, gconf-2.0, gio-2.0,
    gjs-1.0, gobject-introspection-1.0, gstreamer-0.10,
    gstreamer-base-0.10, libgnome-menu,
    libstartup-notification-1.0, mutter-plugins, xfixes.
- Change lang Requires to Recommends.
- Do not call autoreconf: it's not needed.
- Pass --disable-schemas-install to configure.
- Remove unneeded librsvg-devel BuildRequires.
* Thu Jul 15 2010 dimstar@opensuse.org
- Update to version 2.31.5:
  + Build against and depend on GTK+-3.0
  + If a notification ID has a name matching a themed icon, use the
    icon for that button when displaying the notification
  + Work around problems with typedef GdkRectangle
    cairo_rectangle_int_t
  + Visual tweak: don't bounce the startup notification back and
    forth
  + Build fixes
  + Bugs fixed:
  - bgo#623494: [TelepathyClient] Missing presence notifications
  - Other bugs: bgo#621014, bgo#621845, bgo#623353, bgo#623640,
    bgo#623687, bgo#623889
- Replace gtk2-devel BuildRequires with pkgconfig(gtk+-3.0) and
  gnome-desktop-devel with pkgconfig(gnome-desktop-3.0).
- Add pkgconfig(libcroco-0.6) BuildRequires.
- Add gconf2_gsettings_* macros to post, postun and preamble. Note
  that there are still some gconf schemas, so we don't remove
  anything from the gconf schema handling.
* Sat Jun 26 2010 dimstar@opensuse.org
- Update to version 2.31.4:
  + UI changes and additions:
  - Expand notification icons on hover to show title
  - Display an animation on the app menu title for startup
    notification
  - Add a right-click option on the clock to get to the
    preference dialog
  - Add sections to the application browser in the overview
  - Add week-number support to calendar
  - Hide application menu in overview
  + Visual improvements:
  - Fade in the alt-Tab popups, use consistent fade-in timings
  - Use the same code and visuals for all menu popups
  - Use newly implemented CSS style transitions to animate hover
    effects
  - Use status icons from the icon theme
  - Misc tweaks
  + Switch from GConf to GSettings:
  - Use the dconf backend
  - Followup fixes
  + Stop Ubuntu indicators on startup (this causes proper fallback
    to the system tray specification)
  + Right-to-left locale fixes
  + Multihead fixes
  + St [Shell Toolkit] improvements:
  - Add 'transition-duration' property for animated style changes
  - Implement CSS 'outline' property
  - Implement CSS 'text-align' property
  - Add st_describe_actor() and use it for Actor.toString in JS
  - Add st_texture_cache_load_sliced_image
  - Add st_set_slow_down_factor() to replace
    Tweener.slowDownFactor
  + Replace the frame count in perf stats with an accurate frame
    rate
  + Add 'x' format specifier and field width to our String.format()
  + Code cleanups
  + Build fixes
  + Bugs fixed: bgo#597481, bgo#598349, bgo#600276, bgo#602466,
    bgo#603532, bgo#610868, bgo#611095, bgo#611269, bgo#612635,
    bgo#613286, bgo#613907, bgo#614131, bgo#617281, bgo#617917,
    bgo#618055, bgo#618873, bgo#619025, bgo#619083, bgo#619203,
    bgo#619236, bgo#619240, bgo#619515, bgo#619516, bgo#619521,
    bgo#619541, bgo#619693, bgo#619854, bgo#620125, bgo#620374,
    bgo#620377, bgo#620378, bgo#620381, bgo#620404, bgo#620504,
    bgo#620525, bgo#620775, bgo#620782, bgo#620783, bgo#620855,
    bgo#620899, bgo#620940, bgo#620997, bgo#621083, bgo#621123,
    bgo#621140, bgo#621197, bgo#621247, bgo#621382, bgo#621385,
    bgo#621582, bgo#621668, bgo#621669, bgo#622050, bgo#622236,
    bgo#622243, bgo#622249, bgo#622308, bgo#622395, bgo#622447,
    bgo#622458, bgo#622508
- Use %%{?_smp_mflags} for parallel build.
* Thu May 27 2010 dimstar@opensuse.org
- Update to version 2.31.2:
  + Add a magnifier to the shell
  + Make the clock configurable via GConf and add a simple
    preferences dialog (gnome-shell-clock-preferences)
  + Message tray:
  - Support inline chatting in IM notifications; IM notifications
    now use Telepathy, rather than the generic notification
    protocol.
  - Display urgent notifications first and fully expanded
  - Pop out last notification when mousing over summary area
  - Don't time out the tray if the user is mousing towards it
  + Shell performance framework:
  - Add a performance event log that tracks events (such as frame
    paints), and statistics such as malloc'ed memory.
  - Javascript "performance scripts" drive the shell and then
    extract "metrics" such as the frame rate when zooming to the
    overview.
  - Recorded performance data can be uploaded to
    http://shell-perf.gnome.org
  + Add an initial application menu in the top panel; currently
    just has a Quit option.
  + User interface enhancements:
  - Allow using the middle mouse button to open an instance of an
    application on a new workspace
  - Restyle user status menu to match application menu, rather
    than being an out-of-place GTK+ menu
  - Add keyboard navigation of menus
  - Raise all windows for an application when alt-Tabbing to it
    or clicking on it in the app well
  - Restore click-and-hold menus for app-well icons
  - Fade in windows on map rather than scaling them in
  - Remove icon and menu from window titlebar
  - In linear view, activate the drop-target workspace
  - When dragging on linear workspace view, detect when the user
  * didn't*  mean to "throw" to the next workspace
  - Always hide the info (e.g. undo) bar after a short timeout
  - Provide the feedback in the info bar when it is not possible
    to create new workspace or remove the current workspace
  - Visual tweaks
  + Run dialog:
  - Don't add duplicates to the history
  - Accept Enter (keypad) key in addition to Return.
  + Remove the sidebar; it's not the direction we want to go for
    "gizmos", and the unfinished version was showing up in too many
    screenshots.
  + Shell Toolkit:
  - Add methods to add/remove individual names from style class
  - Add hover tracking to StWidget
  - Refactor drawing from StWidget to StThemeNode
  - Add support for "spread radius" to shadows
  - Shadow all background/border elements, not just the
    background image
  - Add a StContainer base class with common container
    functionality
  - Add a StGroup container to mix fixed positioning with CSS
  + Looking Glass:
  - Add window list
  - Replace properties tab with a properties popup
  + GTK+ 3 compat: Build properly against GTK+ with -DGSEAL_ENABLE
  + Call JS_MaybeGC at idle, hopefully reducing GC pauses
  + Move user files to XDG_DATA_HOME, rather than ~/.gnome2
  + Remove libbig, rewriting remaining code to use ST instead
  + Pick up system settings for font rendering
  + Support application identification by startup notification
    properties
  + Many bug fixes for full-screen window handling
  + Improve identification of primary monitor for multihead
  + Prefer eject over unmount for the eject button in places
  + Fix many bugs with using the wrong functions to get event
    state, then block the wrong functions once and for all
  + Build fixes
  + Code cleanups
  + Bugs fixed: bgo#610726, bgo#610801, bgo#610872, bgo#610892,
    bgo#611609, bgo#611610, bgo#611612, bgo#611613, bgo#611660,
    bgo#611754, bgo#612072, bgo#612200, bgo#612635, bgo#612651,
    bgo#612833, bgo#612967, bgo#613101, bgo#613164, bgo#613195,
    bgo#613367, bgo#613405, bgo#613428, bgo#613456, bgo#613536,
    bgo#613731, bgo#613749, bgo#613804, bgo#613832, bgo#613944,
    bgo#613964, bgo#614047, bgo#614144, bgo#614293, bgo#614362,
    bgo#614516, bgo#614660, bgo#614702, bgo#614725, bgo#614755,
    bgo#614905, bgo#614972, bgo#614974, bgo#614975, bgo#614978,
    bgo#615004, bgo#615590, bgo#615592, bgo#615621, bgo#616051,
    bgo#616574, bgo#616706, bgo#616951, bgo#617555, bgo#617785,
    bgo#617959, bgo#618062, bgo#618104, bgo#618189, bgo#618258,
    bgo#618295, bgo#618371, bgo#618378, bgo#618438, bgo#618460,
    bgo#618482, bgo#618793, bgo#618915, bgo#618918, bgo#619008,
    bgo#619044, bgo#619113, bgo#619144, bgo#619276, bgo#619580,
    bgo#619623
  + Updated translations.
* Tue Mar 23 2010 vuntz@opensuse.org
- Update to version 2.29.1:
  + For a full list of changes, see
    http://mail.gnome.org/archives/gnome-shell-list/2010-March/msg00096.html
  + Support and require Clutter 1.2
  + Allow dragging windows in the linear workspaces view
  + Shrink and scale the application switcher as necessary when
    there are too many applications to fit on the screen
  + Scroll in the linear view by clicking on desktop and dragging
  + Display application search results as tiles
  + Improve RTL support
  + Add WindowManager.setKeybindingHandler() to allow extensions to
    take over keybindings such as alt-Tab
  + Add style information to the LookingGlass actor picker
  + Run dialog improvements:
  - Make <Control>Return run in terminal
  - Port to CSS
  - Support opening files and folders
  - Store history in GConf and allow access with up arrow
  + Minor UI improvements:
  - Show a message when unmount from "Places & Devices" fails
  - Use one button to toggle between single and grid view
  - Disable clicking on the background of workspaces with
    multiple windows to prevent accidental workspace activation
    when activating a window
  - Reduce window movement when closing windows from the overview
  - Update look and feel of the search field to match mockups
  - Animate the transition between the linear and grid views
  - Shrink windows to small previews when dragging
  - Visual tweaks
  - Make workspace switch keybindings work in the overview
  + Shell toolkit (ST):
  - allow "background-gradient-direction: none"
  - replace StTextureCache with the much more feature-rich
    ShellTextureCache
  - Add st_texture_cache_load() and
    st_texture_cache_load_file_to_cogl_texture()
  - Add caret-size CSS property to style the size of the StEntry
    cursor
  - Clean up and rework scrolling to work better with Clutter
    size negotiation
  - Redo StDrawingArea not to use ClutterCairoTexture, fixing
    Clutter-1.2 compatibility
  - Rewrite StScrollbar size allocation for clutter-1.2
    compatibiltiy
  - Add :hover pseudo-class support to StEntry
  - Add st_theme_node_get_horizontal/vertical_padding
  - Factor out common ClutterContainer implementation code
  - Improve handling of hint text
  + Development and building:
  - Add a --version command line option
  - Add 'gnome-shell-full' target to our jhbuild that builds GTK+
    stack in addition to more immediate gnome-shell dependencies
  - To allow debugging from an ssh session, when running without
    a display, automatically try to connect to a current session
    of the same user
  - Error out at startup if GConf schemas are missing
  - Change screencast extension to ogv
  - Build fixes
  + Code cleanups
  + Bug fixes:
  - Fix detection of 12/24 locals
  - Memory leak fixes
  - Miscellaneous bug fixes
  + Updated translations.
- Drop gnome-shell-translations.patch: fixed upstream.
* Tue Feb 23 2010 vuntz@opensuse.org
- Update to version 2.29.0:
  + For a full list of changes, see
    http://mail.gnome.org/archives/gnome-shell-list/2010-February/msg00058.html
  + New message tray showing notifications sliding into the bottom
    of the screen. Includes a status area for past notifications,
    and also pulls in "urgent window" handled in GNOME 2 by
    flashing the taskbar.
  + Add the ability to set your presence to the user status menu
  + Allow switching the overview between a grid and linear view of
    workspaces
  + Redo the application browser to use a grid of icons
  + Initial version of the extension system
  + Initial support for RTL layout in ST and the shell
  + Add undo capability to overview, e.g., when removing favorites
  + New workspace switcher popup
  + Work on visual appearance to match mockups
  + Port most of existing code to CSS
  + Other visual improvements
  - Show a scaled-up excerpt from the application item in the
    panel
  - Minimize windows to 'Activities' button
  - Fade out desktop icons when showing overview
  - Use a fixed ordering for well-known icons in the system tray
  - Nicer animation of hidden windows when transitioning to/from
    the overview
  - Draw a ripple when the hot corner is hit
  + App switcher (Alt-Tab) improvements
  - Many behavior and visual refinements based on design feedback
  - Show a separator between windows on this and other workspaces
  - Position on the currently focused monitor
  - Bug fixes
  + Miscellaneous behavioral improvements
  - Allow workspace switching by mousewheel on indicators in
    overview
  - Allow dropping on workspace indicators
  - Enable DND of search results
  - When closing a window from the overview that puts up a
    confirm dialog, switch to that dialog
  - When the sidebar is collapsed, auto-hide it
  - Show "No matching results" when search matches nothing
  - Limit user to 16 workspaces
  - Allow clicking on any part of section headers in the dash for
    browsing
  - Match on executable names as well when searching
  - For clock AM/PM vs. 24-hour based on the locale
  + ST (Shell Toolkit) improvements
  - CSS addtions:
    . width/height
    . max-width/max-height
    . -st-shadow
    . gradients
    . radial gradients
    . Non-uniform border widths (when no corner radius)
    . text-decoration: [underline|strikethrough]
  - Make allocation behavior consistent across actors
  - Support fixed-position children in StBoxLayout
  - Support raising and lowering children in StBoxLayout
  - Add st_box_layout_move_child and st_box_layout_insert_actor
  - Add st_box_layout_remove_all, st_box_layout_destroy_children,
    st_box_layout_get_n_children
  - Add StClickable, StOverflowBox actors
  - Support setting scrollbar policy on StScrollView
  - Support shadows on edges of StScrollView to hint at more
    content
  + Make places results available in search
  + Handle changes to the current resolution
  + Bug fixes for multihead support
  + Make screen shell recorder work again
  + More miscellaneous improvements
  - Add gnome-shell --eval-file=<file> to eval file in running
    shell via D-BUS
  - Add eject buttons to places section
  - Add completion to the Alt-F2 run dialog
  - Make screen recording parameters configurable
  - Add an initial version of a manpage
  + Performance improvements
  + Code cleanups
  + Bug fixes
  + Build fixes
  + Updated translations.
- Drop gnome-shell-leak.patch: fixed upstream.
- Add gnome-shell-translations.patch to fix installation of
  translations, and call autoreconf -fi for this patch.
* Thu Jan 28 2010 vuntz@opensuse.org
- Pass --enable-compile-warnings=no to configure, to avoid broken
  build because of deprecated functions.
* Sun Oct 11 2009 vuntz@opensuse.org
- Add gnome-shell-leak.patch from git to fix some slow down after
  using alt-tab a lot.
* Thu Oct  8 2009 vuntz@opensuse.org
- Update to version 2.28.0:
  + Many changes, for the complete list, see
    http://git.gnome.org/cgit/gnome-shell/log/?id=2.28.0
  + New application switcher with alt-tab
  + bgo#594916 - Allow cancelling DND by hitting Esc
  + Use a stable minimum-motion placement for windows
  + Remove window destroy effect
  + Improve support for multihead setups
  + Possibility to use CSS for styling
  + Add scroll-wheel support to the calendar
  + Many bug fixes and UI improvements
* Wed Oct  7 2009 vuntz@opensuse.org
- Create a preview mode for GNOME 3 that can be started from gdm:
  + install a .desktop file in /usr/share/xsessions.
  + this .desktop file starts a script that will prepend a custom
    directory to XDG_CONFIG_DIRS and then start the usual GNOME
    script.
  + the custom directory contain an autostart file for gnome-shell,
    that overrides the default gnome-panel+windowmanager combo.
* Wed Sep 16 2009 lmedinas@opensuse.org
- Update to version 2.27.3:
  + Add a popup menu to the "Applications" area in the overview
    that shows up on click on hold and allows selecting between the
    windows of the application
  + Search enhancements:
  - Add a separate search results section for "Preferences"
  - Hide search headers for empty sections
  + Make mouse scroll window over windows in the overview zoom them
  + Display errors nicely if command execution in the run dialog
    fails
  + Make the run dialog and "looking glass" debug console work in
    the overview
  + Control-click on applications now opens a new window
  + Bug fixes
  + Build fixes
  + Code cleanups
  + Updated translations.
* Wed Sep  9 2009 vuntz@opensuse.org
- Update to version 2.27.2:
  + See http://git.gnome.org/cgit/gnome-shell/log/?id=2.27.2 for
    details, here's a selection of the important changes
  + bgo#592507 - Javascript exception when ~/.gtk-bookmarks is missing
  + Add an active property to ShellButtonBox
  + ShellButtonBox: Use default handlers, not self-connections
  + ShellButtonBox: only listen to button 1 and single clicks
  + Simplify Button class by using ShellButtonBox
  + Build tweaks
  + Consolidate window tracking filters between app monitor and
    overview
  + Do not display windows with skip-taskbar hint in overview
  + Improve key navigation for search results
  + Remove the timeout for checking if an item is drawn under the
    pointer
  + Merge headers when a single section of search results is
    displayed
  + Add Tweener.slowDownFactor, initialize from
    $GNOME_SHELL_SLOWDOWN_FACTOR
  + Add API to programmatically initiate a drag
  + Add shell_texture_cache_pixbufs_equal
  + Add shell_button_box_fake_release
  + Add volumes support to places
  + Remove some vestigial code
  + Redo AppWell glow to be based on a based on a .png instead of
    cairo
  + Make checking if an item is under the pointer asynchonous again
  + Compress notifications of menu changes with a timeout
  + bgo#594184 - Fix up glow positioning logic
  + Updated translations.
* Sat Aug 29 2009 vuntz@novell.com
- Update to version 2.27.1:
  + See http://git.gnome.org/cgit/gnome-shell/log/?id=2.27.1 for
    details, here's a selection of the important changes
  + Many UI improvements
  + Use GnomeDesktopThumbnailFactory instead of
    GnomeThumbnailFactory
  + panel: Switch to fully dynamic layout
  + Add application menu area to panel
  + Move towards shell-black02 mockup
  + Implement the multi-window highlight on WellDisplayItem
  + Make dragging an item to the Add Workspace button launch it on
    a new workspace
  + Implement distinct 2-window and multi-window highlights
  + Remove maximization effects
  + Add localization support.
  + Highlight the search entry when the user clicks or starts
    typing in it
  + Prevent activating hot corner multiple times by accident
  + ShellAppMonitor: create "applications" for unknown windows
  + Don't show empty categories
  + Make recent docs display two columns
  + Display search results in the dash
  + Only respawn if gnome-shell exits abnormally
  + Use new plugin-modality functionality in Mutter
  + Add 'r' as an alias to 'restart' in run dialog
  + Improve display of search results
  + Better handling of Nautilus window
  + Handle window title changes causing mapping changes
  + Require an explicit --xephyr option
  + Restore GNOME based on GNOME configuration
  + Make the gradient on the top panel the same as the "dash"
  + Change search box text to "Find..."
  + Renable PrintScreen and Super_L in the overview
- Remove libgnomeui-devel, libwnck-devel BuildRequires.
- Add gnome-desktop-devel, intltool BuildRequires.
- Add lang package.
* Wed Aug 12 2009 vuntz@novell.com
- Update to version 2.27.0:
  + This is the first official tarball.
  + No list of changes as the code is really moving a lot at the
    moment.
- Drop gnome-shell-clutter-1.0.patch: fixed upstream.
- Remove gnome-common BuildRequires and gnome-autogen.sh call.
* Mon Aug  3 2009 vuntz@novell.com
- Add gnome-shell-clutter-1.0.patch to fix build with clutter 1.0,
  and add gnome-common BuildRequires and gnome-autogen.sh call.
* Wed Jul 22 2009 vuntz@novell.com
- Update to git as of today.
- Use libexecdir.
* Fri Jul 17 2009 vuntz@novell.com
- Change clutter-unstable-devel BuildRequires to clutter-devel.
* Thu May 14 2009 vuntz@novell.com
- Update to git version as of May 14th.
- Drop gnome-shell-no-static-lib.patch: fixed upstream.
* Mon May  4 2009 vuntz@novell.com
- Try to fix build on 11.1.
* Mon May  4 2009 vuntz@novell.com
- Add tarball created from git, with a patch to adapt for the
  mutter rename (included in the tarball, unforunately, since I
  couldn't generate the tarball without the patch).
* Fri May  1 2009 vuntz@novell.com
- Initial package.
